@@ -88,7 +88,8 @@ $LANG_CAL_1 = array(
     48 => 'klikke',
     49 => 'Nib, et saidil pole htegi sndmust vi mitte keegi pole neil klpsanud.',
     50 => 'Sndmused',
-    51 => 'Kustuta'
+    51 => 'Kustuta',
+    'autotag_desc_event' => '[event: id alternate title] - Displays a link to an Event Link from the Calendar using the Event Title as the title. An alternate title may be specified but is not required.'
 );
 
 $_LANG_CAL_SEARCH = array(
@@ -109,7 +110,7 @@ $LANG_CAL_2 = array(
     11 => 'Peakalender',
     12 => 'Minu kalender',
     25 => 'tagasi ',
-    26 => 'Kik pevad',
+    26 => 'Kogu pev',
     27 => 'Ndal',
     28 => 'Isiklik kalender, kasutaja',
     29 => 'Avalik kalender',
@@ -209,16 +210,34 @@ $LANG_confignames['calendar'] = array(
     'notification' => 'Teavituskiri?',
     'delete_event' => 'Kustuta sndmused, omanikuks?',
     'aftersave' => 'Prast sndmuste salvestamist',
-    'default_permissions' => 'Sndmuste vaikimisi igused'
+    'default_permissions' => 'Sndmuste vaikimisi igused',
+    'autotag_permissions_event' => '[event: ] Permissions',
+    'block_enable' => 'Enabled',
+    'block_isleft' => 'Display Block on Left',
+    'block_order' => 'Block Order',
+    'block_topic_option' => 'Topic Options',
+    'block_topic' => 'Topic',
+    'block_group_id' => 'Group',
+    'block_permissions' => 'Permissions'
 );
 
 $LANG_configsubgroups['calendar'] = array(
     'sg_main' => 'Peahlestused'
 );
 
+$LANG_tab['calendar'] = array(
+    'tab_main' => 'General Calendar Settings',
+    'tab_permissions' => 'Default Permissions',
+    'tab_autotag_permissions' => 'Autotag Usage Permissions',
+    'tab_events_block' => 'Events Block'
+);
+
 $LANG_fs['calendar'] = array(
     'fs_main' => 'Kalendri ldised hlestused',
-    'fs_permissions' => 'Vaikimisi igused'
+    'fs_permissions' => 'Vaikimisi igused',
+    'fs_autotag_permissions' => 'Autotag Usage Permissions',
+    'fs_block_settings' => 'Block Settings',
+    'fs_block_permissions' => 'Block Permissions'
 );
 
 // Note: entries 0, 1, 6, 9, 12 are the same as in $LANG_configselects['Core']
@@ -226,8 +245,11 @@ $LANG_configselects['calendar'] = array(
     0 => array('Jah' => 1, 'Ei' => 0),
     1 => array('Jah' => true, 'Ei' => false),
     6 => array('12' => 12, '24' => 24),
-    9 => array('Suuna sndmuste juurde' => 'item', 'Nita administreerimisloetelu' => 'list', 'Nita kalendrit' => 'plugin', 'Niga avalehte' => 'home', 'Nita admini lehte' => 'admin'),
-    12 => array('Pole ligipsu' => 0, 'Ainult loetav' => 2, 'Loetav ja muudetav' => 3)
+    9 => array('Suuna sndmuste juurde' => 'item', 'Nita administreerimisloetelu' => 'list', 'Nita kalendrit' => 'plugin', 'Nita avalehte' => 'home', 'Nita admini lehte' => 'admin'),
+    12 => array('Pole ligipsu' => 0, 'Ainult loetav' => 2, 'Loetav ja muudetav' => 3),
+    13 => array('No access' => 0, 'Use' => 2),
+    14 => array('No access' => 0, 'Read-Only' => 2),
+    15 => array('All' => TOPIC_ALL_OPTION, 'Homepage Only' => TOPIC_HOMEONLY_OPTION, 'Select Topics' => TOPIC_SELECTED_OPTION)
 );
 
 ?>
