@@ -42,22 +42,22 @@ global $LANG32;
 
 # index.php
 $LANG_CAL_1 = array(
-    1 => 'イベントカレンダ',
+    1 => 'イベントカレンダー',
     2 => '-',
     3 => '日時',
     4 => '場所',
     5 => '詳細',
     6 => 'イベントの追加',
     7 => 'これからのイベント',
-    8 => '個人カレンダにこのイベントを追加すると、「個人カレンダ」をユーザ管理メニューから選択することで見ることができます。',
-    9 => '個人カレンダに追加',
-    10 => '個人カレンダから削除',
-    11 => 'このイベントを %sの個人カレンダに追加',
+    8 => '個人カレンダーにこのイベントを追加すると、「個人カレンダー」をユーザー管理メニューから選択することで見ることができます。',
+    9 => '個人カレンダーに追加',
+    10 => '個人カレンダーから削除',
+    11 => 'このイベントを %sの個人カレンダーに追加',
     12 => 'イベント',
     13 => '開始',
     14 => '終了',
-    15 => 'カレンダに戻る',
-    16 => 'カレンダ',
+    15 => 'カレンダーに戻る',
+    16 => 'カレンダー',
     17 => '開始',
     18 => '終了',
     19 => 'イベントの投稿申請',
@@ -68,7 +68,7 @@ $LANG_CAL_1 = array(
     24 => '全体イベント',
     25 => '-',
     26 => 'イベントを投稿する',
-    27 => "{$_CONF['site_name']}にイベントを投稿すると、サイト全体のカレンダに登録されます。<br" . XHTML . ">全体カレンダのイベントは、各ユーザが必要に応じて個人カレンダに登録できます。",
+    27 => "{$_CONF['site_name']}にイベントを投稿すると、サイト全体のカレンダーに登録します。<br" . XHTML . ">全体カレンダーのイベントは、各ユーザーが必要に応じて個人カレンダーに登録できます。",
     28 => 'タイトル',
     29 => '日時',
     30 => '日時',
@@ -82,14 +82,14 @@ $LANG_CAL_1 = array(
     38 => 'イベントの種類を編集',
     39 => '場所',
     40 => 'イベントを登録:',
-    41 => '全体カレンダ',
-    42 => '個人カレンダ',
+    41 => '全体カレンダー',
+    42 => '個人カレンダー',
     43 => 'リンク',
     44 => 'HTMLタグは使用できません',
     45 => '投稿',
     46 => 'イベント数',
-    47 => 'イベント（上位10件）',
-    48 => '閲覧数',
+    47 => 'イベント(上位10件)',
+    48 => '表示回数',
     49 => 'このサイトにはイベントがないか、誰もイベントをクリックしていないかどちらかのようです。',
     50 => 'イベント',
     51 => '削除',
@@ -111,13 +111,13 @@ $LANG_CAL_2 = array(
     8 => '個人イベント登録',
     9 => '%s イベント',
     10 => 'イベント:',
-    11 => '全体カレンダ',
-    12 => '個人カレンダ',
+    11 => '全体カレンダー',
+    12 => '個人カレンダー',
     25 => '戻る:',
     26 => '全日',
     27 => '週',
-    28 => '個人カレンダ:',
-    29 => '全体カレンダ',
+    28 => '個人カレンダー:',
+    29 => '全体カレンダー',
     30 => 'イベントを削除',
     31 => '追加',
     32 => 'イベント',
@@ -125,7 +125,7 @@ $LANG_CAL_2 = array(
     34 => '時間',
     35 => '簡単追加',
     36 => '投稿',
-    37 => 'このサイトでは、個人カレンダは無効です。',
+    37 => 'このサイトでは、個人カレンダーは無効です。',
     38 => '個人イベントの編集',
     39 => '日',
     40 => '週',
@@ -148,13 +148,13 @@ $LANG_CAL_ADMIN = array(
     8 => '詳細',
     9 => '(http://から始めてください)',
     10 => 'イベントの日付・時間、タイトル、詳細を入力してください。',
-    11 => 'カレンダ管理',
+    11 => 'カレンダー管理',
     12 => 'イベントの編集・削除は編集アイコンをクリック、コピーはコピーアイコンをクリックしてください。イベントの作成は上の「新規作成」をクリックしてください。',
     13 => '投稿者',
     14 => '時間',
     15 => '時間',
     16 => '',
-    17 => "管理権限のないイベントを編集しようとしました。この行為は記録されました。<a href=\"{$_CONF['site_admin_url']}/plugins/calendar/index.php\">イベント編集画面</a>に戻ってください。",
+    17 => "管理権限のないイベントを編集しようとしました。このアクセスを記録しました。<a href=\"{$_CONF['site_admin_url']}/plugins/calendar/index.php\">イベント編集画面</a>に戻ってください。",
     18 => '',
     19 => '',
     20 => '保存',
@@ -168,44 +168,44 @@ $LANG_CAL_ADMIN = array(
     28 => ' ヶ月以上前のイベントです。 これらを削除する場合はゴミ箱アイコンをクリックしてください。または、異なる期間を選択してください:<br' . XHTML . '> ',
     29 => ' ヶ月以上前のイベントを検索します。',
     30 => 'リストの更新',
-    31 => '選択したユーザを本当に削除してもよろしいですか?',
-    32 => '全てのリスト',
-    33 => '削除対象のイベントが選択されていません。',
+    31 => '選択したユーザーを本当に削除してもよろしいですか?',
+    32 => 'すべてのリスト',
+    33 => '削除対象のイベントを選択していません。',
     34 => 'イベント ID',
     35 => '削除できませんでした。',
     36 => '削除したイベント'
 );
 
 $LANG_CAL_MESSAGE = array(
-    'save' => 'イベントが保存されました。',
-    'delete' => 'イベントが削除されました。',
-    'private' => 'イベントが個人カレンダに保存されました。',
-    'login' => '個人カレンダを開くには、最初にログインしてください。',
-    'removed' => '個人カレンダからイベントが削除されました。',
-    'noprivate' => '申し訳ありませんが、このサイトでは、個人カレンダが無効です。',
-    'unauth' => '申し訳ありませんが、イベント管理ページにアクセスする権限がありません。このアクセスは記録させていただきましたのでご了承ください。'
+    'save' => 'イベントを保存しました。',
+    'delete' => 'イベントを削除しました。',
+    'private' => 'イベントを個人カレンダーに保存しました。',
+    'login' => '個人カレンダーを開くには、最初にログインしてください。',
+    'removed' => '個人カレンダーからイベントを削除しました。',
+    'noprivate' => 'このサイトでは、個人カレンダーは無効です。',
+    'unauth' => 'イベント管理ページにアクセスする権限がありません。すべての許可していない機能へのアクセスは記録していることに注意してください。'
 );
 
-$PLG_calendar_MESSAGE4 = "{$_CONF['site_name']}にイベントを投稿していただき、ありがとうございます。スタッフに送信され、承認待ちの状態になりました。承認された場合、このサイトの<a href=\"{$_CONF['site_url']}/calendar/index.php\">カレンダ</a>セクションに表示されます。";
-$PLG_calendar_MESSAGE17 = 'イベントが保存されました。';
-$PLG_calendar_MESSAGE18 = 'イベントが削除されました。';
-$PLG_calendar_MESSAGE24 = 'イベントが個人カレンダに保存されました。';
-$PLG_calendar_MESSAGE26 = 'イベントが削除されました。';
+$PLG_calendar_MESSAGE4 = "{$_CONF['site_name']}にイベントを投稿していただき、ありがとうございます。イベントはスタッフによる承認待ちとなっています。承認が済むと、このサイトの<a href=\"{$_CONF['site_url']}/calendar/index.php\">カレンダー</a>セクションにイベントを表示します。";
+$PLG_calendar_MESSAGE17 = 'イベントを保存しました。';
+$PLG_calendar_MESSAGE18 = 'イベントを削除しました。';
+$PLG_calendar_MESSAGE24 = 'イベントを個人カレンダーに保存しました。';
+$PLG_calendar_MESSAGE26 = 'イベントを削除しました。';
 
 // Messages for the plugin upgrade
-$PLG_calendar_MESSAGE3001 = 'プラグインのアップグレードはサポートされていません。';
+$PLG_calendar_MESSAGE3001 = 'プラグインはアップグレードをサポートしていません。';
 $PLG_calendar_MESSAGE3002 = $LANG32[9];
 
 // Localization of the Admin Configuration UI
 $LANG_configsections['calendar'] = array(
-    'label' => 'カレンダ',
-    'title' => 'カレンダの設定'
+    'label' => 'カレンダー',
+    'title' => 'カレンダーの設定'
 );
 
 $LANG_confignames['calendar'] = array(
     'calendarloginrequired' => 'ログインを要求する',
     'hidecalendarmenu' => 'メニューに表示しない',
-    'personalcalendars' => '個人カレンダを有効にする',
+    'personalcalendars' => '個人カレンダーを有効にする',
     'eventsubmission' => 'イベント投稿を管理者が承認する',
     'showupcomingevents' => 'イベント予告を表示する',
     'upcomingeventsrange' => 'イベント予告を表示する期間',
@@ -215,7 +215,14 @@ $LANG_confignames['calendar'] = array(
     'delete_event' => '所有者の削除と共に削除する',
     'aftersave' => 'イベント保存後の画面遷移',
     'default_permissions' => 'パーミッション',
-    'autotag_permissions_event' => '[event: ] パーミッション'
+    'autotag_permissions_event' => '[event: ] パーミッション',
+    'block_enable' => '有効',
+    'block_isleft' => '左ブロックで表示する',
+    'block_order' => 'ブロックの順番',
+    'block_topic_option' => '話題オプション',
+    'block_topic' => '話題',
+    'block_group_id' => 'グループ',
+    'block_permissions' => 'パーミッション'
 );
 
 $LANG_configsubgroups['calendar'] = array(
@@ -223,15 +230,18 @@ $LANG_configsubgroups['calendar'] = array(
 );
 
 $LANG_tab['calendar'] = array(
-    'tab_main' => 'カレンダのメイン設定',
+    'tab_main' => 'カレンダーのメイン設定',
     'tab_permissions' => 'パーミッションのデフォルト',
-    'tab_autotag_permissions' => '自動タグのパーミッション'
+    'tab_autotag_permissions' => '自動タグのパーミッション',
+    'tab_events_block' => 'イベントブロック'
 );
 
 $LANG_fs['calendar'] = array(
-    'fs_main' => 'カレンダのメイン設定',
-    'fs_permissions' => 'カレンダのパーミッションのデフォルト（[0]所有者 [1]グループ [2]メンバー [3]ゲスト）',
-    'fs_autotag_permissions' => '自動タグのパーミッション'
+    'fs_main' => 'カレンダーのメイン設定',
+    'fs_permissions' => 'カレンダーのパーミッションのデフォルト([0]所有者 [1]グループ [2]メンバー [3]ゲスト)',
+    'fs_autotag_permissions' => '自動タグのパーミッション',
+    'fs_block_settings' => 'ブロック設定',
+    'fs_block_permissions' => 'ブロックのパーミッション'
 );
 
 // Note: entries 0, 1, 6, 9, 12 are the same as in $LANG_configselects['Core']
@@ -239,9 +249,11 @@ $LANG_configselects['calendar'] = array(
     0 => array('はい' => 1, 'いいえ' => 0),
     1 => array('はい' => true, 'いいえ' => false),
     6 => array('12' => 12, '24' => 24),
-    9 => array('ページを表示する' => 'item', 'リストを表示する' => 'list', 'プラグイントップを表示する' => 'plugin', 'ホームを表示する' => 'home', '管理画面トップを表示する' => 'admin'),
+    9 => array('ページを表示' => 'item', 'リストを表示' => 'list', 'プラグイントップを表示' => 'plugin', 'ホームを表示' => 'home', '管理画面のトップを表示' => 'admin'),
     12 => array('アクセス不可' => 0, '表示' => 2, '表示・編集' => 3),
-    13 => array('アクセス不可' => 0, '利用する' => 2)
+    13 => array('アクセス不可' => 0, '利用する' => 2),
+    14 => array('アクセス不可' => 0, '表示' => 2),
+    15 => array('すべて' => TOPIC_ALL_OPTION, 'ホームページのみ' => TOPIC_HOMEONLY_OPTION, '話題を選択する' => TOPIC_SELECTED_OPTION)
 );
 
 ?>
