@@ -6,7 +6,7 @@
 // +---------------------------------------------------------------------------+
 // | Upgrade SQL                                                               |
 // +---------------------------------------------------------------------------+
-// | Copyright (C) 2008-2009 by dengen - taharaxp AT gmail DOT com             |
+// | Copyright (C) 2008-2012 by dengen - taharaxp AT gmail DOT com             |
 // |                                                                           |
 // | Calendarjp plugin is based on prior work by:                              |
 // | Authors: Tony Bibbs        - tony AT tonybibbs DOT com                    |
@@ -44,13 +44,22 @@ $_UPDATES = array(
     ),
 
     '1.1.4' => array(
-        // Set new Tab column to whatever fieldset is
-        "UPDATE {$_TABLES['conf_values']} SET tab = fieldset WHERE group_name = 'calendarjp'", 
         "INSERT INTO {$_TABLES['features']} (ft_name, ft_descr, ft_gl_core) VALUES ('config.calendarjp.tab_main', 'Access to configure general calendar settings', 0)",
         "INSERT INTO {$_TABLES['features']} (ft_name, ft_descr, ft_gl_core) VALUES ('config.calendarjp.tab_permissions', 'Access to configure event default permissions', 0)",
         "INSERT INTO {$_TABLES['features']} (ft_name, ft_descr, ft_gl_core) VALUES ('config.calendarjp.tab_autotag_permissions', 'Access to configure event autotag usage permissions', 0)"        
-    )
+    ),     
+
+    '1.1.5' => array(
+        // Delete Events block since moved to dynamic
+        "DELETE FROM {$_TABLES['blocks']} WHERE phpblockfn = 'phpblock_calendarjp'", 
+        "INSERT INTO {$_TABLES['features']} (ft_name, ft_descr, ft_gl_core) VALUES ('config.calendarjp.tab_events_block', 'Access to configure events block', 0)"
+    ),
     
+    '1.1.6' => array(
+        "ALTER TABLE {$_TABLES['eventsjp']} CHANGE zipcode zipcode varchar(16) default NULL",
+        "ALTER TABLE {$_TABLES['eventsubmissionjp']} CHANGE zipcode zipcode varchar(16) default NULL",
+        "ALTER TABLE {$_TABLES['personal_eventsjp']} CHANGE zipcode zipcode varchar(16) default NULL",
+    ),
 );
 
 /**
@@ -81,4 +90,33 @@ function calendarjp_update_ConfigSecurity_1_1_4()
 
 }
 
+/**
+ * Add in new security rights for the Group "Calendarjp Admin"
+ *
+ */
+function calendarjp_update_ConfigSecurity_1_1_5()
+{
+    global $_TABLES;
+    
+    // Add in security rights for Calendarjp Admin
+    $group_id = DB_getItem($_TABLES['groups'], 'grp_id',
+                            "grp_name = 'Calendarjp Admin'");
+
+    if ($group_id > 0) {
+        $ft_id = DB_getItem($_TABLES['features'], 'ft_id', "ft_name = 'config.calendarjp.tab_events_block'");   
+        $sql = "INSERT INTO {$_TABLES['access']} (acc_ft_id, acc_grp_id) VALUES ($ft_id, $group_id)";
+        DB_query($sql);    
+    }    
+
+}
+
+/**
+ * Modify zipcode field
+ *
+ */
+function calendarjp_update_Zipcode_1_1_5()
+{
+    // Nothing to do
+}
+
 ?>
