@@ -38,6 +38,7 @@ global $LANG32;
 
 $LANG_POLLS = array(
     'polls' => 'Ksitlused',
+    'poll' => 'Poll',
     'results' => 'Tulemused',
     'pollresults' => 'Hletuste tulemused',
     'votes' => 'Hletust',
@@ -146,7 +147,14 @@ $LANG_confignames['polls'] = array(
     'newpollsinterval' => 'New Polls Interval',
     'hidenewpolls' => 'New Polls',
     'title_trim_length' => 'Title Trim Length',
-    'meta_tags' => 'Luba Meta sildid'
+    'meta_tags' => 'Luba Meta sildid',
+    'block_enable' => 'Enabled',
+    'block_isleft' => 'Display Block on Left',
+    'block_order' => 'Block Order',
+    'block_topic_option' => 'Topic Options',
+    'block_topic' => 'Topic',
+    'block_group_id' => 'Group',
+    'block_permissions' => 'Permissions'
 );
 
 $LANG_configsubgroups['polls'] = array(
@@ -157,14 +165,17 @@ $LANG_tab['polls'] = array(
     'tab_main' => 'General Polls Settings',
     'tab_whatsnew' => 'What\'s New Block',
     'tab_permissions' => 'Default Permissions',
-    'tab_autotag_permissions' => 'Autotag Usage Permissions'
+    'tab_autotag_permissions' => 'Autotag Usage Permissions',
+    'tab_poll_block' => 'Poll Block'
 );
 
 $LANG_fs['polls'] = array(
     'fs_main' => 'Ksitluste ldised hlestused',
     'fs_whatsnew' => 'What\'s New Block',
     'fs_permissions' => 'Vaikimisi igused',
-    'fs_autotag_permissions' => 'Autotag Usage Permissions'
+    'fs_autotag_permissions' => 'Autotag Usage Permissions',
+    'fs_block_settings' => 'Block Settings',
+    'fs_block_permissions' => 'Block Permissions'
 );
 
 // Note: entries 0, 1, and 12 are the same as in $LANG_configselects['Core']
@@ -175,7 +186,9 @@ $LANG_configselects['polls'] = array(
     5 => array('Hide' => 'hide', 'Show - Use Modified Date' => 'modified', 'Show - Use Created Date' => 'created'),
     9 => array('Suuna ksitluste juurde' => 'item', 'Nita administreerimisloetelu' => 'list', 'Nita avalikku loetelu' => 'plugin', 'Nita avalehte' => 'home', 'Nita administreerimislehte' => 'admin'),
     12 => array('Pole ligipsu' => 0, 'Ainult loetav' => 2, 'Loetav ja muudetav' => 3),
-    13 => array('No access' => 0, 'Use' => 2)
+    13 => array('No access' => 0, 'Use' => 2),
+    14 => array('No access' => 0, 'Read-Only' => 2),
+    15 => array('All' => TOPIC_ALL_OPTION, 'Homepage Only' => TOPIC_HOMEONLY_OPTION, 'Select Topics' => TOPIC_SELECTED_OPTION)
 );
 
 ?>
