@@ -9,10 +9,11 @@
 *
 * Licensed under the GNU General Public License
 *
-* $Id: SLVreport.Action.class.php,v 1.2 2008/09/21 08:37:08 dhaun Exp $
+* @package Spam-X
+* @subpackage Modules
 */
 
-if (strpos(strtolower($_SERVER['PHP_SELF']), 'SLVreport.Action.class.php') !== false) {
+if (strpos(strtolower($_SERVER['PHP_SELF']), 'slvreport.action.class.php') !== false) {
     die('This file can not be used on its own!');
 }
 
@@ -31,41 +32,33 @@ require_once $_CONF['path'] . 'plugins/spamx/' . 'SLVbase.class.php';
 * this class ensures that SLV sees spam detected by other Spam-X modules, too.
 *
 * @author Dirk Haun     dirk AT haun-online DOT de
-*
 * based on the works of Tom Willet (Spam-X) and Russ Jones (SLV)
+* @package Spam-X
+*
 */
-class SLVreport extends BaseCommand {
-    /**
-     * Constructor
-     * Numbers are always binary digits and added together to make call
-     */
-    function SLVreport()
+class SLVreport extends BaseCommand
+{
+    public function __construct()
     {
-        global $num;
-
-        // Actually, this is the code used by the DeleteComment class.
-        // We're piggybacking on the delete operation here.
-        $num = 128;
+        $this->actionCode = PLG_SPAM_ACTION_DELETE;
     }
 
     /**
      * Here we do the work
      */
-    function execute ($comment)
+    public function execute($comment)
     {
-        global $result;
+        $this->result = PLG_SPAM_ACTION_DELETE;
 
-        $result = 128;
-
-        if (isset ($GLOBALS['slv_triggered']) && $GLOBALS['slv_triggered']) {
+        if (isset($GLOBALS['slv_triggered']) && $GLOBALS['slv_triggered']) {
             // the Examine class already reported these to SLV
-            return 1;
+            return PLG_SPAM_FOUND;
         }
 
         $slv = new SLVbase();
-        $slv->CheckForSpam ($comment);
+        $slv->CheckForSpam($comment);
 
-        return 1;
+        return PLG_SPAM_FOUND;
     }
 }
 
