@@ -51,6 +51,7 @@ $LANG_SX00 = array(
     'e1' => 'Kande kustutamiseks klõpsa sellel',
     'e2' => 'Kande lisamiseks kirjuta uus kanne kirjutamisväljale ja klõpsa Lisa nuppu. Kannetes saab kasutada täiemahulisi Perli regulaaravaldisi.',
     'pblack' => 'Spam-X isikli blacklist',
+    'sfseblack' => 'Spam-X SFS Email Blacklist',
     'conmod' => 'Häälesta Spam-X Mooduli kasutamist',
     'acmod' => 'Spam-X toimingute  Moodulid',
     'exmod' => 'Spam-X kontrollimoodulid',
@@ -71,6 +72,7 @@ $LANG_SX00 = array(
     'clearlog' => 'Tühjenda Logifail',
     'logcleared' => '- Spam-X Logifail tühjendatud',
     'plugin' => 'Plugin',
+    'action' => 'Action',
     'access_denied' => 'Ligipääs tõkestatud',
     'access_denied_msg' => 'Ainult root kasutajatel on  ligipääs sellele lehele.  Sinu kasutajanimi ja IP on salvestatud',
     'admin' => 'Plugina administreerimine',
@@ -113,6 +115,10 @@ $LANG_SX00 = array(
     'ipofurlblack' => 'Spam-X IP of URL Blacklist',
     'headerblack' => 'Spam-X HTTP päiste blacklist',
     'headers' => 'Päringute päised:',
+    'edit' => 'Edit',
+    'view' => 'View',
+    'value' => 'Value',
+    'counter' => 'Counter',
     'stats_headline' => 'Spam-X Statistika',
     'stats_page_title' => 'Blacklist',
     'stats_entries' => 'Kanded',
@@ -122,6 +128,16 @@ $LANG_SX00 = array(
     'stats_ipofurl' => 'Blocked by IP of URL',
     'stats_header' => 'HTTP päised',
     'stats_deleted' => 'Spammina kustutatud postitused',
+    'invalid_email_or_ip' => 'Invalid e-mail address or IP address has been blocked.',
+    'email_ip_spam' => '%s or %s attempted to register but was considered a spammer.',
+    'edit_personal_blacklist' => 'Edit Personal Blacklist',
+    'mass_delete_spam_comments' => 'Mass Delete Spam Comments',
+    'mass_delete_trackback_spam' => 'Mass Delete Trackback Spam',
+    'edit_http_header_blacklist' => 'Edit HTTP Header Blacklist',
+    'edit_ip_blacklist' => 'Edit IP Blacklist',
+    'edit_ip_url_blacklist' => 'Edit IP of URL Blacklist',
+    'edit_sfs_blacklist' => 'Edit SFS Email Blacklist',
+    'edit_slv_whitelist' => 'Edit SLV Whitelist',
     'plugin_name' => 'Spam-X',
     'slvwhitelist' => 'SLV Whitelist'
 );
@@ -144,7 +160,13 @@ $LANG_confignames['spamx'] = array(
     'spamx_action' => 'Spam-X Actions',
     'notification_email' => 'Teavituskiri',
     'logging' => 'Luba logimine',
-    'timeout' => 'Ajapiir'
+    'timeout' => 'Ajapiir',
+    'max_age' => 'Max Age of Records',
+    'records_delete' => 'Record Types to Delete',
+    'sfs_enabled' => 'Enable SFS',
+    'sfs_confidence' => 'Confidence Threshold',
+    'snl_enabled' => 'Enable SNL',
+    'snl_num_links' => 'Number of links'
 );
 
 $LANG_configsubgroups['spamx'] = array(
@@ -152,11 +174,14 @@ $LANG_configsubgroups['spamx'] = array(
 );
 
 $LANG_tab['spamx'] = array(
-    'tab_main' => 'Spam-X Main Settings'
+    'tab_main' => 'Spam-X Main Settings',
+    'tab_modules' => 'Modules'
 );
 
 $LANG_fs['spamx'] = array(
-    'fs_main' => 'Spam-X peahäälestused'
+    'fs_main' => 'Spam-X peahäälestused',
+    'fs_sfs' => 'Stop Forum Spam (SFS)',
+    'fs_snl' => 'Spam Number of Links (SNL)'
 );
 
 // Note: entries 0, 1, 9, and 12 are the same as in $LANG_configselects['Core']
