@@ -73,6 +73,7 @@ $LANG_SX00 = array(
     'clearlog' => 'Vider fichier ',
     'logcleared' => '- fichier log Spam-X vide',
     'plugin' => 'Plugin',
+    'action' => 'Action',
     'access_denied' => 'Accs refus',
     'access_denied_msg' => 'Seulement les utilisateurs Root ont accs  cette page.  Votre code d\'usager et votre adresse IP ont t enregistrs.',
     'admin' => 'Administration Plugin',
@@ -115,6 +116,10 @@ $LANG_SX00 = array(
     'ipofurlblack' => 'Spam-X IP of URL Blacklist',
     'headerblack' => 'Spam-X HTTP Header Blacklist',
     'headers' => 'Request headers:',
+    'edit' => 'Edit',
+    'view' => 'View',
+    'value' => 'Value',
+    'counter' => 'Counter',
     'stats_headline' => 'Spam-X Statistics',
     'stats_page_title' => 'Blacklist',
     'stats_entries' => 'Entries',
@@ -157,7 +162,10 @@ $LANG_confignames['spamx'] = array(
     'notification_email' => 'Notification Email',
     'logging' => 'Enable Logging',
     'timeout' => 'Timeout',
+    'max_age' => 'Max Age of Records',
+    'records_delete' => 'Record Types to Delete',
     'sfs_enabled' => 'Enable SFS',
+    'sfs_confidence' => 'Confidence Threshold',
     'snl_enabled' => 'Enable SNL',
     'snl_num_links' => 'Number of links'
 );
