@@ -3,9 +3,9 @@
 /**
 * File: hebrew_utf-8.php
  * This is the Hebrew language file for the Geeklog Spam-X plugin
-* Copyright (C) 2009
+* Copyright (C) 2013
  * http://lior.weissbrod.com
- * Version 1.6#1
+ * Version 2.0.0#2
  * 
  * Licensed under GNU General Public License
  *
@@ -50,6 +50,7 @@ $LANG_SX00 = array(
     'e1' => 'כדי למחוק פריט, ליחצו עליו.',
     'e2' => 'כדי להוסיף פריט, הכניסו אותו לתיבה וליחצו על הוספה.  הפריטים יכולים להשתמש באופן מלא ב-Regular Expressions של Perl.',
     'pblack' => 'הרשימה השחורה האישית של Spam-X',
+    'sfseblack' => 'רשימות שחורות של אימייל SFS של Spam-X',
     'conmod' => 'כוונו את מודול השימוש של Spam-X',
     'acmod' => 'מודולי הפעולה של Spam-X',
     'exmod' => 'מודולי הבחינה של Spam-X',
@@ -70,6 +71,7 @@ $LANG_SX00 = array(
     'clearlog' => 'נקו את קובץ היומן',
     'logcleared' => '- קובץ היומן של Spam-X נוקה',
     'plugin' => 'Plugin',
+    'action' => 'Action',
     'access_denied' => 'הגישה לא אושרה',
     'access_denied_msg' => 'רק מנהלים יכולים לגשת לעמוד זה.  שם המשתמש שלך וכתובת ה-IP תועדו.',
     'admin' => 'ניהול ה-Plugin',
@@ -112,6 +114,10 @@ $LANG_SX00 = array(
     'ipofurlblack' => 'הרשימה השחורה של כתובות ה-IP של כתובות אתרים של Spam-X',
     'headerblack' => 'הרשימה השחורה של HTTP Headers של Spam-X',
     'headers' => 'Request headers:',
+    'edit' => 'Edit',
+    'view' => 'View',
+    'value' => 'Value',
+    'counter' => 'Counter',
     'stats_headline' => 'הסטטיסטיקה של Spam-X',
     'stats_page_title' => 'רשימה שחורה',
     'stats_entries' => 'פריטים',
@@ -121,8 +127,18 @@ $LANG_SX00 = array(
     'stats_ipofurl' => 'נחסם על ידי כתובת ה-IP של כתובת אתר',
     'stats_header' => 'HTTP headers',
     'stats_deleted' => 'פריטים שנמחקו כספאם',
+    'invalid_email_or_ip' => 'כתובת אימייל או IP נחסמו.',
+    'email_ip_spam' => '%s או %s ניסו להירשם אבל נחשבו כספאם.',
+    'edit_personal_blacklist' => 'עריכת רשימה שחורה אישית',
+    'mass_delete_spam_comments' => 'מחיקה המונית של תגובות ספאם',
+    'mass_delete_trackback_spam' => 'מחיקה המונית של ספאם trackback',
+    'edit_http_header_blacklist' => 'עריכת רשימה שחורה של HTTP Header',
+    'edit_ip_blacklist' => 'עריכת רשימה שחורה של IP',
+    'edit_ip_url_blacklist' => 'עריכת IP של רשימה שחורה של כתובות אתרי אינטרנט',
+    'edit_sfs_blacklist' => 'עריכת רשימה שחורה של אימייל SFS',
+    'edit_slv_whitelist' => 'עריכת רשימה לבנה של SLV',
     'plugin_name' => 'Spam-X',
-    'slvwhitelist' => 'SLV Whitelist'
+    'slvwhitelist' => 'רשימה לבנה של SLV'
 );
 
 // Define Messages that are shown when Spam-X module action is taken
@@ -140,10 +156,16 @@ $LANG_configsections['spamx'] = array(
 );
 
 $LANG_confignames['spamx'] = array(
-    'spamx_action' => 'Spam-X Actions',
+    'spamx_action' => 'פעולות Spam-X',
     'notification_email' => 'התרעה בהודעת אימייל',
     'logging' => 'איפשור לוג',
-    'timeout' => 'פקיעת זמן מוקצב'
+    'timeout' => 'פקיעת זמן מוקצב',
+    'max_age' => 'Max Age of Records',
+    'records_delete' => 'Record Types to Delete',
+    'sfs_enabled' => 'איפשור SFS',
+    'sfs_confidence' => 'Confidence Threshold',
+    'snl_enabled' => 'איפשור SNL',
+    'snl_num_links' => 'מספר הקישורים'
 );
 
 $LANG_configsubgroups['spamx'] = array(
@@ -151,11 +173,14 @@ $LANG_configsubgroups['spamx'] = array(
 );
 
 $LANG_tab['spamx'] = array(
-    'tab_main' => 'Spam-X Main Settings'
+    'tab_main' => 'הגדרות Spam-X כלליות',
+    'tab_modules' => 'מודולים'
 );
 
 $LANG_fs['spamx'] = array(
-    'fs_main' => 'ההגדרות הראשיות של Spam-X'
+    'fs_main' => 'ההגדרות הראשיות של Spam-X',
+    'fs_sfs' => 'הפסיקו פורום ספאם (SFS)',
+    'fs_snl' => 'ספאם מספר קישורים (SNL)'
 );
 
 // Note: entries 0, 1, 9, and 12 are the same as in $LANG_configselects['Core']
