@@ -85,6 +85,7 @@ $LANG_SX00 = array(
     'clearlog' => 'Cancella File di Log',
     'logcleared' => '- File di Log di Spam-X Cancellato',
     'plugin' => 'Estensione',
+    'action' => 'Action',
     'access_denied' => 'Accesso Negato',
     'access_denied_msg' => 'Solo gli Utenti Root possono Accedere a questa Pagina. Il Tuo nome utente ed IP sono stati registrati.',
     'admin' => 'Amministrazione dell\'Estensione',
@@ -127,6 +128,10 @@ $LANG_SX00 = array(
     'ipofurlblack' => 'Blacklist degli IP di indirizzi',
     'headerblack' => 'Blacklist degli header HTTP',
     'headers' => 'Headers delle Richieste:',
+    'edit' => 'Edit',
+    'view' => 'View',
+    'value' => 'Value',
+    'counter' => 'Counter',
     'stats_headline' => 'Statistiche di Spam-X',
     'stats_page_title' => 'Blacklist',
     'stats_entries' => 'Totale',
@@ -169,7 +174,10 @@ $LANG_confignames['spamx'] = array(
     'notification_email' => 'Notifica via Email',
     'logging' => 'Registrazione dell\'utilizzo e degli errori abilitata',
     'timeout' => 'Timeout',
+    'max_age' => 'Max Age of Records',
+    'records_delete' => 'Record Types to Delete',
     'sfs_enabled' => 'Enable SFS',
+    'sfs_confidence' => 'Confidence Threshold',
     'snl_enabled' => 'Enable SNL',
     'snl_num_links' => 'Number of links'
 );
