@@ -50,6 +50,7 @@ $LANG_SX00 = array(
     'e1' => '  , Φ .',
     'e2' => '  , Ħ   ̦  Φ .     Ӧ Φ  Perl (Perl Regular Expressions).',
     'pblack' => '   Spam-X',
+    'sfseblack' => 'Spam-X SFS Email Blacklist',
     'conmod' => '   Spam-X',
     'acmod' => '̦ Ħ Spam-X',
     'exmod' => '̦ ̦ Spam-X',
@@ -70,6 +71,7 @@ $LANG_SX00 = array(
     'clearlog' => ' ',
     'logcleared' => '- - Spam-X ',
     'plugin' => '',
+    'action' => 'Action',
     'access_denied' => ' ',
     'access_denied_msg' => ' צ ަ    æ Ҧ.   Ǧ  IP- .',
     'admin' => 'ͦΦ ̦',
@@ -112,6 +114,10 @@ $LANG_SX00 = array(
     'ipofurlblack' => '  IP  URL Spam-X',
     'headerblack' => '  HTTP-˦ Spam-X',
     'headers' => ' :',
+    'edit' => 'Edit',
+    'view' => 'View',
+    'value' => 'Value',
+    'counter' => 'Counter',
     'stats_headline' => ' Spam-X',
     'stats_page_title' => ' ',
     'stats_entries' => '',
@@ -121,6 +127,16 @@ $LANG_SX00 = array(
     'stats_ipofurl' => '  IP  URL',
     'stats_header' => 'HTTP-',
     'stats_deleted' => ', Φ  ',
+    'invalid_email_or_ip' => 'Invalid e-mail address or IP address has been blocked.',
+    'email_ip_spam' => '%s or %s attempted to register but was considered a spammer.',
+    'edit_personal_blacklist' => 'Edit Personal Blacklist',
+    'mass_delete_spam_comments' => 'Mass Delete Spam Comments',
+    'mass_delete_trackback_spam' => 'Mass Delete Trackback Spam',
+    'edit_http_header_blacklist' => 'Edit HTTP Header Blacklist',
+    'edit_ip_blacklist' => 'Edit IP Blacklist',
+    'edit_ip_url_blacklist' => 'Edit IP of URL Blacklist',
+    'edit_sfs_blacklist' => 'Edit SFS Email Blacklist',
+    'edit_slv_whitelist' => 'Edit SLV Whitelist',
     'plugin_name' => 'Spam-X',
     'slvwhitelist' => '  SLV'
 );
@@ -143,7 +159,13 @@ $LANG_confignames['spamx'] = array(
     'spamx_action' => 'Spam-X Actions',
     'notification_email' => 'Notification Email',
     'logging' => 'Enable Logging',
-    'timeout' => 'Timeout'
+    'timeout' => 'Timeout',
+    'max_age' => 'Max Age of Records',
+    'records_delete' => 'Record Types to Delete',
+    'sfs_enabled' => 'Enable SFS',
+    'sfs_confidence' => 'Confidence Threshold',
+    'snl_enabled' => 'Enable SNL',
+    'snl_num_links' => 'Number of links'
 );
 
 $LANG_configsubgroups['spamx'] = array(
@@ -151,11 +173,14 @@ $LANG_configsubgroups['spamx'] = array(
 );
 
 $LANG_tab['spamx'] = array(
-    'tab_main' => 'Spam-X Main Settings'
+    'tab_main' => 'Spam-X Main Settings',
+    'tab_modules' => 'Modules'
 );
 
 $LANG_fs['spamx'] = array(
-    'fs_main' => 'Spam-X Main Settings'
+    'fs_main' => 'Spam-X Main Settings',
+    'fs_sfs' => 'Stop Forum Spam (SFS)',
+    'fs_snl' => 'Spam Number of Links (SNL)'
 );
 
 // Note: entries 0, 1, 9, and 12 are the same as in $LANG_configselects['Core']
