@@ -38,15 +38,19 @@ $_UPDATES = array(
         "INSERT INTO {$_TABLES['features']} (ft_name, ft_descr) VALUES ('spamx.skip', 'Skip checking posts for Spam')",
         "UPDATE {$_TABLES['plugins']} SET pi_homepage = 'http://www.geeklog.net/' WHERE pi_name = 'spamx'"
     ),
-    
+
     '1.2.1' => array(
         "INSERT INTO {$_TABLES['features']} (ft_name, ft_descr, ft_gl_core) VALUES ('config.spamx.tab_main', 'Access to configure Spam-x main settings', 0)" 
     ),
 
     '1.2.2' => array(
         "INSERT INTO {$_TABLES['features']} (ft_name, ft_descr, ft_gl_core) VALUES ('config.spamx.tab_modules', 'Access to configure Spam-x modules', 0)" 
-    )    
-    
+    ),
+
+    '1.3.0' => array(
+        "ALTER TABLE {$_TABLES['spamx']} ADD [counter] [int] NOT NULL default (0) AFTER [value]",
+        "ALTER TABLE {$_TABLES['spamx']} ADD [regdate] [datetime] NOT NULL AFTER [counter]"
+    )
 );
 
 /**
@@ -56,16 +60,16 @@ $_UPDATES = array(
 function spamx_update_ConfigSecurity_1_2_1()
 {
     global $_TABLES;
-    
+
     // Add in security rights for Spam-x Admin
     $group_id = DB_getItem($_TABLES['groups'], 'grp_id',
                             "grp_name = 'Spamx Admin'");
 
     if ($group_id > 0) {
         $ft_names[] = 'config.spamx.tab_main';
-        
+
         foreach ($ft_names as $name) {
-            $ft_id = DB_getItem($_TABLES['features'], 'ft_id', "ft_name = '$name'");         
+            $ft_id = DB_getItem($_TABLES['features'], 'ft_id', "ft_name = '$name'");
             if ($ft_id > 0) {
                 $sql = "INSERT INTO {$_TABLES['access']} (acc_ft_id, acc_grp_id) VALUES ($ft_id, $group_id)";
                 DB_query($sql);
@@ -82,22 +86,22 @@ function spamx_update_ConfigSecurity_1_2_1()
 function spamx_update_ConfigSecurity_1_2_2()
 {
     global $_TABLES;
-    
+
     // Add in security rights for Spam-x Admin
     $group_id = DB_getItem($_TABLES['groups'], 'grp_id',
                             "grp_name = 'Spamx Admin'");
 
     if ($group_id > 0) {
         $ft_names[] = 'config.spamx.tab_modules';
-        
+
         foreach ($ft_names as $name) {
-            $ft_id = DB_getItem($_TABLES['features'], 'ft_id', "ft_name = '$name'");         
+            $ft_id = DB_getItem($_TABLES['features'], 'ft_id', "ft_name = '$name'");
             if ($ft_id > 0) {
                 $sql = "INSERT INTO {$_TABLES['access']} (acc_ft_id, acc_grp_id) VALUES ($ft_id, $group_id)";
                 DB_query($sql);
             }
-        }        
-    }    
+        }
+    }
 
 }
 
