@@ -64,7 +64,7 @@ $LANG_STATIC = array(
     'all_html_allowed' => 'All HTML is allowed',
     'results' => 'Static Pages Results',
     'author' => 'Author',
-    'no_title_or_content' => 'You must at least fill in the <b>Title</b> and <b>Content</b> fields.',
+    'no_title_or_content' => 'You must at least fill in the <b>Title</b> and <b>Content</b> fields as well as make a <b>Topic</b> selection.',
     'no_such_page_anon' => 'Please log in..',
     'no_page_access_msg' => "This could be because you're not logged in, or not a member of {$_CONF['site_name']}. Please <a href=\"{$_CONF['site_url']}/users.php?mode=new\"> become a member</a> of {$_CONF['site_name']} to receive full membership access",
     'php_msg' => 'PHP: ',
@@ -80,8 +80,8 @@ $LANG_STATIC = array(
     'duplicate_id' => 'The ID you chose for this static page is already in use. Please select another ID.',
     'instructions' => 'To modify or delete a static page, click on that page\'s edit icon below. To view a static page, click on the title of the page you wish to view. To create a new static page, click on "Create New" above. Click on on the copy icon to create a copy of an existing page.',
     'centerblock' => 'Centerblock: ',
-    'centerblock_msg' => 'When checked, this Static Page will be displayed as a center block on the index page.',
-    'topic' => 'Topic: ',
+    'centerblock_msg' => 'When checked, this Static Page will be displayed as a center block on the index page of the topics it is assigned to.',
+    'topic' => 'Topic',
     'position' => 'Position: ',
     'all_topics' => 'All',
     'no_topic' => 'Homepage Only',
@@ -105,7 +105,6 @@ $LANG_STATIC = array(
     'select_php_free' => 'execute PHP',
     'php_not_activated' => 'The use of PHP in static pages is not activated. Please see the <a href="' . $_CONF['site_url'] . '/docs/english/staticpages.html#php">documentation</a> for details.',
     'printable_format' => 'Printable Format',
-    'edit' => 'Edit',
     'copy' => 'Copy',
     'limit_results' => 'Limit Results',
     'search' => 'Search',
@@ -120,7 +119,11 @@ $LANG_STATIC = array(
     'use_template_msg' => 'If this Static Page is not a template, you can assign it to use a template. If a selection is made then remember that the content of this page must follow the proper XML format.',
     'draft' => 'Draft',
     'draft_yes' => 'Yes',
-    'draft_no' => 'No'
+    'draft_no' => 'No',
+    'cache_time'        => 'Cache Time',
+    'cache_time_desc'   => 'This staticpage content will be cached for no longer than this many seconds. If 0 caching is disabled. If -1 cached until page is edited again. Staticpages with PHP enabled or are a template will not be cached. (3600 = 1 hour,  86400 = 1 day)',
+    'autotag_desc_staticpage' => '[staticpage: id alternate title] - Displays a link to a static page using the static page title as the title. An alternate title may be specified but is not required.',
+    'autotag_desc_staticpage_content' => '[staticpage_content: id] - Displays the contents of a staticpage.'
 );
 
 $PLG_staticpages_MESSAGE15 = 'Your comment has been submitted for review and will be published when approved by a moderator.';
@@ -151,11 +154,15 @@ $LANG_confignames['staticpages'] = array(
     'filter_html' => 'Filter HTML?',
     'censor' => 'Censor Content?',
     'default_permissions' => 'Page Default Permissions',
+    'autotag_permissions_staticpage' => '[staticpage: ] Permissions', 
+    'autotag_permissions_staticpage_content' => '[staticpage_content: ] Permissions', 
     'aftersave' => 'After Saving Page',
     'atom_max_items' => 'Max. Pages in Webservices Feed',
     'meta_tags' => 'Enable Meta Tags',
     'comment_code' => 'Comment Default',
     'draft_flag' => 'Draft Flag Default',
+    'disable_breadcrumbs_staticpages' => 'Disable Breadcrumbs',
+    'default_cache_time' => 'Default Cache Time',
     'newstaticpagesinterval' => 'New Static Page Interval',
     'hidenewstaticpages' => 'New Static Pages',
     'title_trim_length' => 'Title Trim Length',
@@ -170,11 +177,20 @@ $LANG_configsubgroups['staticpages'] = array(
     'sg_main' => 'Main Settings'
 );
 
+$LANG_tab['staticpages'] = array(
+    'tab_main' => 'Static Pages Main Settings',
+    'tab_whatsnew' => 'What\'s New Block',
+    'tab_search' => 'Search Results',
+    'tab_permissions' => 'Default Permissions', 
+    'tab_autotag_permissions' => 'Autotag Usage Permissions'     
+);
+
 $LANG_fs['staticpages'] = array(
     'fs_main' => 'Static Pages Main Settings',
     'fs_whatsnew' => 'What\'s New Block',
     'fs_search' => 'Search Results',
-    'fs_permissions' => 'Default Permissions'
+    'fs_permissions' => 'Default Permissions', 
+    'fs_autotag_permissions' => 'Autotag Usage Permissions'      
 );
 
 // Note: entries 0, 1, 9, 12, 17 are the same as in $LANG_configselects['Core']
@@ -187,6 +203,7 @@ $LANG_configselects['staticpages'] = array(
     5 => array('Hide' => 'hide', 'Show - Use Modified Date' => 'modified', 'Show - Use Created Date' => 'created'),
     9 => array('Forward to page' => 'item', 'Display List' => 'list', 'Display Home' => 'home', 'Display Admin' => 'admin'),
     12 => array('No access' => 0, 'Read-Only' => 2, 'Read-Write' => 3),
+    13 => array('No access' => 0, 'Use' => 2),
     17 => array('Comments Enabled' => 0, 'Comments Disabled' => -1)
 );
 
