@@ -8,7 +8,7 @@
 // |                                                                           |
 // | Geeklog block administration.                                             |
 // +---------------------------------------------------------------------------+
-// | Copyright (C) 2000-2009 by the following authors:                         |
+// | Copyright (C) 2000-2010 by the following authors:                         |
 // |                                                                           |
 // | Authors: Tony Bibbs        - tony AT tonybibbs DOT com                    |
 // |          Mark Limburg      - mlimburg AT users DOT sourceforge DOT net    |
@@ -57,36 +57,14 @@ require_once 'auth.inc.php';
 $display = '';
 
 if (!SEC_hasRights('block.edit')) {
-    $display .= COM_siteHeader('menu', $MESSAGE[30])
-             . COM_showMessageText($MESSAGE[29], $MESSAGE[30])
-             . COM_siteFooter();
+    $display .= COM_showMessageText($MESSAGE[29], $MESSAGE[30]);
+    $display = COM_createHTMLDocument($display, array('pagetitle' => $MESSAGE[30]));
     COM_accessLog("User {$_USER['username']} tried to illegally access the block administration screen");
     COM_output($display);
     exit;
 }
 
 
-/**
-* Check for block topic access (need to handle 'all' and 'homeonly' as
-* special cases)
-*
-* @param    string  $tid    ID for topic to check on
-* @return   int             returns 3 for read/edit 2 for read only 0 for no access
-*
-*/
-function hasBlockTopicAccess ($tid)
-{
-    $access = 0;
-
-    if (($tid == 'all') || ($tid == 'homeonly')) {
-        $access = 3;
-    } else {
-        $access = SEC_hasTopicAccess ($tid);
-    }
-
-    return $access;
-}
-
 /**
 * Shows default block editor
 *
@@ -110,12 +88,8 @@ function editdefaultblock ($A, $access)
     $token = SEC_createToken();
     $retval .= SEC_getTokenExpiryNotice($token);
 
-    $block_templates = new Template($_CONF['path_layout'] . 'admin/block');
+    $block_templates = COM_newTemplate($_CONF['path_layout'] . 'admin/block');
     $block_templates->set_file('editor','defaultblockeditor.thtml');
-    $block_templates->set_var('xhtml', XHTML);
-    $block_templates->set_var('site_url', $_CONF['site_url']);
-    $block_templates->set_var('site_admin_url', $_CONF['site_admin_url']);
-    $block_templates->set_var('layout_url', $_CONF['layout_url']);
     $block_templates->set_var('block_id', $A['bid']);
     // standard Admin strings
     $block_templates->set_var('lang_blocktitle', $LANG_ADMIN['title']);
@@ -137,22 +111,17 @@ function editdefaultblock ($A, $access)
     $block_templates->set_var('lang_explanation', $LANG21[52]);
     $block_templates->set_var('block_name',$A['name']);
     $block_templates->set_var('lang_blockname', $LANG21[48]);
-    $block_templates->set_var('lang_homeonly', $LANG21[43]);
-    if ($A['tid'] == 'all') {
-        $block_templates->set_var('all_selected', 'selected="selected"');
-    } else if ($A['tid'] == 'homeonly') {
-        $block_templates->set_var('homeonly_selected', 'selected="selected"');
-    }
-    $block_templates->set_var('topic_options',
-                              COM_topicList ('tid,topic', $A['tid'], 1, true));
-    $block_templates->set_var('lang_all', $LANG21[7]);
+    
+    $block_templates->set_var('topic_selection',
+                          TOPIC_getTopicSelectionControl ('block', $A['bid'], true, true));
+    
     $block_templates->set_var('lang_side', $LANG21[39]);
     $block_templates->set_var('lang_left', $LANG21[40]);
     $block_templates->set_var('lang_right', $LANG21[41]);
 
     if ($A['onleft'] == 1) {
         $block_templates->set_var('left_selected', 'selected="selected"');
-    } else if ($A['onleft'] == 0) {
+    } elseif ($A['onleft'] == 0) {
         $block_templates->set_var('right_selected', 'selected="selected"');
     }
     $block_templates->set_var('lang_blockorder', $LANG21[9]);
@@ -201,25 +170,27 @@ function editdefaultblock ($A, $access)
 function editblock ($bid = '')
 {
     global $_CONF, $_GROUPS, $_TABLES, $_USER, $LANG01, $LANG21, $LANG_ACCESS,
-           $LANG_ADMIN, $MESSAGE;
+           $LANG_ADMIN, $MESSAGE, $_SCRIPTS;
 
     $retval = '';
 
     if (!empty($bid)) {
         $sql['mysql'] = "SELECT * FROM {$_TABLES['blocks']} WHERE bid ='$bid'";
 
-        $sql['mssql'] = "SELECT bid, is_enabled, name, type, title, tid, blockorder, cast(content as text) as content, rdfurl, ";
+        $sql['mssql'] = "SELECT bid, is_enabled, name, type, title, blockorder, cast(content as text) as content, rdfurl, ";
         $sql['mssql'] .= "rdfupdated, rdflimit, onleft, phpblockfn, help, owner_id,group_id, ";
-        $sql['mssql'] .= "perm_owner, perm_group, perm_members, perm_anon, allow_autotags FROM {$_TABLES['blocks']} WHERE bid ='$bid'";
+        $sql['mssql'] .= "perm_owner, perm_group, perm_members, perm_anon, allow_autotags, cache_time FROM {$_TABLES['blocks']} WHERE bid ='$bid'";
 
+        $sql['pgsql'] = "SELECT * FROM {$_TABLES['blocks']} WHERE bid ='$bid'";
+        
         $result = DB_query($sql);
         $A = DB_fetchArray($result);
-        $access = SEC_hasAccess($A['owner_id'],$A['group_id'],$A['perm_owner'],$A['perm_group'],$A['perm_members'],$A['perm_anon']);
-        if ($access == 2 || $access == 0 || hasBlockTopicAccess ($A['tid']) < 3) {
-            $retval .= COM_startBlock ($LANG_ACCESS['accessdenied'], '',
-                               COM_getBlockTemplate ('_msg_block', 'header'))
-                    . $LANG21[45]
-                    . COM_endBlock (COM_getBlockTemplate ('_msg_block', 'footer'));
+        
+        $access = SEC_hasAccess($A['owner_id'], $A['group_id'], $A['perm_owner'], $A['perm_group'], $A['perm_members'], $A['perm_anon']);
+        if (($access == 2) || ($access == 0) ||
+                (TOPIC_hasMultiTopicAccess('block', $bid) < 3)) {
+            $retval .= COM_showMessageText($LANG21[45],
+                                           $LANG_ACCESS['accessdenied']);
             COM_accessLog("User {$_USER['username']} tried to illegally create or edit block $bid.");
 
             return $retval;
@@ -234,8 +205,9 @@ function editblock ($bid = '')
         $A['name'] = '';
         $A['type'] = 'normal';
         $A['title'] = '';
-        $A['tid'] = 'All';
+        $A['tid'] = '';
         $A['blockorder'] = 0;
+        $A['cache_time'] = $_CONF['default_cache_time_block'];
         $A['content'] = '';
         $A['allow_autotags'] = 0;
         $A['rdfurl'] = '';
@@ -256,12 +228,8 @@ function editblock ($bid = '')
 
     $token = SEC_createToken();
 
-    $block_templates = new Template($_CONF['path_layout'] . 'admin/block');
+    $block_templates = COM_newTemplate($_CONF['path_layout'] . 'admin/block');
     $block_templates->set_file('editor','blockeditor.thtml');
-    $block_templates->set_var('site_url', $_CONF['site_url']);
-    $block_templates->set_var('xhtml', XHTML);
-    $block_templates->set_var('site_admin_url', $_CONF['site_admin_url']);
-    $block_templates->set_var('layout_url', $_CONF['layout_url']);
     $block_start = COM_startBlock($LANG21[3], '',
                         COM_getBlockTemplate('_admin_block', 'header'));
     $block_start .= LB . SEC_getTokenExpiryNotice($token);
@@ -301,21 +269,16 @@ function editblock ($bid = '')
     $block_templates->set_var('block_name', $A['name']);
     $block_templates->set_var('lang_blockname', $LANG21[48]);
     $block_templates->set_var('lang_nospaces', $LANG21[49]);
-    $block_templates->set_var('lang_all', $LANG21[7]);
-    $block_templates->set_var('lang_homeonly', $LANG21[43]);
-    if ($A['tid'] == 'all') {
-        $block_templates->set_var('all_selected', 'selected="selected"');
-    } else if ($A['tid'] == 'homeonly') {
-        $block_templates->set_var('homeonly_selected', 'selected="selected"');
-    }
-    $block_templates->set_var('topic_options',
-                              COM_topicList('tid,topic', $A['tid'], 1, true));
+    
+    $block_templates->set_var('topic_selection',
+                          TOPIC_getTopicSelectionControl ('block', $A['bid'], true, true));    
+
     $block_templates->set_var('lang_side', $LANG21[39]);
     $block_templates->set_var('lang_left', $LANG21[40]);
     $block_templates->set_var('lang_right', $LANG21[41]);
     if ($A['onleft'] == 1) {
         $block_templates->set_var('left_selected', 'selected="selected"');
-    } else if ($A['onleft'] == 0) {
+    } elseif ($A['onleft'] == 0) {
         $block_templates->set_var('right_selected', 'selected="selected"');
     }
     $block_templates->set_var('lang_blockorder', $LANG21[9]);
@@ -325,11 +288,15 @@ function editblock ($bid = '')
     $block_templates->set_var('lang_portalblock', $LANG21[11]);
     if ($A['type'] == 'normal') {
         $block_templates->set_var('normal_selected', 'selected="selected"');
-    } else if ($A['type'] == 'phpblock') {
+    } elseif ($A['type'] == 'phpblock') {
         $block_templates->set_var('php_selected', 'selected="selected"');
-    } else if ($A['type'] == 'portal') {
+    } elseif ($A['type'] == 'portal') {
         $block_templates->set_var('portal_selected', 'selected="selected"');
     }
+    $block_templates->set_var('lang_cachetime', $LANG21['cache_time']);
+    $block_templates->set_var('lang_cachetime_desc', $LANG21['cache_time_desc']);
+    $block_templates->set_var('cache_time', $A['cache_time']);
+    
     $block_templates->set_var('lang_accessrights', $LANG_ACCESS['accessrights']);
     $block_templates->set_var('lang_owner', $LANG_ACCESS['owner']);
     $ownername = COM_getDisplayName ($A['owner_id']);
@@ -362,12 +329,16 @@ function editblock ($bid = '')
     } else {
         $block_templates->set_var ('block_rdfupdated', $A['rdfupdated']);
     }
-    $block_templates->set_var ('lang_normalblockoptions', $LANG21[16]);
-    $block_templates->set_var ('lang_blockcontent', $LANG21[17]);
-    $block_templates->set_var ('lang_autotags', $LANG21[66]);
-    $block_templates->set_var ('lang_use_autotags', $LANG21[67]);
-    $block_templates->set_var ('block_content',
-                               htmlspecialchars (stripslashes ($A['content'])));
+    $block_templates->set_var('lang_normalblockoptions', $LANG21[16]);
+    $block_templates->set_var('lang_blockcontent', $LANG21[17]);
+    $block_templates->set_var('lang_autotags', $LANG21[66]);
+    $block_templates->set_var('lang_use_autotags', $LANG21[67]);
+
+    $content = htmlspecialchars(stripslashes($A['content']));
+    $content = str_replace(array('{', '}'), array('&#123;', '&#125;'),
+                           $content);
+    $block_templates->set_var('block_content', $content);
+
     if ($A['allow_autotags'] == 1) {
         $block_templates->set_var ('allow_autotags', 'checked="checked"');
     } else {
@@ -380,9 +351,33 @@ function editblock ($bid = '')
     $block_templates->parse('output', 'editor');
     $retval .= $block_templates->finish($block_templates->get_var('output'));
 
+    // Shows/Hides relevant block options dynamically
+    $_SCRIPTS->setJavaScript("
+jQuery(function () {
+    var $ = jQuery;
+    $('#admin-blockeditor-type').on('change', function () {
+        var fs, i, fieldsets = ['normal', 'phpblock', 'portal'];
+        
+        for (i = 0; i < 3; i++) {
+            if (this.value === fieldsets[i]) {
+                $('#fs-' + fieldsets[i] + '-options').show();
+            } else {
+                $('#fs-' + fieldsets[i] + '-options').hide();
+            }
+        }
+    })
+    .trigger('change');
+});", true, true);
+
     return $retval;
 }
 
+/**
+* Display two lists of blocks, separated by left and right
+*
+* @return   string  HTML for the two lists
+*
+*/
 function listblocks()
 {
     global $_CONF, $_TABLES, $LANG_ADMIN, $LANG21, $_IMAGE_TYPE;
@@ -410,14 +405,16 @@ function listblocks()
 
     reorderblocks();
     
-    // writing the list
+    // Left
+    // Regular Blocks
     $header_arr = array(      # display 'text' and use table field 'field'
         array('text' => $LANG_ADMIN['edit'], 'field' => 'edit', 'sort' => false),
         array('text' => $LANG21[65], 'field' => 'blockorder', 'sort' => true),
         array('text' => $LANG21[46], 'field' => 'move', 'sort' => false),
         array('text' => $LANG_ADMIN['title'], 'field' => 'title', 'sort' => true),
+        array('text' => $LANG21[48], 'field' => 'name', 'sort' => true),
         array('text' => $LANG_ADMIN['type'], 'field' => 'type', 'sort' => true),
-        array('text' => $LANG_ADMIN['topic'], 'field' => 'tid', 'sort' => true),
+        array('text' => $LANG_ADMIN['topic'], 'field' => 'topic', 'sort' => true),
         array('text' => $LANG_ADMIN['enabled'], 'field' => 'is_enabled', 'sort' => true)
     );
 
@@ -425,6 +422,7 @@ function listblocks()
 
     $text_arr = array(
         'has_extras' => true,
+		'title'      => "$LANG21[20] ($LANG21[40])",
         'form_url'   => $_CONF['site_admin_url'] . '/block.php'
     );
 
@@ -438,15 +436,47 @@ function listblocks()
     // this is a dummy variable so we know the form has been used if all blocks
     // should be disabled on one side in order to disable the last one.
     // The value is the onleft var
-    $form_arr = array('bottom' => '<input type="hidden" name="blockenabler" value="1"' . XHTML . '>');
+    $form_arr = array(
+        'top'    => '<input type="hidden" name="' . CSRF_TOKEN . '" value="'
+                    . $token . '"' . XHTML . '>',
+        'bottom' => '<input type="hidden" name="blockenabler" value="1"'
+                    . XHTML . '>'
+    );
 
-    $retval .= ADMIN_list(
+	$retval .= ADMIN_list(
         'blocks', 'ADMIN_getListField_blocks', $header_arr, $text_arr,
         $query_arr, $defsort_arr, '', $token, '', $form_arr
     );
+    
 
-    $retval .= COM_endBlock(COM_getBlockTemplate('_admin_block', 'footer'));
+    // Dynamic blocks 
+    $dyn_header_arr = array(      # display 'text' and use table field 'field'
+        array('text' => $LANG21[65], 'field' => 'blockorder', 'sort' => true),
+        array('text' => $LANG21[69], 'field' => 'plugin', 'sort' => true),
+        array('text' => $LANG_ADMIN['title'], 'field' => 'title', 'sort' => true),
+        array('text' => $LANG21[48], 'field' => 'name', 'sort' => true),
+        array('text' => $LANG_ADMIN['type'], 'field' => 'type', 'sort' => true),
+        array('text' => $LANG_ADMIN['topic'], 'field' => 'topic', 'sort' => true),
+        array('text' => $LANG_ADMIN['enabled'], 'field' => 'is_enabled', 'sort' => true)
+    );    
 
+	
+	$dyn_text_arr = array(
+        'title'      => "$LANG21[22] ($LANG21[40])",
+        'form_url'   => $_CONF['site_admin_url'] . '/block.php'
+    );
+	
+	$leftblocks = PLG_getBlocksConfig('left', '');    
+	
+	// Sort Dynamic Blocks on Block Order
+    usort($leftblocks, "cmpDynamicBlocks");
+
+	$retval .= ADMIN_simpleList('ADMIN_getListField_dynamicblocks', $dyn_header_arr, $dyn_text_arr,
+                    $leftblocks, '', $form_arr);
+	
+
+    // Right
+    // Regular Blocks	
     $query_arr = array(
         'table' => 'blocks',
         'sql' => "SELECT * FROM {$_TABLES['blocks']} WHERE onleft = 0",
@@ -456,22 +486,55 @@ function listblocks()
 
     $text_arr = array(
         'has_extras' => true,
-        'title'      => "$LANG21[19] ($LANG21[41])",
+        'title'      => "$LANG21[20] ($LANG21[41])",
         'form_url'   => $_CONF['site_admin_url'] . '/block.php'
     );
 
     // this is a dummy-variable so we know the form has been used if all blocks should be disabled
     // on one side in order to disable the last one. The value is the onleft var
-    $form_arr = array('bottom' => '<input type="hidden" name="blockenabler" value="0"' . XHTML . '>');
+    $form_arr = array(
+        'top'    => '<input type="hidden" name="' . CSRF_TOKEN . '" value="'
+                    . $token . '"' . XHTML . '>',
+        'bottom' => '<input type="hidden" name="blockenabler" value="0"'
+                    . XHTML . '>'
+    );
 
     $retval .= ADMIN_list (
         'blocks', 'ADMIN_getListField_blocks', $header_arr, $text_arr,
         $query_arr, $defsort_arr, '', $token, '', $form_arr
     );
 
+	// Dynamic blocks
+	$dyn_text_arr = array(
+        'title'      => "$LANG21[22] ($LANG21[41])",
+        'form_url'   => $_CONF['site_admin_url'] . '/block.php'
+    );
+	
+	$rightblocks = PLG_getBlocksConfig('right', '');
+	
+	// Sort Dynamic Blocks on Block Order
+    usort($rightblocks, "cmpDynamicBlocks");
+
+	$retval .= ADMIN_simpleList('ADMIN_getListField_dynamicblocks', $dyn_header_arr, $dyn_text_arr,
+                    $rightblocks, '', $form_arr);
+	
+	$retval .= COM_endBlock(COM_getBlockTemplate('_admin_block', 'footer'));
+	
     return $retval;
 }
 
+/**
+* Used by listblocks function when sorting the dynamic block array using the 
+* usort function
+*
+* @return   boolean
+*
+*/
+function cmpDynamicBlocks($a, $b)
+{
+    return $a["blockorder"] > $b["blockorder"];
+}
+
 /**
 * Saves a block
 *
@@ -480,7 +543,7 @@ function listblocks()
 * @param    string  $type           Type of block
 * @param    int     $blockorder     Order block appears relative to the others
 * @param    string  $content        Content of block
-* @param    string  $tid            Topic block should appear in
+* @param    string  $tid            Ids of topics block is assigned to
 * @param    string  $rdfurl         URL to headline feed for portal blocks
 * @param    string  $rdfupdated     Date RSS/RDF feed was last updated
 * @param    string  $rdflimit       max. number of entries to import from feed
@@ -496,23 +559,18 @@ function listblocks()
 * @return   string                  HTML redirect or error message
 *
 */
-function saveblock ($bid, $name, $title, $help, $type, $blockorder, $content, $tid, $rdfurl, $rdfupdated, $rdflimit, $phpblockfn, $onleft, $owner_id, $group_id, $perm_owner, $perm_group, $perm_members, $perm_anon, $is_enabled, $allow_autotags)
+function saveblock($bid, $name, $title, $help, $type, $blockorder, $content, $rdfurl, $rdfupdated, $rdflimit, $phpblockfn, $onleft, $owner_id, $group_id, $perm_owner, $perm_group, $perm_members, $perm_anon, $is_enabled, $allow_autotags, $cache_time)
 {
-    global $_CONF, $_TABLES, $LANG01, $LANG21, $MESSAGE;
+    global $_CONF, $_TABLES, $LANG01, $LANG21, $MESSAGE, $_USER;
 
     $retval = '';
 
-    $title = addslashes (COM_stripslashes (strip_tags ($title)));
-    $phpblockfn = addslashes (COM_stripslashes (trim ($phpblockfn)));
-    if (empty($title)) {
-        $retval .= COM_siteHeader ('menu', $LANG21[63])
-                . COM_startBlock ($LANG21[63], '',
-                          COM_getBlockTemplate ('_msg_block', 'header'))
-                . $LANG21[64]
-                . COM_endBlock (COM_getBlockTemplate ('_msg_block',
-                                                      'footer'))
-                . editblock ($bid)
-                . COM_siteFooter ();
+    $title = DB_escapeString(COM_stripslashes (strip_tags ($title)));
+    $phpblockfn = DB_escapeString(COM_stripslashes (trim ($phpblockfn)));
+    if (empty($title) || !TOPIC_checkTopicSelectionControl()) {
+        $retval .= COM_showMessageText($LANG21[64], $LANG21[63])
+                . editblock($bid);
+        $retval = COM_createHTMLDocument($retval, array('pagetitle' => $LANG21[63]));
         return $retval;
     }
 
@@ -530,14 +588,18 @@ function saveblock ($bid, $name, $title, $help, $type, $blockorder, $content, $t
         $access = SEC_hasAccess ($owner_id, $group_id, $perm_owner, $perm_group,
                 $perm_members, $perm_anon);
     }
-    if (($access < 3) || !hasBlockTopicAccess($tid) || !SEC_inGroup($group_id)) {
-        $retval .= COM_siteHeader('menu', $MESSAGE[30])
-                . COM_showMessageText($MESSAGE[29], $MESSAGE[30])
-                . COM_siteFooter();
+    
+    if (($access < 3) || !TOPIC_hasMultiTopicAccess('topic') || !SEC_inGroup($group_id)) {
+        $retval .= COM_showMessageText($MESSAGE[29], $MESSAGE[30]);
+        $retval = COM_createHTMLDocument($retval, array('pagetitle' => $MESSAGE[30]));
         COM_accessLog("User {$_USER['username']} tried to illegally create or edit block $bid.");
 
         return $retval;
-    } elseif (($type == 'normal' && !empty($title) && !empty($content)) OR ($type == 'portal' && !empty($title) && !empty($rdfurl)) OR ($type == 'gldefault' && (strlen($blockorder)>0)) OR ($type == 'phpblock' && !empty($phpblockfn) && !empty($title))) {
+    } elseif (!empty($name) AND
+             ( ($type == 'normal' && !empty($title) && !empty($content))
+            OR ($type == 'portal' && !empty($title) && !empty($rdfurl))
+            OR ($type == 'phpblock' && !empty($phpblockfn) && !empty($title))
+            OR ($type == 'gldefault' && (strlen($blockorder) > 0)) )) {
         if ($is_enabled == 'on') {
             $is_enabled = 1;
         } else {
@@ -548,6 +610,10 @@ function saveblock ($bid, $name, $title, $help, $type, $blockorder, $content, $t
         } else {
             $allow_autotags = 0;
         }
+        
+        if ($cache_time < -1 OR $cache_time == "") {
+            $cache_time = $_CONF['default_cache_time_block'];
+        }        
 
         if ($type == 'portal') {
             $content = '';
@@ -557,7 +623,7 @@ function saveblock ($bid, $name, $title, $help, $type, $blockorder, $content, $t
             // get rid of possible extra prefixes (e.g. "feed://http://...")
             if (substr ($rdfurl, 0, 4) == 'rss:') {
                 $rdfurl = substr ($rdfurl, 4);
-            } else if (substr ($rdfurl, 0, 5) == 'feed:') {
+            } elseif (substr ($rdfurl, 0, 5) == 'feed:') {
                 $rdfurl = substr ($rdfurl, 5);
             }
             if (substr ($rdfurl, 0, 2) == '//') {
@@ -566,9 +632,7 @@ function saveblock ($bid, $name, $title, $help, $type, $blockorder, $content, $t
             $rdfurl = COM_sanitizeUrl ($rdfurl, array ('http', 'https'));
         }
         if ($type == 'gldefault') {
-            if ($name != 'older_stories') {
-                $content = '';
-            }
+            $content = '';
             $rdfurl = '';
             $rdfupdated = '';
             $rdflimit = 0;
@@ -580,14 +644,9 @@ function saveblock ($bid, $name, $title, $help, $type, $blockorder, $content, $t
             // must start with phpblock_ as the prefix.  This will prevent
             // the arbitrary execution of code
             if (!(stristr($phpblockfn,'phpblock_'))) {
-                $retval .= COM_siteHeader ('menu', $LANG21[37])
-                        . COM_startBlock ($LANG21[37], '',
-                                  COM_getBlockTemplate ('_msg_block', 'header'))
-                        . $LANG21[38]
-                        . COM_endBlock (COM_getBlockTemplate ('_msg_block',
-                                                              'footer'))
-                        . editblock ($bid)
-                        . COM_siteFooter ();
+                $retval .= COM_showMessageText($LANG21[38], $LANG21[37])
+                        . editblock($bid);
+                $retval = COM_createHTMLDocument($retval, array('pagetitle' => $LANG21[37]));
                 return $retval;
             }
             $content = '';
@@ -600,70 +659,82 @@ function saveblock ($bid, $name, $title, $help, $type, $blockorder, $content, $t
             $rdfupdated = '';
             $rdflimit = 0;
             $phpblockfn = '';
-            $content = addslashes ($content);
+            
+            if ($allow_autotags == 1) {
+                // Remove any autotags the user doesn't have permission to use
+                $content = PLG_replaceTags($content, '', true);
+            }
+            $content = DB_escapeString($content);
         }
         if ($rdflimit < 0) {
             $rdflimit = 0;
         }
         if (!empty ($rdfurl)) {
-            $rdfurl = addslashes ($rdfurl);
+            $rdfurl = DB_escapeString($rdfurl);
         }
         if (empty ($rdfupdated)) {
             $rdfupdated = '0000-00-00 00:00:00';
         }
 
         if ($bid > 0) {
-            DB_save($_TABLES['blocks'],'bid,name,title,help,type,blockorder,content,tid,rdfurl,rdfupdated,rdflimit,phpblockfn,onleft,owner_id,group_id,perm_owner,perm_group,perm_members,perm_anon,is_enabled,allow_autotags,rdf_last_modified,rdf_etag',"$bid,'$name','$title','$help','$type','$blockorder','$content','$tid','$rdfurl','$rdfupdated','$rdflimit','$phpblockfn',$onleft,$owner_id,$group_id,$perm_owner,$perm_group,$perm_members,$perm_anon,$is_enabled,$allow_autotags,NULL,NULL");
+            DB_save($_TABLES['blocks'],'bid,name,title,help,type,blockorder,content,rdfurl,rdfupdated,rdflimit,phpblockfn,onleft,owner_id,group_id,perm_owner,perm_group,perm_members,perm_anon,is_enabled,allow_autotags,cache_time,rdf_last_modified,rdf_etag',"$bid,'$name','$title','$help','$type','$blockorder','$content','$rdfurl','$rdfupdated','$rdflimit','$phpblockfn',$onleft,$owner_id,$group_id,$perm_owner,$perm_group,$perm_members,$perm_anon,$is_enabled,$allow_autotags,$cache_time,NULL,NULL");
         } else {
-            $sql = "INSERT INTO {$_TABLES['blocks']} "
-             .'(name,title,help,type,blockorder,content,tid,rdfurl,rdfupdated,rdflimit,phpblockfn,onleft,owner_id,group_id,perm_owner,perm_group,perm_members,perm_anon,is_enabled,allow_autotags) '
-             ."VALUES ('$name','$title','$help','$type','$blockorder','$content','$tid','$rdfurl','$rdfupdated','$rdflimit','$phpblockfn',$onleft,$owner_id,$group_id,$perm_owner,$perm_group,$perm_members,$perm_anon,$is_enabled,$allow_autotags)";
+            $sql = array();
+            $sql['mysql'] = $sql['mssql'] = "INSERT INTO {$_TABLES['blocks']} "
+             .'(name,title,help,type,blockorder,content,rdfurl,rdfupdated,rdflimit,phpblockfn,onleft,owner_id,group_id,perm_owner,perm_group,perm_members,perm_anon,is_enabled,allow_autotags,cache_time) '
+             ."VALUES ('$name','$title','$help','$type','$blockorder','$content','$rdfurl','$rdfupdated','$rdflimit','$phpblockfn',$onleft,$owner_id,$group_id,$perm_owner,$perm_group,$perm_members,$perm_anon,$is_enabled,$allow_autotags,$cache_time)";
+            
+             $sql['pgsql'] = "INSERT INTO {$_TABLES['blocks']} "
+             .'(bid,name,title,help,type,blockorder,content,rdfurl,rdfupdated,rdflimit,phpblockfn,onleft,owner_id,group_id,perm_owner,perm_group,perm_members,perm_anon,is_enabled,allow_autotags,cache_time) '
+             ."VALUES ((SELECT NEXTVAL('{$_TABLES['blocks']}_bid_seq')),'$name','$title','$help','$type','$blockorder','$content','$rdfurl','1970-01-01','$rdflimit','$phpblockfn',$onleft,$owner_id,$group_id,$perm_owner,$perm_group,$perm_members,$perm_anon,$is_enabled,$allow_autotags,$cache_time)";
+             
              DB_query($sql);
              $bid = DB_insertId();
         }
 
-        if (($type == 'gldefault') && ($name == 'older_stories')) {
-            COM_olderStuff ();
-        }
-
+        TOPIC_saveTopicSelectionControl('block', $bid);
+        
+        $cacheInstance = 'block__' . $bid . '__';  // remove any of this blocks instances if exists
+        CACHE_remove_instance($cacheInstance);            
+        
         return COM_refresh ($_CONF['site_admin_url'] . '/block.php?msg=11');
     } else {
-        $retval .= COM_siteHeader ('menu', $LANG21[32])
-                . COM_startBlock ($LANG21[32], '',
-                          COM_getBlockTemplate ('_msg_block', 'header'));
-        if ($type == 'portal') {
+        if (empty($name)) {
+            // empty block name
+            $msgtxt = $LANG21[50];
+        } elseif ($type == 'portal') {
             // Portal block is missing fields
-            $retval .= $LANG21[33];
-        } else if ($type == 'phpblock') {
+            $msgtxt = $LANG21[33];
+        } elseif ($type == 'phpblock') {
             // PHP Block is missing field
-            $retval .= $LANG21[34];
-        } else if ($type == 'normal') {
+            $msgtxt = $LANG21[34];
+        } elseif ($type == 'normal') {
             // Normal block is missing field
-            $retval .= $LANG21[35];
-        } else if ($type == 'gldefault') {
+            $msgtxt = $LANG21[35];
+        } elseif ($type == 'gldefault') {
             // Default geeklog field missing
-            $retval .= $LANG21[42];
+            $msgtxt = $LANG21[42];
         } else {
             // Layout block missing content
-            $retval .= $LANG21[36];
+            $msgtxt = $LANG21[36];
         }
-        $retval .= COM_endBlock (COM_getBlockTemplate ('_msg_block', 'footer'))
-                . editblock ($bid)
-                . COM_siteFooter ();
+        $retval .= COM_showMessageText($msgtxt, $LANG21[32])
+                . editblock($bid);
+        $retval = COM_createHTMLDocument($retval, array('pagetitle' => $LANG21[32]));
     }
 
     return $retval;
 }
+
 /**
-*
-* Re-orders all blocks in steps of 10
+* Re-orders all blocks in increments of 10
 *
 */
 function reorderblocks()
 {
     global $_TABLES;
 
-    $sql = "SELECT * FROM {$_TABLES['blocks']} ORDER BY onleft asc, blockorder asc;";
+    $sql = "SELECT * FROM {$_TABLES['blocks']} ORDER BY onleft ASC, blockorder ASC;";
     $result = DB_query($sql);
     $nrows = DB_numRows($result);
 
@@ -732,25 +803,32 @@ function moveBlock()
 
 
 /**
-* Enable and Disable block
+* Enable and Disable blocks
+*
+* @param    array   $enabledblocks  array containing ids of enabled blocks
+* @param    array   $visibleblocks  array containing ids of visible blocks
+* @return   void
+*
 */
-function changeBlockStatus($side, $bid_arr)
+function changeBlockStatus($enabledblocks, $visibleblocks)
 {
     global $_CONF, $_TABLES;
 
-    // first, disable all on the requested side
-    $side = COM_applyFilter($side, true);
-    $sql = "UPDATE {$_TABLES['blocks']} SET is_enabled = '0' WHERE onleft='$side';";
-    DB_query($sql);
-    if (isset($bid_arr)) {
-        foreach ($bid_arr as $bid => $side) {
-            $bid = COM_applyFilter($bid, true);
-            // the enable those in the array
-            $sql = "UPDATE {$_TABLES['blocks']} SET is_enabled = '1' WHERE bid='$bid' AND onleft='$side'";
-            DB_query($sql);
-        }
+    $disabled = array_diff($visibleblocks, $enabledblocks);
+
+    // disable blocks
+    $in = implode(',', $disabled);
+    if (! empty($in)) {
+        $sql = "UPDATE {$_TABLES['blocks']} SET is_enabled = 0 WHERE bid IN ($in)";
+        DB_query($sql);
+    }
+
+    // enable blocks
+    $in = implode(',', $enabledblocks);
+    if (! empty($in)) {
+        $sql = "UPDATE {$_TABLES['blocks']} SET is_enabled = 1 WHERE bid IN ($in)";
+        DB_query($sql);
     }
-    return;
 }
 
 /**
@@ -764,16 +842,21 @@ function deleteBlock ($bid)
 {
     global $_CONF, $_TABLES, $_USER;
 
-    $result = DB_query ("SELECT tid,owner_id,group_id,perm_owner,perm_group,perm_members,perm_anon FROM {$_TABLES['blocks']} WHERE bid ='$bid'");
+    $result = DB_query ("SELECT owner_id,group_id,perm_owner,perm_group,perm_members,perm_anon FROM {$_TABLES['blocks']} WHERE bid ='$bid'");
     $A = DB_fetchArray($result);
     $access = SEC_hasAccess ($A['owner_id'], $A['group_id'], $A['perm_owner'],
             $A['perm_group'], $A['perm_members'], $A['perm_anon']);
-    if (($access < 3) || (hasBlockTopicAccess ($A['tid']) < 3)) {
+    if (($access < 3) || (TOPIC_hasMultiTopicAccess('block', $bid) < 3)) {
         COM_accessLog ("User {$_USER['username']} tried to illegally delete block $bid.");
         return COM_refresh ($_CONF['site_admin_url'] . '/block.php');
     }
 
+    TOPIC_deleteTopicAssignments('block', $bid);
+    
     DB_delete ($_TABLES['blocks'], 'bid', $bid);
+    
+    $cacheInstance = 'block__' . $bid . '__';  // remove any of this blocks instances if exists
+    CACHE_remove_instance($cacheInstance);            
 
     return COM_refresh ($_CONF['site_admin_url'] . '/block.php?msg=12');
 }
@@ -794,9 +877,13 @@ if (isset($_POST['blockenabler']) && SEC_checkToken()) {
     if (isset($_POST['enabledblocks'])) {
         $enabledblocks = $_POST['enabledblocks'];
     }
-    changeBlockStatus($_POST['blockenabler'], $enabledblocks);
+    $visibleblocks = array();
+    if (isset($_POST['visibleblocks'])) {
+        $visibleblocks = $_POST['visibleblocks'];
+    }
+    changeBlockStatus($enabledblocks, $visibleblocks);
 }
-
+    
 if (($mode == $LANG_ADMIN['delete']) && !empty ($LANG_ADMIN['delete'])) {
     if (!isset ($bid) || empty ($bid) || ($bid == 0)) {
         COM_errorLog ('Attempted to delete block, bid empty or null, value =' . $bid);
@@ -840,32 +927,32 @@ if (($mode == $LANG_ADMIN['delete']) && !empty ($LANG_ADMIN['delete'])) {
     if (isset ($_POST['allow_autotags'])) {
         $allow_autotags = $_POST['allow_autotags'];
     }
+    $cache_time = $_CONF['default_cache_time_block'];
+    if (isset ($_POST['cache_time'])) {
+        $cache_time = COM_applyFilter ($_POST['cache_time'], true);
+    }    
     $display .= saveblock ($bid, $_POST['name'], $_POST['title'],
                     $help, $_POST['type'], $_POST['blockorder'], $content,
-                    COM_applyFilter ($_POST['tid']), $rdfurl, $rdfupdated,
+                    $rdfurl, $rdfupdated,
                     $rdflimit, $phpblockfn, $_POST['onleft'],
                     COM_applyFilter ($_POST['owner_id'], true),
                     COM_applyFilter ($_POST['group_id'], true),
                     $_POST['perm_owner'], $_POST['perm_group'],
                     $_POST['perm_members'], $_POST['perm_anon'],
-                    $is_enabled, $allow_autotags);
-} else if ($mode == 'edit') {
-    $display .= COM_siteHeader ('menu', $LANG21[3])
-             . editblock ($bid)
-             . COM_siteFooter ();
-} else if ($mode == 'move') {
-    $display .= COM_siteHeader('menu', $LANG21[19]);
+                    $is_enabled, $allow_autotags, $cache_time);
+} elseif ($mode == 'edit') {
+    $tmp = editblock($bid);
+    $display = COM_createHTMLDocument($tmp, array('pagetitle' => $LANG21[3]));
+} elseif ($mode == 'move') {
     if(SEC_checkToken()) {
         $display .= moveBlock();
     }
     $display .= listblocks();
-    $display .= COM_siteFooter();
+    $display = COM_createHTMLDocument($display, array('pagetitle' => $LANG21[19]));
 } else {  // 'cancel' or no mode at all
-    $display .= COM_siteHeader('menu', $LANG21[19]);
     $display .= COM_showMessageFromParameter();
     $display .= listblocks();
-
-    $display .= COM_siteFooter();
+    $display = COM_createHTMLDocument($display, array('pagetitle' => $LANG21[19]));
 }
 
 COM_output($display);
