@@ -47,7 +47,7 @@ require_once 'lib-upgrade.php';
  */
 function INST_installEngine($install_type, $install_step)
 {
-    global $_CONF, $_TABLES, $LANG_INSTALL, $LANG_CHARSET, $_DB, $_DB_dbms, $_DB_table_prefix, $_URL, $gl_path, $html_path, $dbconfig_path, $siteconfig_path, $display, $language, $form_label_dir, $use_innodb, $LANG_INSTALL_JP;
+    global $_CONF, $_TABLES, $LANG_INSTALL, $LANG_CHARSET, $_DB, $_DB_dbms, $_DB_table_prefix, $_URL, $gl_path, $html_path, $dbconfig_path, $siteconfig_path, $display, $language, $form_label_dir, $use_innodb;
 
     switch ($install_step) {
 
@@ -267,10 +267,12 @@ function INST_installEngine($install_type, $install_step)
             }
 
             // for the default charset, patch siteconfig.php again
-            if (!INST_setDefaultCharset($siteconfig_path,
-                    ($utf8 ? 'utf-8' : $LANG_CHARSET))) {
-                exit($LANG_INSTALL[26] . ' ' . $siteconfig_path
-                     . $LANG_INSTALL[58]);
+            if ($install_type != 'upgrade') {
+                if (!INST_setDefaultCharset($siteconfig_path,
+                        ($utf8 ? 'utf-8' : $LANG_CHARSET))) {
+                    exit($LANG_INSTALL[26] . ' ' . $siteconfig_path
+                         . $LANG_INSTALL[58]);
+                }
             }
 
             require $dbconfig_path;
@@ -425,7 +427,7 @@ function INST_installEngine($install_type, $install_step)
                 require_once $dbconfig_path;
                 require_once $siteconfig_path;
                 require_once $_CONF['path_system'] . 'lib-database.php';
-                
+
                 if($_DB_dbms=='pgsql')
                 {
                     //Create a func to check if plpgsql is already installed
@@ -501,14 +503,18 @@ function INST_installEngine($install_type, $install_step)
                         INST_personalizeAdminAccount($site_mail, $site_url);
 
                         // Insert the form data into the conf_values table
+                        $site_name   = urldecode($site_name);
+                        $site_name   = INST_cleanString($site_name);
+                        $site_slogan = urldecode($site_slogan);
+                        $site_slogan = INST_cleanString($site_slogan);
 
                         require_once $_CONF['path_system'] . 'classes/config.class.php';
                         require_once 'config-install.php';
                         install_config();
 
                         $config = config::get_instance();
-                        $config->set('site_name', urldecode($site_name));
-                        $config->set('site_slogan', urldecode($site_slogan));
+                        $config->set('site_name', $site_name);
+                        $config->set('site_slogan', $site_slogan);
                         $config->set('site_url', urldecode($site_url));
                         $config->set('site_admin_url', urldecode($site_admin_url));
                         $config->set('site_mail', urldecode($site_mail));
@@ -520,8 +526,10 @@ function INST_installEngine($install_type, $install_step)
                         $config->set('path_data', $gl_path . 'data/');
                         $config->set('path_images', $html_path . 'images/');
                         $config->set('path_themes', $html_path . 'layout/');
+                        $config->set('path_editors', $html_path . 'editors/');
                         $config->set('rdf_file', $html_path . 'backend/geeklog.rss');
                         $config->set('path_pear', $_CONF['path_system'] . 'pear/');
+                        $config->set('cookie_path', INST_guessCookiePath(urldecode($site_url)));
                         $config->set_default('default_photo', urldecode($site_url) . '/default.jpg');
 
                         $lng = INST_getDefaultLanguage($gl_path . 'language/', $language, $utf8);
@@ -531,7 +539,7 @@ function INST_installEngine($install_type, $install_step)
 
                         INST_setVersion($siteconfig_path);
 
-                        if (! $install_plugins) { 
+                        if (! $install_plugins) {
                             // do a default install of all available plugins
 
                             /**
@@ -551,10 +559,6 @@ function INST_installEngine($install_type, $install_step)
                             $language = $lx_inst;
 
                             INST_defaultPluginInstall();
-
-                        	require_once 'LocalizeGeeklog.php';
-                        	$obj = new LocalizeGeeklog('ja');
-                        	$obj->execute();
                         }
 
                         // Installation is complete. Continue onto either
@@ -607,10 +611,15 @@ function INST_installEngine($install_type, $install_step)
                         $site_mail      = isset($_POST['site_mail']) ? $_POST['site_mail'] : (isset($_GET['site_mail']) ? $_GET['site_mail'] : '') ;
                         $noreply_mail   = isset($_POST['noreply_mail']) ? $_POST['noreply_mail'] : (isset($_GET['noreply_mail']) ? $_GET['noreply_mail'] : '') ;
 
+                        $site_name   = urldecode($site_name);
+                        $site_name   = INST_cleanString($site_name);
+                        $site_slogan = urldecode($site_slogan);
+                        $site_slogan = INST_cleanString($site_slogan);
+
                         require_once $_CONF['path_system'] . 'classes/config.class.php';
                         $config = config::get_instance();
-                        $config->set('site_name', urldecode($site_name));
-                        $config->set('site_slogan', urldecode($site_slogan));
+                        $config->set('site_name', $site_name);
+                        $config->set('site_slogan', $site_slogan);
                         $config->set('site_url', urldecode($site_url));
                         $config->set('site_admin_url', urldecode($site_admin_url));
                         $config->set('site_mail', urldecode($site_mail));
@@ -627,10 +636,6 @@ function INST_installEngine($install_type, $install_step)
                     // disable plugins for which we don't have the source files
                     INST_checkPlugins();
 
-                    require_once 'LocalizeGeeklog.php';
-                    $obj = new LocalizeGeeklog('ja');
-                    $obj->execute();
-
                     // extra step 4: upgrade plugins
                     $next_link = 'index.php?step=4&mode=' . $install_type
                                . '&language=' . $language;
@@ -646,6 +651,10 @@ function INST_installEngine($install_type, $install_step)
                 }
                 break;
         }
+        
+        // Clear the Geeklog Cache        
+        INST_clearCache();
+
         break;
 
     /**
@@ -709,7 +718,7 @@ function INST_checkIfWritable($files)
  */
 function INST_permissionWarning($files)
 {
-    global $LANG_INSTALL, $form_label_dir, $LANG_INSTALL_JP;
+    global $LANG_INSTALL, $form_label_dir;
     $display .= '
         <div class="install-path-container-outer">
             <div class="install-path-container-inner">
@@ -856,12 +865,12 @@ function INST_personalizeAdminAccount($site_mail, $site_url)
 
         if (!empty($site_mail)) {
             if (strpos($site_mail, 'example.com') === false) {
-                DB_query("UPDATE {$_TABLES['users']} SET email = '" . addslashes($site_mail) . "' WHERE uid = 2");
+                DB_query("UPDATE {$_TABLES['users']} SET email = '" . DB_escapeString($site_mail) . "' WHERE uid = 2");
             }
         }
         if (!empty($site_url)) {
             if (strpos($site_url, 'example.com') === false) {
-                DB_query("UPDATE {$_TABLES['users']} SET homepage = '" . addslashes($site_url) . "' WHERE uid = 2");
+                DB_query("UPDATE {$_TABLES['users']} SET homepage = '" . DB_escapeString($site_url) . "' WHERE uid = 2");
             }
         }
     }
@@ -951,10 +960,10 @@ $use_innodb = false;
 
 // $display holds all the outputted HTML and content
 if (defined('XHTML')) {
-	$display = '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
+    $display = '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
 <html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">';
 } else {
-	$display = '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
+    $display = '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
 <html>';
 }
 
@@ -969,6 +978,7 @@ $display .= '<head>
     <div class="header-navigation-container">
         <div class="header-navigation-line">
             <a href="' . 'precheck.php' . '" class="header-navigation">' . (isset($LANG_INSTALL_JP) ? $LANG_INSTALL_JP[1] : 'Pre-Installation Check (in Japanese)') . '</a>&nbsp;&nbsp;&nbsp;
+            <a href="rescue.php" class="header-navigation">' . $LANG_INSTALL[109] . '</a>&nbsp;&nbsp;&nbsp;
             <a href="' . $LANG_INSTALL[87] . '" class="header-navigation">' . $LANG_INSTALL[1] . '</a>&nbsp;&nbsp;&nbsp;
         </div>
     </div>
@@ -1131,17 +1141,31 @@ if (INST_phpOutOfDate()) {
             // Files to check if writable
             $file_list = array( $_PATH['db-config.php'],
                                 $gl_path . 'data/',
+                                $gl_path . 'data/layout_cache/',
                                 $gl_path . 'logs/error.log',
                                 $_PATH['public_html/'] . 'siteconfig.php',
                                 $_PATH['public_html/'] . 'backend/geeklog.rss',
                                 $_PATH['public_html/'] . 'images/articles/',
                                 $_PATH['public_html/'] . 'images/topics/',
-                                $_PATH['public_html/'] . 'images/userphotos' );
+                                $_PATH['public_html/'] . 'images/userphotos',
+                                $_PATH['public_html/'] . 'filemanager/scripts/filemanager.config.js',
+                                $_PATH['public_html/'] . 'images/library/File/',
+                                $_PATH['public_html/'] . 'images/library/Flash/',
+                                $_PATH['public_html/'] . 'images/library/Image/',
+                                $_PATH['public_html/'] . 'images/library/Image/_thumbs/',
+                                $_PATH['public_html/'] . 'images/library/Image/icons/',
+                                $_PATH['public_html/'] . 'images/library/Media/',
+                                $_PATH['public_html/'] . 'images/_thumbs/',
+                                $_PATH['public_html/'] . 'images/_thumbs/articles/',
+                                $_PATH['public_html/'] . 'images/_thumbs/library/Image/',
+                                $_PATH['public_html/'] . 'images/_thumbs/userphotos/',
+			);
 
             if (!isset($_CONF['allow_mysqldump']) && $_DB_dbms == 'mysql') {
                 array_splice($file_list, 1, 0, $gl_path . 'backups/');
             }
-
+            $check_selinux = false;
+            $cmd_selinux = '';
             foreach ($file_list as $file) {
                 if (!is_writable($file)) {
                     if (is_file($file)) {
@@ -1150,7 +1174,16 @@ if (INST_phpOutOfDate()) {
                         $perm_should_be = '777';
                     }
                     $permission = sprintf("%3o", @fileperms($file) & 0777);
-                    $display_permissions    .= '<p><label class="' . $perms_label_dir . '"><code>' . $file . '</code></label>' . LB
+                    $check_perm = 0;
+                    for ($i=0; $i<strlen($permission); $i++) {
+                        if ($permission[$i] >= $perm_should_be[$i])
+                            $check_perm++;
+                    }
+                    if ($check_perm >= 3) {
+                        $check_selinux = true;
+                        $cmd_selinux .= $file . ' ';
+                    }
+                    $display_permissions    .= '<p class="clearboth"><label class="' . $perms_label_dir . '"><code>' . $file . '</code></label>' . LB
                                             . ' <span class="permissions-list">' . $LANG_INSTALL[12] . ' '. $perm_should_be .'</span> ('
                                             . $LANG_INSTALL[13] . ' ' . $permission . ')</p>' . LB ;
                     $chmod_string .= $file . ' ' ;
@@ -1159,11 +1192,18 @@ if (INST_phpOutOfDate()) {
             }
 
             $display_step = 1;
-
             /**
              * Display permissions, etc
              */
-            if ($num_wrong && (strtoupper(substr(PHP_OS, 0, 3)) !== 'WIN')) {
+            if ($check_selinux){
+                $display .= '<h1 class="heading">' . $LANG_INSTALL[101] . ' ' . $display_step . ' - ' . $LANG_INSTALL[97] . '</h1>' . LB;
+                $display .= $LANG_INSTALL[110];
+                $cmd = 'chcon -Rt httpd_user_rw_content_t '.$cmd_selinux;
+                $display .= '<p class="codeblock"><code>' . $cmd . LB 
+                    . '</code></p><br ' . XHTML . '>' . LB;
+                $display_step++;
+            }
+            else if ($num_wrong) {
                 // If any files have incorrect permissions.
 
                 $display .= '<h1 class="heading">' . $LANG_INSTALL[101] . ' ' . $display_step . ' - ' . $LANG_INSTALL[97] . '</h1>' . LB;
@@ -1183,7 +1223,7 @@ if (INST_phpOutOfDate()) {
                 // Also, list the auto-generated chmod command for advanced users
                 $display .= '<div class="file-permissions">' . LB
                     . $display_permissions . '</div>' . LB
-                    . '<h2>' . $LANG_INSTALL[98] . '</h2>' . LB
+                    . '<h2 class="clearboth">' . $LANG_INSTALL[98] . '</h2>' . LB
                     . '<p>' . $LANG_INSTALL[99] . '</p>' . LB
                     . '<p class="codeblock"><code>' . $chmod_string . LB 
                     . '</code></p><br ' . XHTML . '>' . LB;
@@ -1225,7 +1265,7 @@ if (INST_phpOutOfDate()) {
             // Show the "Select your installation method" buttons
             $upgr_class = ($LANG_DIRECTION == 'rtl') ? 'upgrade-rtl' : 'upgrade' ;
             $display .= '<h1 class="heading">' . $LANG_INSTALL[101] . ' ' . $display_step . ' - ' . $LANG_INSTALL[23] . '</h1>' . LB
-                . '<p><form action="index.php" method="GET">' . LB
+                . '<div><form action="index.php" method="get">' . LB
                 . '<input type="hidden" name="dbconfig_path" value="' . htmlspecialchars($dbconfig_path) . '"' . XHTML . '>' . LB
                 . '<input type="hidden" name="mode" value="' . htmlspecialchars($mode) . '"' . XHTML . '>' . LB
                 . '<input type="hidden" name="language" value="' . $language . '"' . XHTML . '>' . LB
@@ -1233,8 +1273,8 @@ if (INST_phpOutOfDate()) {
                 . '<input type="submit" name="install_type" class="button big-button" value="' . $LANG_INSTALL[24] . '"' . XHTML .'>' . LB
                 . '<input type="submit" name="install_type" class="button big-button" value="' . $LANG_INSTALL[25] . '"' . XHTML .'>' . LB
                 . '<input type="submit" name="install_type" class="button big-button" value="' . $LANG_INSTALL[16] . '"' . XHTML .'>' . LB
-                . '</form> </p> <br' . XHTML . '>' . LB;
-   
+                . '</form> </div> <br' . XHTML . '>' . LB;
+
         }
         break;
 
@@ -1306,6 +1346,7 @@ if (INST_phpOutOfDate()) {
 
         // Run the installation function
         INST_installEngine($mode, $step); 
+
         break;
 
     } // End switch ($mode)
