@@ -159,7 +159,8 @@ $LANG_INSTALL = array(
     106 => 'PostgreSQL',
     107 => 'Database Password is required for production environments.',
     108 => 'No Database Drivers found!',
-    109 => 'Emergency Rescue Tool'
+    109 => 'Emergency Rescue Tool',
+    110 => 'The permissions seem to be correct but the install script still cannot write to the Geeklog directory. If you happen to be on SELinux, make sure the httpd process has write permissions for the same, try this out:'
 );
 
 // +---------------------------------------------------------------------------+
