@@ -14,9 +14,9 @@
 // |          Mark Limburg       - mlimburg AT users DOT sourceforge DOT net   |
 // |          Jason Whittenburg  - jwhitten AT securitygeeks DOT com           |
 // |          Dirk Haun          - dirk AT haun-online DOT de                  |
-// |          Randy Kolenko      - randy AT nextide DOT ca				       |
-// |          Matt West          - matt AT mattdanger DOT net			       |
-// |		  Samuel Maung Stone - sam AT stonemicro DOT com                   |
+// |          Randy Kolenko      - randy AT nextide DOT ca                     |
+// |          Matt West          - matt AT mattdanger DOT net                  |
+// |          Samuel Maung Stone - sam AT stonemicro DOT com                   |
 // +---------------------------------------------------------------------------+
 // |                                                                           |
 // | This program is free software; you can redistribute it and/or             |
@@ -158,7 +158,9 @@ $LANG_INSTALL = array(
     105 => 'Sorry, but the admin directory path you entered does not appear to be correct. Please go back and try again.',
     106 => 'PostgreSQL',
     107 => 'Database Password is required for production environments.',
-    108 => 'No Database Drivers found!'
+    108 => 'No Database Drivers found!',
+    109 => 'Emergency Rescue Tool',
+    110 => 'The permissions seem to be correct but the install script still cannot write to the Geeklog directory. If you happen to be on SELinux, make sure the httpd process has write permissions for the same, try this out:'
 );
 
 // +---------------------------------------------------------------------------+
@@ -287,9 +289,7 @@ $LANG_BIGDUMP = array(
     8 => 'Processing file:',
     9 => 'Can\'t set file pointer behind the end of file.',
     10 => 'Can\'t set file pointer to offset: ',
-    11 => 'Stopped at the line ',
-    12 => '. At this place the current query is from csv file, but ',
-    13 => ' was not set.',
+    11 => 'There is no MySQL extension available in your PHP installation.',
     14 => 'Stopped at the line ',
     15 => '. At this place the current query includes more than ',
     16 => ' dump lines. That can happen if your dump file was created by some tool which doesn\'t place a semicolon followed by a linebreak at the end of each query, or if your dump contains extended inserts. Please read the BigDump FAQs for more information.',
@@ -349,6 +349,57 @@ $LANG_HELP = array(
     'plugin_upload' => 'Choose a plugin archive (in .zip, .tar.gz, or .tgz format) to upload and install.'
 );
 
+// +---------------------------------------------------------------------------+
+// rescue.php
+
+$LANG_RESCUE = array(
+    0 => 'Login successful',
+    1 => 'Geeklog Emergency Rescue Tool',
+    2 => 'Geeklog Install',
+    3 => 'Geeklog Emergency Rescue Tool',
+    4 => 'Do not forget to <strong>delete this {{SELF}} file and the install directory once you are done!</strong>  If other users guess the password, they can seriously harm your geeklog installation!',
+    5 => 'Status',
+    6 => 'You are attempting to access a secure section.  You can\'t proceed until you pass the security check.',
+    7 => 'In order to verify you, we require you to enter your database password.  This is the password that is stored in geeklog\'s db-config.php',
+    8 => 'Password',
+    9 => 'Verify Me',
+    10 => 'Password incorrect!',
+    11 => 'enabling ',
+    12 => 'disabling ',
+    13 => 'success ',
+    14 => 'error ',
+    15 => 'There was an error updating configs',
+    16 => 'Updating configs completed successfully',
+    17 => 'There was an error updating your password',
+    18 => 'Geeklog password request',
+    19 => 'Requested Password',
+    20 => 'Someone (hopefully you) has accessed the emergency password request form and a new password:"%s" for your account "%s" on %s, has been generated.',
+    21 => 'If it was not you, please check the security of your site. Make sure to remove the Emergency Rescue Form /admin/rescue.php',
+    22 => 'New password has been sent to the recorded email address',
+    23 => 'There was an error sending email with the subject: ',
+    24 => 'PHP Information',
+    25 => 'Return to main screen',
+    26 => 'System Information',
+    27 => 'PHP version',
+    28 => 'Geeklog version',
+    29 => 'Options',
+    30 => 'If you happen to install a plugin or addon that brings down your geeklog site, you can remedy the problem with the options below.',
+    31 => 'Enable/Disable Plugins',
+    32 => 'Enable/Disable Blocks',
+    33 => 'Edit Select $_CONF Values',
+    34 => 'Reset Admin Password',
+    35 => 'Here you can enable/disable any plugin that is currently installed on your geeklog website.',
+    36 => 'Select a plugin',
+    37 => 'Enable',
+    38 => 'Disable',
+    39 => 'Here you can enable/disable any block (except dynamic) that is currently installed on your geeklog website.',
+    40 => 'Select a block',
+    41 => 'Go',
+    42 => 'You can edit some key $_CONF options.',
+    43 => 'Here you can reset your geeklog root/admin password.',
+    44 => 'Email my password'
+);
+
 // which texts to use as labels, so they don't have to be translated again
 $LANG_LABEL = array(
     'site_name'      => $LANG_INSTALL[32],
