@@ -157,7 +157,9 @@ $LANG_INSTALL = array(
     105 => 'Der Pfad, den Du f&uuml;r das Admin-Verzeichnis eingegeben hast, scheint nicht korrekt zu sein. Bitte &uuml;berpr&uuml;fe Deine Eingabe und versuche es dann noch einmal.',
     106 => 'PostgreSQL',
     107 => 'F&uuml;r den produktiven Einsatz wird ein Datenbank-Passwort ben&ouml;tigt!',
-    108 => 'Keine Datenbank-Treiber gefunden!'
+    108 => 'Keine Datenbank-Treiber gefunden!',
+    109 => 'Emergency Rescue Tool',
+    110 => 'The permissions seem to be correct but the install script still cannot write to the Geeklog directory. If you happen to be on SELinux, make sure the httpd process has write permissions for the same, try this out:'
 );
 
 // +---------------------------------------------------------------------------+
@@ -346,6 +348,57 @@ $LANG_HELP = array(
     'plugin_upload' => 'W&auml;hle ein Plugin-Archiv (in den Formaten .zip, .tar.gz oder .tgz format) zum Hochladen und Installieren.'
 );
 
+// +---------------------------------------------------------------------------+
+// rescue.php
+
+$LANG_RESCUE = array(
+    0 => 'Login successful',
+    1 => 'Geeklog Emergency Rescue Tool',
+    2 => 'Geeklog Install',
+    3 => 'Geeklog Emergency Rescue Tool',
+    4 => 'Do not forget to <strong>delete this {{SELF}} file and the install directory once you are done!</strong>  If other users guess the password, they can seriously harm your geeklog installation!',
+    5 => 'Status',
+    6 => 'You are attempting to access a secure section.  You can\'t proceed until you pass the security check.',
+    7 => 'In order to verify you, we require you to enter your database password.  This is the password that is stored in geeklog\'s db-config.php',
+    8 => 'Password',
+    9 => 'Verify Me',
+    10 => 'Password incorrect!',
+    11 => 'enabling ',
+    12 => 'disabling ',
+    13 => 'success ',
+    14 => 'error ',
+    15 => 'There was an error updating configs',
+    16 => 'Updating configs completed successfully',
+    17 => 'There was an error updating your password',
+    18 => 'Geeklog password request',
+    19 => 'Requested Password',
+    20 => 'Someone (hopefully you) has accessed the emergency password request form and a new password:"%s" for your account "%s" on %s, has been generated.',
+    21 => 'If it was not you, please check the security of your site. Make sure to remove the Emergency Rescue Form /admin/rescue.php',
+    22 => 'New password has been sent to the recorded email address',
+    23 => 'There was an error sending email with the subject: ',
+    24 => 'PHP Information',
+    25 => 'Return to main screen',
+    26 => 'System Information',
+    27 => 'PHP version',
+    28 => 'Geeklog version',
+    29 => 'Options',
+    30 => 'If you happen to install a plugin or addon that brings down your geeklog site, you can remedy the problem with the options below.',
+    31 => 'Enable/Disable Plugins',
+    32 => 'Enable/Disable Blocks',
+    33 => 'Edit Select $_CONF Values',
+    34 => 'Reset Admin Password',
+    35 => 'Here you can enable/disable any plugin that is currently installed on your geeklog website.',
+    36 => 'Select a plugin',
+    37 => 'Enable',
+    38 => 'Disable',
+    39 => 'Here you can enable/disable any block (except dynamic) that is currently installed on your geeklog website.',
+    40 => 'Select a block',
+    41 => 'Go',
+    42 => 'You can edit some key $_CONF options.',
+    43 => 'Here you can reset your geeklog root/admin password.',
+    44 => 'Email my password'
+);
+
 // which texts to use as labels, so they don't have to be translated again
 $LANG_LABEL = array(
     'site_name'      => $LANG_INSTALL[32],
