@@ -56,11 +56,11 @@ $LANG_INSTALL = array(
     2 => 'The secure CMS.',
     3 => 'Geeklogをインストールする',
     4 => 'PHP %s以上が必要です',
-    5 => '残念ながらGeeklogをインストールするには最低でもPHP %sが必要です(現在のバージョンは ',
+    5 => 'Geeklogをインストールするには最低でもPHP %sが必要です(現在のバージョンは ',
     6 => ')。自分で<a href="http://www.php.net/downloads.php">PHPをバージョンアップする</a>か、ホスティング会社に依頼してください。',
     7 => 'Geeklogファイルが見つかりません',
     8 => 'Geeklogの重要なファイルが見つかりません。既定の位置から移動させていると思われます。下のテキストボックスにファイルのパスを入力してください。:',
-    9 => 'Geeklogへようこそ!　Geeklogを選んでいただき、ありがとうございます。',
+    9 => 'Geeklogへようこそ!  Geeklogを選んでいただき、ありがとうございます。',
     10 => 'ファイル/ディレクトリ',
     11 => 'パーミッション',
     12 => '推奨値',
@@ -68,16 +68,16 @@ $LANG_INSTALL = array(
     14 => '',
     15 => 'Geeklogのヘッドライン(RSS)が無効になっています。<code>backend</code>ディレクトリのテストを行いませんでした。',
     16 => '移行',
-    17 => 'ユーザ写真が無効になっています。<code>userphotos</code>ディレクトリのテストを行いませんでした。',
+    17 => 'ユーザー写真が無効になっています。<code>userphotos</code>ディレクトリのテストを行いませんでした。',
     18 => '記事に画像を添付する機能が無効になっています。<code>articles</code>ディレクトリのテストを行いませんでした。',
     19 => 'Geeklogでは、いくつかのファイルとディレクトリがWebサーバーから書き込める必要があります。以下は、変更する必要のあるファイルとディレクトリの一覧です。',
     20 => '警告!',
-    21 => '以下のエラーが解消されるまで、インストールできません。先に必要な変更を行ってください。',
+    21 => '以下のエラーを解消するまで、インストールできません。先に必要な変更を行ってください。',
     22 => '不明',
     23 => 'インストールの種類を選択してください:',
     24 => '新規インストール',
     25 => 'アップグレード',
-    26 => '変更できませんでした：',
+    26 => '変更できませんでした: ',
     27 => '。ファイルはWebサーバーから書き込みできますか?',
     28 => 'siteconfig.php。このファイルはWebサーバーから書き込みできますか?',
     29 => 'Geeklog Site',
@@ -87,12 +87,12 @@ $LANG_INSTALL = array(
     33 => 'サイトのスローガン',
     34 => 'データベースの種類',
     35 => 'MySQL',
-    36 => 'MySQL（InnoDBテーブルをサポート）',
+    36 => 'MySQL(InnoDBテーブルをサポート)',
     37 => 'Microsoft SQL',
     38 => 'エラー',
     39 => 'データベースのホスト名',
     40 => 'データベース名',
-    41 => 'データベースのユーザ名',
+    41 => 'データベースのユーザー名',
     42 => 'データベースのパスワード',
     43 => 'データベースの接頭子',
     44 => 'オプションの設定',
@@ -103,15 +103,15 @@ $LANG_INSTALL = array(
     49 => 'サイトのNo-Reply Email',
     50 => 'インストール',
     51 => '少なくともMySQL %sが必要です',
-    52 => '残念ながら、Geeklogをインストールするには最低でもMySQL %sが必要です(現在のバージョンは ',
+    52 => 'Geeklogをインストールするには最低でもMySQL %sが必要です(現在のバージョンは ',
     53 => ')。自分で<a href="http://dev.mysql.com/downloads/mysql/">MySQLをアップグレードする</a>か、ホスティング会社に依頼してください。',
     54 => 'データベース情報が不正確です',
-    55 => '残念ながら入力したデータベース情報が不正確です。戻ってやり直してください。',
+    55 => '入力したデータベース情報が不正確です。戻ってやり直してください。',
     56 => 'データベースに接続できません',
-    57 => '残念ながら指定されているデータベースが見つかりません。データベースが存在しないか、綴り（大文字小文字）が違うのでしょう。戻ってやり直してください。',
+    57 => '指定しているデータベースが見つかりません。データベースが存在しないか、綴り(大文字小文字)が違うのでしょう。戻ってやり直してください。',
     58 => '。このファイルはWebサーバーから書き込みできますか?',
     59 => '注意:',
-    60 => 'お使いのMySQLのバージョンではInnoDBテーブルはサポートされていません。InnoDBサポートなしで、インストールを続けますか?',
+    60 => 'お使いのMySQLのバージョンではInnoDBテーブルをサポートしていません。InnoDBサポートなしで、インストールを続けますか?',
     61 => '戻る',
     62 => '次へ',
     63 => 'インストール済みのGeeklogのデータベースが既に存在しています。既存のGeeklogデータベースを上書きして新規インストールを行うことはできません。続けるには、次のどちらかを行ってください:',
@@ -119,47 +119,49 @@ $LANG_INSTALL = array(
     65 => '下の"アップグレード"オプションを選択することで、(Geeklogの新バージョンへ)データベースのアップグレードを行います。',
     66 => '再試行',
     67 => 'Geeklogのデータベースを設定中にエラーが発生しました',
-    68 => 'データベースが空ではありません。データベース中のテーブルを全て削除してから、やり直してください。',
+    68 => 'データベースが空ではありません。データベース中のテーブルをすべて削除してから、やり直してください。',
     69 => 'Geeklogをアップグレード',
     70 => '始める前に現在のGeeklogのデータベースのバックアップを行ってください。インストール・スクリプトはGeeklogのデータベースを変更するので、失敗してアップグレードをやり直すには、オリジナルのデータベースのバックアップが必要になります。警告しましたよ!',
-    71 => '現在のGeeklogのバージョンを下で正確に選択してください。インストール・スクリプトは入力されたバージョンから少しずつアップグレードしていきます（つまり、任意の古いバージョンから次のバージョンへアップグレードできます:',
-    72 => '）。',
+    71 => '現在のGeeklogのバージョンを下で正確に選択してください。インストール・スクリプトは入力したバージョンから少しずつアップグレードしていきます(つまり、任意の古いバージョンから次のバージョンへアップグレードできます:',
+    72 => ')。',
     73 => 'インストール・スクリプトはGeeklogのベータ版やリリース候補(RC)版からのアップグレードは行いません。',
     74 => 'データベースは既に最新の状態になっています!',
     75 => 'データベースは既に最新の状態になっているようです。以前、アップグレードを実行したことがあるのでしょう。再びアップグレードを実行する必要があるなら、データベースのバックアップから復元を行ってからにしてください。',
     76 => '現在のGeeklogのバージョンを選択してください',
-    77 => 'インストーラは現在のGeeklogのバージョンを判定できませんでした。下のリストから選択してください:',
+    77 => 'インストーラーは現在のGeeklogのバージョンを判定できませんでした。下のリストから選択してください:',
     78 => 'アップグレードエラー',
     79 => 'Geeklogのアップグレード中にエラーが発生しました。',
     80 => '変更',
     81 => 'ちょっと待って!',
-    82 => '下に列挙されたファイルのパーミッションを必ず変更する必要があります。変更するまでGeeklogをインストールできません。',
+    82 => '下に列挙したファイルのパーミッションを必ず変更する必要があります。変更するまでGeeklogをインストールできません。',
     83 => 'インストールエラー',
     84 => 'パス "',
     85 => '" は正しくありません。戻ってやり直してください。',
     86 => '言語',
     87 => 'http://www.geeklog.jp/forum/index.php?forum=6',
-    88 => '以下のファイルを含むディレクトリに変更してください：',
+    88 => '以下のファイルを含むディレクトリに変更してください: ',
     89 => '現在のバージョン:',
     90 => 'データベースは空?',
-    91 => 'データベースが空のままか、入力してデータベースの情報が不正確なようです。ひょっとすると、アップグレードではなく、新規インストールするつもりだったのではないでしょうか?　戻ってやり直してください。',
+    91 => 'データベースが空のままか、入力してデータベースの情報が不正確なようです。もしかするとアップグレードではなく、新規インストールするつもりだったのではないでしょうか?  戻ってやり直してください。',
     92 => 'UTF-8を使用する',
     93 => '成功',
     94 => 'パスのヒント:',
     95 => 'インストールスクリプトファイルへの完全なパスはこちらです:',
-    96 => 'インストーラはここで %s を探しています:',
+    96 => 'インストーラーはここで %s を探しています:',
     97 => 'パーミッション設定',
-    98 => 'アドバンストユーザ',
-    99 => 'コマンドライン (SSH) が使えるなら、Webサーバーにアクアセスしてください。shellを使えば、以下のコマンドのコピー・ペーストで簡単に実行できます。:',
+    98 => 'アドバンストユーザー',
+    99 => 'コマンドライン (SSH) が使えるなら、Webサーバーにアクセスしてください。shellを使えば、以下のコマンドのコピー・ペーストで簡単に実行できます。:',
     100 => '無効なモードを指定',
     101 => 'ステップ',
     102 => 'コンフィギュレーションモード入力',
-    103 => '＋追加プラグインの設定',
+    103 => '+追加プラグインの設定',
     104 => '不正な管理者パス',
     105 => '入力した管理者のディレクトリパスは不正確でした。もう一度やり直してください。',
     106 => 'PostgreSQL',
     107 => 'データベースのパスワードが必要です。',
-    108 => 'データベースドライバーがありません!'
+    108 => 'データベースドライバーがありません!',
+    109 => '緊急レスキューツール',
+    110 => 'The permissions seem to be correct but the install script still cannot write to the Geeklog directory. If you happen to be on SELinux, make sure the httpd process has write permissions for the same, try this out:'
 );
 
 // +---------------------------------------------------------------------------+
@@ -170,22 +172,22 @@ $LANG_SUCCESS = array(
     1 => 'Geeklog ',
     2 => ' のインストールが完了しました!',
     3 => 'おめでとうございます。Geeklogの',
-    4 => 'に成功しました。少し時間をさいて、以下の情報をご覧ください。',
+    4 => 'に成功しました。',
     5 => '新しいGeeklogサイトにログインするには、次のアカウントを使用してください:',
-    6 => 'ユーザ名:',
+    6 => 'ユーザー名:',
     7 => 'Admin',
     8 => 'パスワード:',
     9 => 'password',
     10 => 'セキュリティ警告',
     11 => '次の',
-    12 => 'つのことを忘れずに行ってください',
+    12 => '件を必ず実行してください',
     13 => 'installディレクトリを削除またはリネームする:',
-    14 => '変更する',
+    14 => '',
     15 => 'アカウントのパスワードを変更する。',
     16 => 'パーミッションを設定する:',
     17 => 'と',
     18 => 'のパーミッションを次のものに変更する:',
-    19 => '<strong>注意:</strong> セキュリティモデルを変更したので、新しいサイトの管理権限を持ったアカウントを作成しました。ユーザ名は <strong>NewAdmin</strong> で、パスワードは <strong>password</strong> です。',
+    19 => '<strong>注意:</strong> セキュリティモデルを変更したので、新しいサイトの管理権限を持ったアカウントを作成しました。ユーザー名は <strong>NewAdmin</strong> で、パスワードは <strong>password</strong> です。',
     20 => 'インストール',
     21 => 'アップグレード',
     22 => '移行'
@@ -195,10 +197,10 @@ $LANG_SUCCESS = array(
 // migrate.php
 
 $LANG_MIGRATE = array(
-    0 => 'バックアップファイルに"DROP TABLE"が追加されている場合、同じ名前のテーブルがあれば上書きされます。',
+    0 => 'バックアップファイルに"DROP TABLE"を追加している場合、同じ名前のテーブルを上書きします。',
     1 => '実行する前に',
-    2 => '以前のプラグインが新しいサーバーにコピーされていることを確認してください。',
-    3 => '画像ディレクトリ<code>public_html/images/articles/</code>、<code>public_html/images/topics/</code>および<code>public_html/images/userphotos/</code>が、新しいサーバーに移行されていることを確認してください。',
+    2 => '以前のプラグインを新しいサーバーにコピーしていることを確認してください。',
+    3 => '画像ディレクトリ<code>public_html/images/articles/</code>、<code>public_html/images/topics/</code>および<code>public_html/images/userphotos/</code>を、新しいサーバーに移行していることを確認してください。',
     4 => '<strong>1.5.0</strong>以前のバージョンからアップグレードする場合は、<tt>config.php</tt>もコピーしてください。移行後、これを参照して設定できます。',
     5 => 'アップグレードの場合、テーマをそのままアップロードしないでください。テーマを完全に移行するまでは、付属のデフォルトテーマを活用してください。',
     6 => 'バックアップファイルを選択',
@@ -213,8 +215,8 @@ $LANG_MIGRATE = array(
     15 => 'バックアップディレクトリが書き込み可能になっていません。パーミッションを777に設定してください。',
     16 => '移行',
     17 => 'バックアップファイルからの移行',
-    18 => 'バックアップファイルが選択されませんでした。',
-    19 => '保存されませんでした',
+    18 => 'バックアップファイルを選択していません。',
+    19 => '保存できませんでした',
     20 => ' へ ',
     21 => 'ファイル',
     22 => 'が既にサーバーにあります。指定したファイルに置き換えますか?',
@@ -234,11 +236,11 @@ $LANG_MIGRATE = array(
     36 => 'いつでもこれらを修正できます',
     37 => '移行完了',
     38 => '移行プロセスは完了しました。次の問題があるので対応してください:',
-    39 => 'PEARが見つかりません。残念ながらPEARがない場合はバックアップの圧縮形式を処理できません。',
+    39 => 'PEARが見つかりません。PEARがない場合はバックアップの圧縮形式を処理できません。',
     40 => '圧縮ファイル \'%s\' には、SQLファイルが含まれていません。',
     41 => 'データベース \'%s\' におけるバックアップファイルの解凍でエラーが発生しました。',
     42 => 'バックアップファイル \'%s\' が消えました...',
-    43 => 'インポートアボート: ファイル \'%s\'がSQLダンプで表示されません。',
+    43 => 'インポートの中止: ファイル \'%s\'はSQLダンプはないようです。',
     44 => '致命的なエラー: データベースはインポートに失敗しました。継続できません。',
     45 => 'データベースのバージョンがわかりません。手動でアップデートしてください。',
     46 => '',
@@ -256,7 +258,7 @@ $LANG_PLUGINS = array(
     3 => '検索オプションのプラグインやアドオンコンポーネントは、新しい機能を活用した記事の内部サービスを提供しています。デフォルトでは、検索オプションでは、インストールしたい場合は、いくつか便利なプラグインが含まれています。',
     4 => 'また、追加のプラグインをアップロードすることができます。',
     5 => 'アップロードしたファイルは ZIP または GZip 圧縮形式のプラグインファイルではありません。',
-    6 => 'アップロードしたプラグインはすでに存在しています!',
+    6 => 'アップロードしたプラグインは既に存在しています!',
     7 => '成功!',
     8 => '%s プラグインのアップロードに成功しました。',
     9 => 'プラグインアップロード',
@@ -284,10 +286,10 @@ $LANG_BIGDUMP = array(
     4 => 'シーク不可 ',
     5 => 'オープン不可 ',
     6 => ' インポート。',
-    7 => '予期しないエラー：開始位置とオフセット位置が数値ではない値になっています',
+    7 => '予期しないエラー: 開始位置とオフセット位置が数値ではない値になっています',
     8 => '作業中 ファイル:',
-    9 => 'ファイルの末尾にファイルポインタを移動できません。',
-    10 => 'ファイルポインタ移動不可:',
+    9 => 'ファイルの末尾にファイルポインターを移動できません。',
+    10 => 'ファイルポインター移動不可:',
     11 => 'There is no MySQL extension available in your PHP installation.',
     14 => '中止した行版:',
     15 => '。このクエリには',
@@ -295,8 +297,8 @@ $LANG_BIGDUMP = array(
     17 => 'エラーの発生した行番号:',
     18 => 'クエリ:',
     19 => 'MySQL:',
-    20 => 'ファイルポインタオフセットを読み込めません。',
-    21 => 'gzip形式で圧縮されているファイルが利用できない',
+    20 => 'ファイルポインターのオフセットを読み込めません。',
+    21 => 'gzip形式で圧縮したファイルでは利用できません',
     22 => '進捗状況',
     23 => 'このデータベースの移行が正常に完了しました!',
     24 => '待機中 ',
@@ -313,14 +315,14 @@ $LANG_BIGDUMP = array(
 // Error Messages
 
 $LANG_ERROR = array(
-    0 => 'アップロードしたファイルは、php.iniで指定された制限 upload_max_filesize を超えています。他の方法、たとえばFTPでアップロードしてください。',
+    0 => 'アップロードしたファイルは、php.iniで指定した制限 upload_max_filesize を超えています。他の方法、たとえばFTPでアップロードしてください。',
     1 => 'アップロードしたファイルのサイズは、HTMLのフォームで指定したMAX_FILE_SIZEを超えています。バックアップファイルをFTPなどの他の方法でアップロードしてください。',
-    2 => 'ファイルの一部しかアップロードされませんでした。',
-    3 => 'ファイルはアップロードされませんでした。',
-    4 => '一時フォルダがありません。',
+    2 => 'ファイルの一部だけしかアップロードできませんでした。',
+    3 => 'アップロードしたファイルはありません。',
+    4 => '一時フォルダーがありません。',
     5 => 'ディスク書き込みエラーです。',
     6 => '拡張子制限により、アップロードを中止しました。',
-    7 => 'アップロードするファイルはphp.iniで指定されたpost_max_sizeを超えています。データベースをFTPなどでアップロードしてください。',
+    7 => 'アップロードするファイルはphp.iniで指定したpost_max_sizeを超えています。データベースをFTPなどでアップロードしてください。',
     8 => 'エラー',
     9 => 'データベース接続エラー:',
     10 => 'データベースの設定をチェックしてください。'
@@ -333,21 +335,72 @@ $LANG_HELP = array(
     0 => 'インストールヘルプ',
     'site_name' => 'サイト名を入力します。後から変更することもできます。',
     'site_slogan' => 'サイトのスローガンを入力します。後から変更することもできます。',
-    'db_type' => 'データベースの種類を入力します。MySQL, MySQL(InnoDB), Microsoft SQL Serverの中から選びます。</p><p class="indent"><strong>注意:</strong> 大規模なサイトでは、InnoDBテーブルを使用すれば、パフォーマンスが改善されるかもしれませんが、バックアップを行うのが難しくなります。',
+    'db_type' => 'データベースの種類を入力します。MySQL, MySQL(InnoDB), Microsoft SQL Serverの中から選びます。</p><p class="indent"><strong>注意:</strong> 大規模なサイトではInnoDBテーブルを使用すると、パフォーマンスが改善するかもしれませんが、バックアップを行うのが難しくなります。',
     'db_host' => 'ホスト名を入力します。',
     'db_name' => 'データベース名を入力します。',
-    'db_user' => 'データベースのユーザ名（アカウント）を入力します。',
+    'db_user' => 'データベースのユーザー名(アカウント)を入力します。',
     'db_pass' => 'パスワードを入力します。',
     'db_prefix' => 'テーブル名の接頭子を入力します。データベース内に他にテーブルがなければ、既定値を変更する必要はありません。',
     'site_url' => 'サイトのURLを入力します。',
     'site_admin_url' => 'AdminディレクトリのURLを入力します。',
     'site_mail' => 'サイト管理者のEmailアドレスを入力します。',
-    'noreply_mail' => 'サイト管理者のNo-Reply Email（返信を受け付けないEmailアドレス）を入力します。',
+    'noreply_mail' => 'サイト管理者のNo-Reply Email(返信を受け付けないEmailアドレス)を入力します。',
     'utf8' => 'サイトのデフォルト言語としてUTF-8を使用するかどうかを指示します。多言語サイトを作成するなら、チェックを入れることをお勧めします。',
     'migrate_file' => '移行するバックアップファイル(*.sql)を選択します。"backups"ディレクトリ内のファイルから、あるいはあなたのコンピュータからファイルをアップロードできます。または、データベースの現在の内容を移行することもできます。',
     'plugin_upload' => 'アップロードするプラグインの圧縮ファイル(.zip, .tar.gz, .tgzファーマット)を選んでインストールしてください。'
 );
 
+// +---------------------------------------------------------------------------+
+// rescue.php
+
+$LANG_RESCUE = array(
+     0 => 'ログインに成功しました。',
+     1 => 'Geeklog緊急レスキューツール',
+     2 => 'インストーラーへ',
+     3 => 'Geeklog緊急レスキューツール',
+    4 => '終了したら、<strong>必ずこのファイル( {{SELF}} )とinstallディレクトリを削除してください!</strong>  他のユーザーがパスワードの推測に成功した場合、インストールしているGeeklogが重大な被害を被る可能性があります。',
+     5 => '状態',
+     6 => 'これからセキュリティで保護したセクションにアクセスします。セキュリティの検査に合格しなけいと先に進めません。',
+     7 => '本人確認のために、データベースのパスワードを入力する必要があります。このパスワードはGeeklogの"非公開領域/db-config.php"に保存します。',
+     8 => 'パスワード',
+     9 => '確認する',
+    10 => 'パスワードが不正です!',
+    11 => '有効化 ',
+    12 => '無効化 ',
+    13 => '成功 ',
+    14 => 'エラー ',
+    15 => '設定を更新する際にエラーが発生しました。',
+    16 => '設定を更新しました。',
+    17 => 'パスワードを更新する際にエラーが発生しました。',
+    18 => 'Geeklogパスワードリクエスト',
+    19 => 'パスワードをリクエストしました',
+    20 => '誰か(あなたであれば幸いです)がGeeklog緊急レスキューツールの緊急パスワードリクエストフォームにアクセスしました。新しいパスワード "%s" (アカウント "%s" サーバー %s)を作成しました。',
+    21 => 'リクエストした覚えがない場合、サイトのセキュリティを確認してください。緊急レスキューツール "/admin/install/rescue.php" を忘れずに削除してください。',
+    22 => '新しいパスワードを記録しているメールアドレスに送りました。',
+    23 => 'メールを送る際にエラーが発生しました。件名: ',
+    24 => 'PHP情報',
+    25 => 'メイン画面へ戻る',
+    26 => 'システム情報',
+    27 => 'PHPバージョン',
+    28 => 'Geeklogバージョン',
+    29 => 'オプション',
+    30 => 'サイトに不具合を引き起こすプラグインやアドオンをインストールしてしまった場合、以下のオプションで問題点を修正できます。',
+    31 => 'プラグインの有効化/無効化',
+    32 => 'ブロックの有効化/無効化',
+    33 => '主要な$_CONF変数の編集',
+    34 => '管理者パスワードのリセット',
+    35 => 'このサイトに現在インストールしているプラグインを有効/無効にできます。',
+    36 => 'プラグインを選択してください',
+    37 => '有効化',
+    38 => '無効化',
+    39 => 'このサイトに現在インストールしているブロックを有効/無効にできます。',
+    40 => 'ブロックを選択してください',
+    41 => '実行',
+    42 => '主要な$_CONF変数を編集できます。',
+    43 => 'Geeklogのroot/adminパスワードをリセットできます。',
+    44 => 'パスワードをメールで送信する'
+);
+
 // which texts to use as labels, so they don't have to be translated again
 $LANG_LABEL = array(
     'site_name'      => $LANG_INSTALL[32],
@@ -367,8 +420,4 @@ $LANG_LABEL = array(
     'plugin_upload'  => $LANG_PLUGINS[10]
 );
 
-$LANG_INSTALL_JP = array(
-    1 => '日本語環境のインストール前チェック',
-);
-
 ?>
