@@ -56,7 +56,7 @@ if (!defined('VERSION')) {
     * This constant defines Geeklog's version number. It will be written to
     * siteconfig.php and the database (in the latter case minus any suffix).
     */
-    define('VERSION', '1.8.1');
+    define('VERSION', '2.1.0');
 }
 if (!defined('XHTML')) {
     define('XHTML', ' /');
@@ -65,15 +65,9 @@ if (!defined('SUPPORTED_PHP_VER')) {
     define('SUPPORTED_PHP_VER', '5.2.0');
 }
 if (!defined('SUPPORTED_MYSQL_VER')) {
-    define('SUPPORTED_MYSQL_VER', '4.0.18');
+    define('SUPPORTED_MYSQL_VER', '4.1.3');
 }
 
-$_REQUEST = array_merge($_GET, $_POST);
-
-// this is not ideal but will stop PHP 5.3.0ff from complaining ...
-$system_timezone = @date_default_timezone_get();
-date_default_timezone_set($system_timezone);
-
 $language = INST_getLanguage();
 // Include the language file
 require_once 'language/' . $language . '.php'; 
@@ -89,6 +83,34 @@ if ($LANG_DIRECTION == 'rtl') {
     $perms_label_dir = 'perms-label-left';
 }
 
+// Initial PHP version check for PHP-4.x and 5.0.x, which don't have
+// date_default_timezone_get() (introduced as of PHP-5.1.0)
+if (version_compare(PHP_VERSION, '5.1.0', '<')) {
+    $output = '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" '
+            . '"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">' . LB
+            . '<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">' . LB
+            . '<head>' . LB
+            . '  <meta http-equiv="Content-Type" content="text/html;charset='
+            . $LANG_CHARSET . '" />' . LB
+            . '  <title>Geeklog - The secure CMS.</title>' . LB
+            . '</head>' . LB
+            . '<body dir="' . $LANG_DIRECTION . '">' . LB
+            . '<h1>' . $LANG_INSTALL[3] . '</h1>' . LB
+            . '<p>' . sprintf($LANG_INSTALL[5], '<strong>' . SUPPORTED_PHP_VER . '</strong>')
+            . '<strong>' . PHP_VERSION . '</strong>' . $LANG_INSTALL[6] . '</p>' . LB
+            . '</body>' . LB
+            . '</html>' . LB;
+    header('Content-Type: text/html; charset=' . $LANG_CHARSET);
+    echo $output;
+    die(1);
+}
+
+// this is not ideal but will stop PHP 5.3.0ff from complaining ...
+$system_timezone = @date_default_timezone_get();
+date_default_timezone_set($system_timezone);
+
+$_REQUEST = array_merge($_GET, $_POST);
+
 // Before we begin, check if an uploaded file exceeds PHP's post_max_size
 if (isset($_SERVER['CONTENT_LENGTH'])) {
 
@@ -560,7 +582,7 @@ function INST_getUploadError($mFile)
         $mRetval = false;
 
     }
-    
+
     return $mRetval;
 }
 
@@ -788,8 +810,8 @@ function INST_pluginAutoinstall($plugin, $inst_parms, $verbose = true)
                 COM_errorLog("Attempting to create '$name' group", 1);
             }
 
-            $grp_name = addslashes($name);
-            $grp_desc = addslashes($desc);
+            $grp_name = DB_escapeString($name);
+            $grp_desc = DB_escapeString($desc);
             DB_query("INSERT INTO {$_TABLES['groups']} (grp_name, grp_descr) VALUES ('$grp_name', '$grp_desc')", 1);
             if (DB_error()) {
                 COM_errorLog('Error creating plugin group', 1);
@@ -825,9 +847,6 @@ function INST_pluginAutoinstall($plugin, $inst_parms, $verbose = true)
 
         foreach ($_SQL as $sql) {
             $sql = str_replace('#group#', $admin_group_id, $sql);
-            if ($use_innodb) {
-                $sql = str_replace('MyISAM', 'InnoDB', $sql);
-            }
             DB_query($sql);
             if (DB_error()) {
                 COM_errorLog('Error creating plugin table', 1);
@@ -852,8 +871,8 @@ function INST_pluginAutoinstall($plugin, $inst_parms, $verbose = true)
         }
 
         foreach ($features as $feature => $desc) {
-            $ft_name = addslashes($feature);
-            $ft_desc = addslashes($desc);
+            $ft_name = DB_escapeString($feature);
+            $ft_desc = DB_escapeString($desc);
             DB_query("INSERT INTO {$_TABLES['features']} (ft_name, ft_descr) "
                      . "VALUES ('$ft_name', '$ft_desc')", 1);
             if (DB_error()) {
@@ -913,7 +932,7 @@ function INST_pluginAutoinstall($plugin, $inst_parms, $verbose = true)
             if (DB_error()) {
                 COM_errorLog('Error adding plugin default data', 1);
                 PLG_uninstall($plugin);
-            
+
                 return false;
             }
         }
@@ -1031,6 +1050,9 @@ function INST_fixPathsAndUrls($path, $path_html, $site_url, $site_admin_url)
     if (! file_exists($_CONF['path_images'] . 'articles')) {
         $config->set('path_images', $path_html . 'images/');
     }
+    if (! file_exists($_CONF['path_editors'] . 'ckeditor')) {
+        $config->set('path_editors', $path_html . 'editors/');
+    }
     if (substr($_CONF['rdf_file'], strlen($path_html)) != $path_html) {
         // this may not be correct but neither was the old value apparently ...
         $config->set('rdf_file', $path_html . 'backend/geeklog.rss');
@@ -1042,7 +1064,7 @@ function INST_fixPathsAndUrls($path, $path_html, $site_url, $site_admin_url)
         // if we had to fix the site's URL, chances are that cookie domain
         // and path are also wrong and the user won't be able to log in
         $config->set('cookiedomain', '');
-        $config->set('cookie_path', '/');
+        $config->set('cookie_path', INST_guessCookiePath($site_url));
     }
     if (! empty($site_admin_url) &&
             ($_CONF['site_admin_url'] != $site_admin_url)) {
@@ -1186,7 +1208,7 @@ function INST_setVersion($siteconfig_path)
         $v[2] = (int) $v[2];
         $version = implode('.', $v);
     }
-    $version = addslashes($version);
+    $version = DB_escapeString($version);
 
     DB_change($_TABLES['vars'], 'value', $version, 'name', 'database_version');
 }
@@ -1257,6 +1279,14 @@ function INST_listOfSupportedDBs($gl_path, $selected_dbtype, $list_innodb = fals
         if (file_exists($gl_path . '/sql/' . $prefix . '_tableanddata.php') &&
                 file_exists($gl_path . '/system/databases/' . $prefix
                                      . '.class.php')) {
+            if ($prefix == 'mysql') {
+                // check that the MySQLi driver file is also there so we
+                // don't have to check for it every time at runtime
+                if (! file_exists($gl_path . '/system/databases/'
+                                           . 'mysqli.class.php')) {
+                    continue;
+                }
+            }
             $retval .= '<option value="' . $dbname . '"';
             if (! function_exists($info['fn'])) {
                 $retval .= ' disabled="disabled"';
@@ -1302,4 +1332,128 @@ function INST_dbPasswordCheck($site_url, $db)
     }
 }
 
+/**
+* Returns a cookie path for a site URL
+*
+* @param   string  $site_url    site URL
+* @return  string               a cookie path
+*/
+function INST_guessCookiePath($site_url)
+{
+    $retval = '/';
+
+    if (preg_match('|(^https?://[^/]+)|i', $site_url, $match)) {
+        $path = substr($site_url, strlen($match[1]));
+
+        if (($path !== '') AND ($path !== FALSE)) {
+            $retval = $path;
+
+            if (substr($retval, -1) !== '/') {
+                $retval .= '/';
+            }
+        }
+    }
+
+    return $retval;
+}
+
+/**
+* Returns a cleaned string
+*
+* @param   string  $str
+* @return  string
+*/
+function INST_cleanString($str)
+{
+    $str = preg_replace('/[[:cntrl:]]/', '', $str);
+    $str = strip_tags($str);
+
+    return $str;
+}
+
+function INST_clearCacheDirectories($path, $needle = '')
+{
+    if ( $path[strlen($path)-1] != '/' ) {
+        $path .= '/';
+    }
+    if ($dir = @opendir($path)) {
+        while ($entry = readdir($dir)) {
+            if ($entry == '.' || $entry == '..' || is_link($entry) || $entry == '.svn' || $entry == 'index.html') {
+                continue;
+            } elseif (is_dir($path . $entry)) {
+                INST_clearCacheDirectories($path . $entry, $needle);
+                @rmdir($path . $entry);
+            } elseif (empty($needle) || strpos($entry, $needle) !== false) {
+                @unlink($path . $entry);
+            }
+        }
+        @closedir($dir);
+    }
+}
+
+
+function INST_clearCache($plugin='')
+{
+    global $_CONF;
+
+    if (!empty($plugin)) {
+        $plugin = '__' . $plugin . '__';
+    }
+
+    INST_clearCacheDirectories($_CONF['path'] . 'data/layout_cache/', $plugin);
+    INST_clearCacheDirectories($_CONF['path'] . 'data/layout_css/', $plugin);
+}
+
+function INST_checkCacheDir($path,$template,$classCounter)
+{
+    $permError = 0;
+
+    // special test to see if existing cache files exist and are writable...
+    if ( $dh = @opendir($path) ) {
+        while (($file = readdir($dh)) !== false ) {
+            if ( $file == '.' || $file == '..' || $file == '.svn') {
+                continue;
+            }
+            if ( is_dir($path.$file) ) {
+                $rc = INST_checkCacheDir($path.$file.'/',$template,$classCounter);
+                if ( $rc > 0 ) {
+                    $permError = 1;
+                }
+            } else {
+                $ok = INST_isWritable($path.$file);
+                if ( !$ok ) {
+                    $template->set_var('location',$path.$file);
+                    $template->set_var('status', $ok ? '<span class="yes">OK</span>' : '<span class="Unwriteable">NOT WRITABLE</span>');
+                    $template->set_var('rowclass',($classCounter % 2)+1);
+                    $classCounter++;
+                    $template->parse('perm','perms',true);
+                    if  ( !$ok ) {
+                        $permError = 1;
+                    }
+                }
+            }
+        }
+        closedir($dh);
+    }
+    return $permError;
+}
+
+/**
+ * Replaces all newlines in a string with <br> or <br />,
+ * depending on the detected setting.  Ported from "lib-common.php"
+ * 
+ * @param    string    $string  The string to modify
+ * @return   string             The modified string
+ */
+function INST_nl2br($string)
+{
+    if (! defined('XHTML')) {
+        define('XHTML', '');
+    }
+
+    $replace = '<br' . XHTML . '>';
+    $find = array("\r\n", "\n\r", "\r", "\n");
+    return str_replace($find, $replace, $string);
+}
+
 ?>
