@@ -49,9 +49,8 @@ $display = '';
 
 // Make sure user has access to this page
 if (! SEC_hasRights('user.mail')) {
-    $display .= COM_siteHeader('menu', $MESSAGE[30])
-             . COM_showMessageText($MESSAGE[29], $MESSAGE[30])
-             . COM_siteFooter();
+    $display .= COM_showMessageText($MESSAGE[29], $MESSAGE[30]);
+    $display = COM_createHTMLDocument($display, array('pagetitle' => $MESSAGE[30]));
     COM_accessLog("User {$_USER['username']} tried to illegally access the mail administration screen.");
     COM_output($display);
     exit;
@@ -296,8 +295,6 @@ function send_messages($vars)
 
 // MAIN
 
-$display .= COM_siteHeader('menu', $LANG31[1]);
-
 if (isset($_POST['mail']) && ($_POST['mail'] == 'mail') && SEC_checkToken()) {
     $display .= send_messages($_POST);
 } else {
@@ -305,7 +302,7 @@ if (isset($_POST['mail']) && ($_POST['mail'] == 'mail') && SEC_checkToken()) {
     $display .= display_mailform();
 }
 
-$display .= COM_siteFooter();
+$display = COM_createHTMLDocument($display, array('pagetitle' => $LANG31[1]));
 
 COM_output($display);
 
