@@ -43,179 +43,49 @@ require_once $_CONF['path_system'] . 'lib-comment.php';
 // the data being passed in a POST operation
 // echo COM_debug($_POST);
 
-// this defines the amount of icons displayed next to another in the CC-block
-define ('ICONS_PER_ROW', 6);
 
-/**
-* Renders an entry (icon) for the "Command and Control" center
-*
-* @param    template    $template   template to use
-* @param    string      $url        URL the entry links to
-* @param    string      $image      URL of the icon
-* @param    string      $label      text to use under the icon
-* @return   string                  HTML for rendered item
-*
-*/
-function render_cc_item(&$template, $url = '', $image = '', $label = '')
-{
-    if (! empty($url)) {
-        $template->set_var('page_url', $url);
-        $template->set_var('page_image', $image);
-        $template->set_var('option_label', $label);
-        $template->set_var('cell_width', ((int)(100 / ICONS_PER_ROW)) . '%');
-
-        return $template->parse('cc_main_options', 'ccitem', false);
-    }
-
-    return '';
+// Make sure user has rights to access this page
+if (!SEC_hasModerationAccess()) {
+    $display .= COM_showMessageText($MESSAGE[29], $MESSAGE[30]);
+    $display = COM_createHTMLDocument($display, array('pagetitle' => $MESSAGE[30]));
+    COM_accessLog("User {$_USER['username']} tried to illegally access the moderation administration screen.");
+    COM_output($display);
+    exit;
 }
 
 /**
-* Prints the command & control block at the top
+* Prints the user submission lists at the top
 *
 * @param    string  $token  CSRF token
 * @return   string          HTML for the C&C block
 *
 */
-function commandcontrol($token)
+function usersubmissions($token)
 {
-    global $_CONF, $_CONF_FT, $_TABLES, $LANG01, $LANG29, $_IMAGE_TYPE, $_DB_dbms;
+    global $_CONF, $_TABLES, $LANG_ADMIN, $LANG29, $_IMAGE_TYPE;
+
+    require_once $_CONF['path_system'] . 'lib-admin.php';
 
     $retval = '';
 
-    $admin_templates = COM_newTemplate($_CONF['path_layout'] . 'admin/moderation');
-    $admin_templates->set_file (array ('cc'     => 'moderation.thtml',
-                                       'ccrow'  => 'ccrow.thtml',
-                                       'ccitem' => 'ccitem.thtml'));
-
-    $retval .= COM_startBlock ('Geeklog ' . VERSION . ' -- ' . $LANG29[34], '',
-                               COM_getBlockTemplate ('_admin_block', 'header'));
-
-    $showTrackbackIcon = (($_CONF['trackback_enabled'] ||
-                          $_CONF['pingback_enabled'] || $_CONF['ping_enabled'])
-                         && SEC_hasRights('story.ping'));
-    $cc_arr = array(
-                  array('condition' => SEC_hasRights('story.edit'),
-                        'url' => $_CONF['site_admin_url'] . '/story.php',
-                        'lang' => $LANG01[11], 'image' => '/images/icons/story.'),
-                  array('condition' => SEC_hasRights('block.edit'),
-                        'url' => $_CONF['site_admin_url'] . '/block.php',
-                        'lang' => $LANG01[12], 'image' => '/images/icons/block.'),
-                  array('condition' => SEC_hasRights('topic.edit'),
-                        'url' => $_CONF['site_admin_url'] . '/topic.php',
-                        'lang' => $LANG01[13], 'image' => '/images/icons/topic.'),
-                  array('condition' => SEC_hasRights('user.edit'),
-                        'url' => $_CONF['site_admin_url'] . '/user.php',
-                        'lang' => $LANG01[17], 'image' => '/images/icons/user.'),
-                  array('condition' => SEC_hasRights('group.edit'),
-                        'url' => $_CONF['site_admin_url'] . '/group.php',
-                        'lang' => $LANG01[96], 'image' => '/images/icons/group.'),
-                  array('condition' => SEC_hasRights('user.mail'),
-                        'url' => $_CONF['site_admin_url'] . '/mail.php',
-                        'lang' => $LANG01[105], 'image' => '/images/icons/mail.'),
-                  array('condition' => SEC_hasRights ('syndication.edit'),
-                        'url' => $_CONF['site_admin_url'] . '/syndication.php',
-                        'lang' => $LANG01[38], 'image' => '/images/icons/syndication.'),
-                  array('condition' => $showTrackbackIcon,
-                        'url' => $_CONF['site_admin_url'] . '/trackback.php',
-                        'lang' => $LANG01[116], 'image' => '/images/icons/trackback.'),
-                  array('condition' => SEC_hasRights('plugin.edit'),
-                        'url' => $_CONF['site_admin_url'] . '/plugins.php',
-                        'lang' => $LANG01[98], 'image' => '/images/icons/plugins.')
-    );
-    $admin_templates->set_var('cc_icon_width', floor(100/ICONS_PER_ROW));
-
-    for ($i = 0; $i < count ($cc_arr); $i++) {
-        if ($cc_arr[$i]['condition']) {
-            $item = render_cc_item ($admin_templates, $cc_arr[$i]['url'],
-                    $_CONF['layout_url'] . $cc_arr[$i]['image'] . $_IMAGE_TYPE,
-                    $cc_arr[$i]['lang']);
-            $items[$cc_arr[$i]['lang']] = $item;
-        }
-    }
-
-    // now add the plugins
-    $plugins = PLG_getCCOptions ();
-    for ($i = 0; $i < count ($plugins); $i++) {
-        $cur_plugin = current ($plugins);
-        $item = render_cc_item ($admin_templates, $cur_plugin->adminurl,
-                        $cur_plugin->plugin_image, $cur_plugin->adminlabel);
-        $items[$cur_plugin->adminlabel] = $item;
-        next ($plugins);
-    }
-
-    // and finally, add the remaining admin items
-    $docsUrl = $_CONF['site_url'] . '/docs/english/index.html';
-    if ($_CONF['link_documentation'] == 1) {
-        $doclang = COM_getLanguageName();
-        $docs = 'docs/' . $doclang . '/index.html';
-        if (file_exists($_CONF['path_html'] . $docs)) {
-            $docsUrl = $_CONF['site_url'] . '/' . $docs;
-        }
-    }
-
-    $cc_arr = array(
-        array('condition' => ($_CONF['allow_mysqldump'] == 1) &&
-                                ($_DB_dbms == 'mysql') && SEC_inGroup('Root'),
-            'url' => $_CONF['site_admin_url'] . '/database.php',
-            'lang' => $LANG01[103], 'image' => '/images/icons/database.'),
-        array('condition' => ($_CONF['link_documentation'] == 1),
-            'url' => $docsUrl,
-            'lang' => $LANG01[113], 'image' => '/images/icons/docs.'),
-        array('condition' => (SEC_inGroup ('Root') &&
-                              ($_CONF['link_versionchecker'] == 1)),
-            'url' => 'http://www.geeklog.net/versionchecker.php?version='
-                     . VERSION,
-            'lang' => $LANG01[107], 'image' => '/images/icons/versioncheck.'),
-        array('condition' => SEC_hasRights($_CONF_FT, 'OR'),
-            'url'=>$_CONF['site_admin_url'] . '/configuration.php',
-            'lang' => $LANG01[129], 'image' => '/images/icons/configuration.')
+    // writing the menu on top
+    $menu_arr = array (
+        array('url' => $_CONF['site_admin_url'],
+              'text' => $LANG_ADMIN['admin_home'])
     );
 
-    for ($i = 0; $i < count ($cc_arr); $i++) {
-        if ($cc_arr[$i]['condition']) {
-            $item = render_cc_item ($admin_templates, $cc_arr[$i]['url'],
-                    $_CONF['layout_url'] . $cc_arr[$i]['image'] . $_IMAGE_TYPE,
-                    $cc_arr[$i]['lang']);
-            $items[$cc_arr[$i]['lang']] = $item;
-        }
-    }
-
-    if ($_CONF['sort_admin']) {
-        uksort ($items, 'strcasecmp');
-    }
-    // logout is always the last entry
-    $item = render_cc_item ($admin_templates,
-                    $_CONF['site_url'] . '/users.php?mode=logout',
-                    $_CONF['layout_url'] . '/images/icons/logout.' . $_IMAGE_TYPE,
-                    $LANG01[35]);
-    $items[$LANG01[35]] = $item;
-    reset($items);
-    $cols = 0;
-    $cc_main_options = '';
-    foreach ($items as $key => $val) {
-        $cc_main_options .= $val . LB;
-        $cols++;
-        if ($cols == ICONS_PER_ROW) {
-            $admin_templates->set_var('cc_main_options', $cc_main_options);
-            $admin_templates->parse ('cc_rows', 'ccrow', true);
-            $admin_templates->clear_var ('cc_main_options');
-            $cc_main_options = '';
-            $cols = 0;
-        }
-    }
-
-    if($cols > 0) {
-        // "flush out" any unrendered entries
-        $admin_templates->set_var('cc_main_options', $cc_main_options);
-        $admin_templates->parse ('cc_rows', 'ccrow', true);
-        $admin_templates->clear_var ('cc_main_options');
-    }
-
-    $retval .= $admin_templates->finish($admin_templates->parse('output','cc'));
-
-    $retval .= COM_endBlock (COM_getBlockTemplate ('_admin_block', 'footer'));
+    $retval .= COM_startBlock($LANG29[13], '',
+                              COM_getBlockTemplate('_admin_block', 'header'));
+    $retval .= ADMIN_createMenu(
+        $menu_arr,
+        $LANG29['submissions_desc'],
+        $_CONF['layout_url'] . '/images/icons/moderation.'. $_IMAGE_TYPE
+    );    
 
+    // IMPORTANT - If any of the below submission lists change, please 
+    // update the function SEC_hasModerationAccess in lib-security.php to 
+    // reflect the changes
+    
     if (SEC_hasRights('story.moderate')) {
         $retval .= itemlist('story', $token);
     }
@@ -239,6 +109,8 @@ function commandcontrol($token)
     }
 
     $retval .= PLG_showModerationList($token);
+    
+    $retval .= COM_endBlock(COM_getBlockTemplate('_admin_block', 'footer'));
 
     return $retval;
 }
@@ -332,20 +204,36 @@ function itemlist($type, $token)
         $data_arr[$i] = $A;
     }
 
-    $header_arr = array(      // display 'text' and use table field 'field'
-        array('text' => $LANG_ADMIN['edit'], 'field' => 0),
-        array('text' => $H[0], 'field' => 1),
-        array('text' => $H[1], 'field' => 2),
-        array('text' => $H[2], 'field' => 3),
-        array('text' => $LANG29[2], 'field' => 'delete'),
-        array('text' => $LANG29[1], 'field' => 'approve')
-    );
     if ($type == 'comment') {
-        // data for comment submission headers
-        $header_arr[6]['text'] = $LANG29[42];
-        $header_arr[6]['field'] = 'uid';
-        $header_arr[7]['text'] = $LANG29[43];
-        $header_arr[7]['field'] = 'publishfuture';
+        $header_arr = array(      // display 'text' and use table field 'field'
+            array('text' => $LANG_ADMIN['edit'], 'field' => 0),
+            array('text' => $H[0], 'field' => 1),
+            array('text' => $H[1], 'field' => 2),
+            array('text' => $H[2], 'field' => 3),
+            array('text' => $LANG29[2], 'field' => 'delete'),
+            array('text' => $LANG29[1], 'field' => 'approve'),
+            array('text' => $LANG29[42], 'field' => 'uid'),
+            array('text' => $LANG29[43], 'field' => 'publishfuture')
+        );            
+    } elseif ($type == 'story' || $type == 'story_draft') {
+        $header_arr = array(      // display 'text' and use table field 'field'
+            array('text' => $LANG_ADMIN['edit'], 'field' => 0),
+            array('text' => $H[0], 'field' => 1),
+            array('text' => $H[1], 'field' => 'uid'),
+            array('text' => $H[2], 'field' => 3),
+            array('text' => $H[3], 'field' => 4),
+            array('text' => $LANG29[2], 'field' => 'delete'),
+            array('text' => $LANG29[1], 'field' => 'approve')
+        );            
+    } else {
+        $header_arr = array(      // display 'text' and use table field 'field'
+            array('text' => $LANG_ADMIN['edit'], 'field' => 0),
+            array('text' => $H[0], 'field' => 1),
+            array('text' => $H[1], 'field' => 2),
+            array('text' => $H[2], 'field' => 3),
+            array('text' => $LANG29[2], 'field' => 'delete'),
+            array('text' => $LANG29[1], 'field' => 'approve')
+        );          
     }
 
     $text_arr = array('has_menu' => false,
@@ -490,19 +378,26 @@ function moderation($mid, $action, $type, $count)
             // There may be some plugin specific processing that needs to
             // happen first.
             $retval .= PLG_deleteSubmission($type, $mid[$i]);
+            
+            // Notify plugins of a submission that is deleted
+            PLG_submissionDeleted($type);
 
             DB_delete($submissiontable, $id, $mid[$i]);
             break;
 
         case 'approve':
             if ($type == 'story') {
-                $result = DB_query ("SELECT * FROM {$_TABLES['storysubmission']} WHERE sid = '$mid[$i]'");
+                $sql = "SELECT *, ta.tid 
+                    FROM {$_TABLES['storysubmission']}, {$_TABLES['topic_assignments']} ta 
+                    WHERE ta.type = 'article' AND ta.id = sid  AND sid = '$mid[$i]'";
+                
+                $result = DB_query ($sql);
                 $A = DB_fetchArray ($result);
-                $A['related'] = addslashes (implode ("\n", STORY_extractLinks ($A['introtext'])));
+                $A['related'] = DB_escapeString(implode ("\n", STORY_extractLinks ($A['introtext'])));
                 $A['owner_id'] = $A['uid'];
-                $A['title'] = addslashes ($A['title']);
-                $A['introtext'] = addslashes ($A['introtext']);
-                $A['bodytext'] = addslashes( $A['bodytext'] );
+                $A['title'] = DB_escapeString($A['title']);
+                $A['introtext'] = DB_escapeString($A['introtext']);
+                $A['bodytext'] = DB_escapeString( $A['bodytext'] );
                 $result = DB_query ("SELECT group_id,perm_owner,perm_group,perm_members,perm_anon,archive_flag FROM {$_TABLES['topics']} WHERE tid = '{$A['tid']}'");
                 $T = DB_fetchArray ($result);
                 if ($T['archive_flag'] == 1) {
@@ -512,13 +407,12 @@ function moderation($mid, $action, $type, $count)
                 } else {
                     $frontpage = 1;
                 }
-                DB_save ($_TABLES['stories'],'sid,uid,tid,title,introtext,bodytext,related,date,show_topic_icon,commentcode,trackbackcode,postmode,frontpage,owner_id,group_id,perm_owner,perm_group,perm_members,perm_anon',
-                "'{$A['sid']}',{$A['uid']},'{$A['tid']}','{$A['title']}','{$A['introtext']}','{$A['bodytext']}','{$A['related']}','{$A['date']}','{$_CONF['show_topic_icon']}','{$_CONF['comment_code']}','{$_CONF['trackback_code']}','{$A['postmode']}',$frontpage,{$A['owner_id']},{$T['group_id']},{$T['perm_owner']},{$T['perm_group']},{$T['perm_members']},{$T['perm_anon']}");
+                DB_save ($_TABLES['stories'],'sid,uid,title,introtext,bodytext,related,date,show_topic_icon,commentcode,trackbackcode,postmode,frontpage,owner_id,group_id,perm_owner,perm_group,perm_members,perm_anon',
+                "'{$A['sid']}',{$A['uid']},'{$A['title']}','{$A['introtext']}','{$A['bodytext']}','{$A['related']}','{$A['date']}','{$_CONF['show_topic_icon']}','{$_CONF['comment_code']}','{$_CONF['trackback_code']}','{$A['postmode']}',$frontpage,{$A['owner_id']},{$T['group_id']},{$T['perm_owner']},{$T['perm_group']},{$T['perm_members']},{$T['perm_anon']}");
                 DB_delete($_TABLES['storysubmission'],"$id",$mid[$i]);
 
                 PLG_itemSaved($A['sid'], 'article');
                 COM_rdfUpToDateCheck ();
-                COM_olderStuff ();
             } elseif ($type == 'comment') {
                 $sid = CMT_approveModeration($mid[$i]);
                 if (! in_array($sid, $sidArray)) {
@@ -570,13 +464,16 @@ function moderation($mid, $action, $type, $count)
                 // There may be some plugin specific processing that needs
                 // to happen first.
                 $retval .= PLG_deleteSubmission($type, $delitem);
+                
+                // Notify plugins of a submission type that is deleted
+                PLG_submissionDeleted($type);
 
                 DB_delete($submissiontable, $id, $delitem);
             }
         }
     }
 
-    $retval .= commandcontrol(SEC_createToken());
+    $retval .= usersubmissions(SEC_createToken());
 
     return $retval;
 }
@@ -641,30 +538,7 @@ function moderateusers ($uid, $action, $count)
         }
     }
 
-    $retval .= commandcontrol(SEC_createToken());
-
-    return $retval;
-}
-
-/**
-* Display a reminder to execute the security check script
-*
-* @return   string      HTML for security reminder (or empty string)
-*/
-function security_check_reminder()
-{
-    global $_CONF, $_TABLES, $_IMAGE_TYPE, $MESSAGE;
-
-    $retval = '';
-
-    if (!SEC_inGroup ('Root')) {
-        return $retval;
-    }
-
-    $done = DB_getItem ($_TABLES['vars'], 'value', "name = 'security_check'");
-    if ($done != 1) {
-        $retval .= COM_showMessage(92);
-    }
+    $retval .= usersubmissions(SEC_createToken());
 
     return $retval;
 }
@@ -686,17 +560,14 @@ if (isset($_POST['mode']) && ($_POST['mode'] == 'moderation') &&
         $mod_result = moderation($_POST['id'], $action, $_POST['type'],
                                  COM_applyFilter($_POST['count'], true));
     }
-    $display .= COM_siteHeader('menu', $LANG29[34])
-             .  COM_showMessageFromParameter()
+    $display .= COM_showMessageFromParameter()
              .  $mod_result;
 } else {
-    $display .= COM_siteHeader('menu', $LANG29[34])
-             .  COM_showMessageFromParameter()
-             .  security_check_reminder()
-             .  commandcontrol(SEC_createToken());
+    $display .= COM_showMessageFromParameter()
+             .  usersubmissions(SEC_createToken());
 }
 
-$display .= COM_siteFooter();
+$display = COM_createHTMLDocument($display, array('pagetitle' => $LANG29[34]));
 
 COM_output($display);
 
