@@ -2,13 +2,13 @@
 
 // Reminder: always indent with 4 spaces (no tabs).
 // +---------------------------------------------------------------------------+
-// | Links Plugin 2.0                                                          |
+// | Links Plugin 2.1                                                          |
 // +---------------------------------------------------------------------------+
 // | index.php                                                                 |
 // |                                                                           |
 // | Geeklog Links Plugin administration page.                                 |
 // +---------------------------------------------------------------------------+
-// | Copyright (C) 2000-2008 by the following authors:                         |
+// | Copyright (C) 2000-2010 by the following authors:                         |
 // |                                                                           |
 // | Authors: Tony Bibbs        - tony AT tonybibbs DOT com                    |
 // |          Mark Limburg      - mlimburg AT users DOT sourceforge DOT net    |
@@ -31,8 +31,6 @@
 // | Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.           |
 // |                                                                           |
 // +---------------------------------------------------------------------------+
-//
-// $Id: index.php,v 1.61 2008/06/07 12:41:45 dhaun Exp $
 
 /**
  * Geeklog links administration page.
@@ -43,7 +41,7 @@
  * @version 2.0
  * @since GL 1.4.0
  * @copyright Copyright &copy; 2005-2007
- * @license http://opensource.org/licenses/gpl-license.php GNU Public License
+ * @license http://opensource.org/licenses/gpl-2.0.php GNU General Public License v2
  * @author Trinity Bays <trinity93@gmail.com>
  * @author Tony Bibbs <tony@tonybibbs.com>
  * @author Tom Willett <twillett@users.sourceforge.net>
@@ -51,9 +49,11 @@
  * @author Dirk Haun <dirk@haun-online.de>
  */
 
+/** 
+* Geeklog common function library and Admin authentication
+*/
 require_once '../../../lib-common.php';
 require_once '../../auth.inc.php';
-require_once $_CONF['path_system'] . 'lib-security.php';
 
 // Uncomment the lines below if you need to debug the HTTP variables being passed
 // to the script.  This will sometimes cause errors but it will allow you to see
@@ -63,15 +63,11 @@ require_once $_CONF['path_system'] . 'lib-security.php';
 
 $display = '';
 
-if (!SEC_hasRights ('links.edit')) {
-    $display .= COM_siteHeader ('menu', $MESSAGE[30]);
-    $display .= COM_startBlock ($MESSAGE[30], '',
-                                COM_getBlockTemplate ('_msg_block', 'header'));
-    $display .= $MESSAGE[34];
-    $display .= COM_endBlock (COM_getBlockTemplate ('_msg_block', 'footer'));
-    $display .= COM_siteFooter ();
-    COM_accessLog ("User {$_USER['username']} tried to illegally access the links administration screen.");
-    echo $display;
+if (!SEC_hasRights('links.edit')) {
+    $display .= COM_showMessageText($MESSAGE[29], $MESSAGE[30]);
+    $display = COM_createHTMLDocument($display, array('pagetitle' => $MESSAGE[30]));
+    COM_accessLog("User {$_USER['username']} tried to illegally access the links administration screen.");
+    COM_output($display);
     exit;
 }
 
@@ -97,12 +93,8 @@ function editlink ($mode, $lid = '')
 
     $retval = '';
 
-    $link_templates = new Template($_CONF['path'] . 'plugins/links/templates/admin/');
+    $link_templates = COM_newTemplate($_CONF['path'] . 'plugins/links/templates/admin/');
     $link_templates->set_file('editor','linkeditor.thtml');
-    $link_templates->set_var( 'xhtml', XHTML );
-    $link_templates->set_var('site_url', $_CONF['site_url']);
-    $link_templates->set_var('site_admin_url', $_CONF['site_admin_url']);
-    $link_templates->set_var('layout_url',$_CONF['layout_url']);
 
     $link_templates->set_var('lang_pagetitle', $LANG_LINKS_ADMIN[28]);
     $link_templates->set_var('lang_link_list', $LANG_LINKS_ADMIN[53]);
@@ -116,19 +108,13 @@ function editlink ($mode, $lid = '')
     if ($mode <> 'editsubmission' AND !empty($lid)) {
         $result = DB_query("SELECT * FROM {$_TABLES['links']} WHERE lid ='$lid'");
         if (DB_numRows($result) !== 1) {
-            $msg = COM_startBlock ($LANG_LINKS_ADMIN[24], '',
-                COM_getBlockTemplate ('_msg_block', 'header'));
-            $msg .= $LANG_LINKS_ADMIN[25];
-            $msg .= COM_endBlock (COM_getBlockTemplate ('_msg_block', 'footer'));
+            $msg = COM_showMessageText($LANG_LINKS_ADMIN[25], $LANG_LINKS_ADMIN[24]);
             return $msg;
         }
         $A = DB_fetchArray($result);
         $access = SEC_hasAccess($A['owner_id'],$A['group_id'],$A['perm_owner'],$A['perm_group'],$A['perm_members'],$A['perm_anon']);
         if ($access == 0 OR $access == 2) {
-            $retval .= COM_startBlock($LANG_LINKS_ADMIN[16], '',
-                               COM_getBlockTemplate ('_msg_block', 'header'));
-            $retval .= $LANG_LINKS_ADMIN[17];
-            $retval .= COM_endBlock (COM_getBlockTemplate ('_msg_block', 'footer'));
+            $retval .= COM_showMessageText($LANG_LINKS_ADMIN[17], $LANG_LINKS_ADMIN[16]);
             COM_accessLog("User {$_USER['username']} tried to illegally submit or edit link $lid.");
             return $retval;
         }
@@ -153,8 +139,12 @@ function editlink ($mode, $lid = '')
         SEC_setDefaultPermissions ($A, $_LI_CONF['default_permissions']);
         $access = 3;
     }
-    $retval .= COM_startBlock ($LANG_LINKS_ADMIN[1], '',
-                               COM_getBlockTemplate ('_admin_block', 'header'));
+
+    $token = SEC_createToken();
+
+    $retval .= COM_startBlock($LANG_LINKS_ADMIN[1], '',
+                              COM_getBlockTemplate('_admin_block', 'header'));
+    $retval .= SEC_getTokenExpiryNotice($token);
 
     $link_templates->set_var('link_id', $A['lid']);
     if (!empty($lid) && SEC_hasRights('links.edit')) {
@@ -188,6 +178,9 @@ function editlink ($mode, $lid = '')
     $link_templates->set_var('link_hits', $A['hits']);
     $link_templates->set_var('lang_linkdescription', $LANG_LINKS_ADMIN[9]);
     $link_templates->set_var('link_description', stripslashes($A['description']));
+    $allowed = COM_allowedHTML('links.edit')
+             . COM_allowedAutotags();
+    $link_templates->set_var('lang_allowed_html', $allowed);
     $link_templates->set_var('lang_save', $LANG_ADMIN['save']);
     $link_templates->set_var('lang_cancel', $LANG_ADMIN['cancel']);
 
@@ -205,10 +198,12 @@ function editlink ($mode, $lid = '')
                              SEC_getGroupDropdown ($A['group_id'], $access));
     $link_templates->set_var('lang_permissions', $LANG_ACCESS['permissions']);
     $link_templates->set_var('lang_permissionskey', $LANG_ACCESS['permissionskey']);
+    $link_templates->set_var('lang_perm_key', $LANG_ACCESS['permissionskey']);
     $link_templates->set_var('permissions_editor', SEC_getPermissionsHTML($A['perm_owner'],$A['perm_group'],$A['perm_members'],$A['perm_anon']));
+    $link_templates->set_var('lang_permissions_msg', $LANG_ACCESS['permmsg']);
     $link_templates->set_var('lang_lockmsg', $LANG_ACCESS['permmsg']);
     $link_templates->set_var('gltoken_name', CSRF_TOKEN);
-    $link_templates->set_var('gltoken', SEC_createToken());
+    $link_templates->set_var('gltoken', $token);
     $link_templates->parse('output', 'editor');
     $retval .= $link_templates->finish($link_templates->get_var('output'));
 
@@ -254,10 +249,15 @@ function savelink ($lid, $old_lid, $cid, $categorydd, $url, $description, $title
         list($perm_owner,$perm_group,$perm_members,$perm_anon) = SEC_getPermissionValues($perm_owner,$perm_group,$perm_members,$perm_anon);
     }
 
+
+    // Remove any autotags the user doesn't have permission to use
+    $description = PLG_replaceTags($description, '', true);
+    
     // clean 'em up
-    $description = addslashes (COM_checkHTML (COM_checkWords ($description)));
-    $title = addslashes (COM_checkHTML (COM_checkWords ($title)));
-    $cid = addslashes ($cid);
+    $description = DB_escapeString(COM_checkHTML(COM_checkWords($description),
+                              'links.edit'));
+    $title = DB_escapeString(strip_tags(COM_checkWords($title)));
+    $cid = DB_escapeString($cid);
 
     if (empty ($owner_id)) {
         // this is new link from admin, set default values
@@ -273,17 +273,27 @@ function savelink ($lid, $old_lid, $cid, $categorydd, $url, $description, $title
         $perm_anon = 2;
     }
 
-    $lid = COM_sanitizeID ($lid);
-    if (empty ($lid)) {
-        if (empty ($old_lid)) {
-            $lid = COM_makeSid ();
+    $lid = COM_sanitizeID($lid);
+    $old_lid = COM_sanitizeID($old_lid);
+    if (empty($lid)) {
+        if (empty($old_lid)) {
+            $lid = COM_makeSid();
         } else {
             $lid = $old_lid;
         }
     }
 
+    // check for link id change
+    if (!empty($old_lid) && ($lid != $old_lid)) {
+        // check if new lid is already in use
+        if (DB_count($_TABLES['links'], 'lid', $lid) > 0) {
+            // TBD: abort, display editor with all content intact again
+            $lid = $old_lid; // for now ...
+        }
+    }
+
     $access = 0;
-    $old_lid = addslashes ($old_lid);
+    $old_lid = DB_escapeString ($old_lid);
     if (DB_count ($_TABLES['links'], 'lid', $old_lid) > 0) {
         $result = DB_query ("SELECT owner_id,group_id,perm_owner,perm_group,perm_members,perm_anon FROM {$_TABLES['links']} WHERE lid = '{$old_lid}'");
         $A = DB_fetchArray ($result);
@@ -294,20 +304,16 @@ function savelink ($lid, $old_lid, $cid, $categorydd, $url, $description, $title
         $access = SEC_hasAccess ($owner_id, $group_id, $perm_owner, $perm_group,
                 $perm_members, $perm_anon);
     }
-    if (($access < 3) || !SEC_inGroup ($group_id)) {
-        $display .= COM_siteHeader ('menu', $MESSAGE[30]);
-        $display .= COM_startBlock ($MESSAGE[30], '',
-                            COM_getBlockTemplate ('_msg_block', 'header'));
-        $display .= $MESSAGE[31];
-        $display .= COM_endBlock (COM_getBlockTemplate ('_msg_block', 'footer'));
-        $display .= COM_siteFooter ();
+    if (($access < 3) || !SEC_inGroup($group_id)) {
+        $display .= COM_showMessageText($MESSAGE[29], $MESSAGE[30]);
+        $display = COM_createHTMLDocument($display, array('pagetitle' => $MESSAGE[30]));
         COM_accessLog("User {$_USER['username']} tried to illegally submit or edit link $lid.");
-        echo $display;
+        COM_output($display);
         exit;
     } elseif (!empty($title) && !empty($description) && !empty($url)) {
 
         if ($categorydd != $LANG_LINKS_ADMIN[7] && !empty($categorydd)) {
-            $cid = addslashes ($categorydd);
+            $cid = DB_escapeString($categorydd);
         } else if ($categorydd != $LANG_LINKS_ADMIN[7]) {
             echo COM_refresh($_CONF['site_admin_url'] . '/plugins/links/index.php');
         }
@@ -316,6 +322,13 @@ function savelink ($lid, $old_lid, $cid, $categorydd, $url, $description, $title
         DB_delete ($_TABLES['links'], 'lid', $old_lid);
 
         DB_save ($_TABLES['links'], 'lid,cid,url,description,title,date,hits,owner_id,group_id,perm_owner,perm_group,perm_members,perm_anon', "'$lid','$cid','$url','$description','$title',NOW(),'$hits',$owner_id,$group_id,$perm_owner,$perm_group,$perm_members,$perm_anon");
+
+        if (empty($old_lid) || ($old_lid == $lid)) {
+            PLG_itemSaved($lid, 'links');
+        } else {
+            PLG_itemSaved($lid, 'links', $old_lid);
+        }
+
         // Get category for rdf check
         $category = DB_getItem ($_TABLES['linkcategories'],"category","cid='{$cid}'");
         COM_rdfUpToDateCheck ('links', $category, $lid);
@@ -328,14 +341,13 @@ function savelink ($lid, $old_lid, $cid, $categorydd, $url, $description, $title
         );
 
     } else { // missing fields
-        $retval .= COM_siteHeader('menu', $LANG_LINKS_ADMIN[1]);
         $retval .= COM_errorLog($LANG_LINKS_ADMIN[10],2);
         if (DB_count ($_TABLES['links'], 'lid', $old_lid) > 0) {
             $retval .= editlink ('edit', $old_lid);
         } else {
             $retval .= editlink ('edit', '');
         }
-        $retval .= COM_siteFooter();
+        $retval = COM_createHTMLDocument($retval, array('pagetitle' => $LANG_LINKS_ADMIN[1]));
 
         return $retval;
     }
@@ -458,6 +470,8 @@ function deleteLink($lid, $type = '')
 
         DB_delete($_TABLES['links'], 'lid', $lid);
 
+        PLG_itemDeleted($lid, 'links');
+
         return COM_refresh($_CONF['site_admin_url']
                            . '/plugins/links/index.php?msg=3');
     } elseif ($type == 'submission') {
@@ -470,7 +484,7 @@ function deleteLink($lid, $type = '')
             COM_accessLog("User {$_USER['username']} tried to illegally delete link submission $lid.");
         }
     } else {
-        COM_errorLog("User {$_USER['username']} tried to illegally delete link $lid of type $type.");
+        COM_accessLog("User {$_USER['username']} tried to illegally delete link $lid of type $type.");
     }
 
     return COM_refresh($_CONF['site_admin_url'] . '/plugins/links/index.php');
@@ -512,29 +526,26 @@ if (($mode == $LANG_ADMIN['delete']) && !empty ($LANG_ADMIN['delete'])) {
             $_POST['perm_owner'], $_POST['perm_group'],
             $_POST['perm_members'], $_POST['perm_anon']);
 } else if ($mode == 'editsubmission') {
-    $display .= COM_siteHeader ('menu', $LANG_LINKS_ADMIN[1]);
     $display .= editlink ($mode, COM_applyFilter ($_GET['id']));
-    $display .= COM_siteFooter ();
+    $display = COM_createHTMLDocument($display, array('pagetitle' => $LANG_LINKS_ADMIN[1]));
 } else if ($mode == 'edit') {
-    $display .= COM_siteHeader ('menu', $LANG_LINKS_ADMIN[1]);
     if (empty ($_GET['lid'])) {
         $display .= editlink ($mode);
     } else {
         $display .= editlink ($mode, COM_applyFilter ($_GET['lid']));
     }
-    $display .= COM_siteFooter ();
+    $display = COM_createHTMLDocument($display, array('pagetitle' => $LANG_LINKS_ADMIN[1]));
 } else { // 'cancel' or no mode at all
-    $display .= COM_siteHeader ('menu', $LANG_LINKS_ADMIN[11]);
-    if (isset ($_REQUEST['msg'])) {
-        $msg = COM_applyFilter ($_REQUEST['msg'], true);
+    if (isset($_GET['msg'])) {
+        $msg = COM_applyFilter($_GET['msg'], true);
         if ($msg > 0) {
-            $display .= COM_showMessage ($msg, 'links');
+            $display .= COM_showMessage($msg, 'links');
         }
     }
     $display .= listlinks();
-    $display .= COM_siteFooter ();
+    $display = COM_createHTMLDocument($display, array('pagetitle' => $LANG_LINKS_ADMIN[11]));
 }
 
-echo $display;
+COM_output($display);
 
 ?>
