@@ -51,9 +51,8 @@ $_POLL_VERBOSE = false;
 $display = '';
 
 if (!SEC_hasRights('polls.edit')) {
-    $display .= COM_siteHeader('menu', $MESSAGE[30])
-             . COM_showMessageText($MESSAGE[29], $MESSAGE[30])
-             . COM_siteFooter();
+    $display .= COM_showMessageText($MESSAGE[29], $MESSAGE[30]);
+    $display = COM_createHTMLDocument($display, array('pagetitle' => $MESSAGE[30]));
     COM_accessLog("User {$_USER['username']} tried to illegally access the poll administration screen.");
     COM_output($display);
     exit;
@@ -164,6 +163,7 @@ function savepoll($pid, $old_pid, $Q, $mainpage, $topic, $meta_description, $met
     list($perm_owner,$perm_group,$perm_members,$perm_anon) = SEC_getPermissionValues($perm_owner,$perm_group,$perm_members,$perm_anon);
 
     $topic = COM_stripslashes($topic);
+    $topic = COM_checkHTML($topic);
     $meta_description = strip_tags(COM_stripslashes($meta_description));
     $meta_keywords = strip_tags(COM_stripslashes($meta_keywords));
     $pid = COM_sanitizeID($pid);
@@ -179,12 +179,8 @@ function savepoll($pid, $old_pid, $Q, $mainpage, $topic, $meta_description, $met
     // check if any question was entered
     if (empty($topic) or (count($Q) == 0) or (strlen($Q[0]) == 0) or
             (strlen($A[0][0]) == 0)) {
-        $retval .= COM_siteHeader ('menu', $LANG25[5]);
-        $retval .= COM_startBlock ($LANG21[32], '',
-                           COM_getBlockTemplate ('_msg_block', 'header'));
-        $retval .= $LANG25[2];
-        $retval .= COM_endBlock(COM_getBlockTemplate ('_msg_block', 'footer'));
-        $retval .= COM_siteFooter ();
+        $retval .= COM_showMessageText($LANG25[2], $LANG21[32]);
+        $retval = COM_createHTMLDocument($retval, array('pagetitle' => $LANG25[5]));
         return $retval;
     }
 
@@ -221,9 +217,8 @@ function savepoll($pid, $old_pid, $Q, $mainpage, $topic, $meta_description, $met
                                  $perm_group, $perm_members, $perm_anon);
     }
     if (($access < 3) || !SEC_inGroup($group_id)) {
-        $display .= COM_siteHeader('menu', $MESSAGE[30])
-                 . COM_showMessageText($MESSAGE[29], $MESSAGE[30])
-                 . COM_siteFooter();
+        $display .= COM_showMessageText($MESSAGE[29], $MESSAGE[30]);
+        $display = COM_createHTMLDocument($display, array('pagetitle' => $MESSAGE[30]));
         COM_accessLog("User {$_USER['username']} tried to illegally submit or edit poll $pid.");
         COM_output($display);
         exit;
@@ -251,17 +246,23 @@ function savepoll($pid, $old_pid, $Q, $mainpage, $topic, $meta_description, $met
     DB_delete($_TABLES['pollanswers'], 'pid', $del_pid);
     DB_delete($_TABLES['pollquestions'], 'pid', $del_pid);
 
-    $topic = addslashes($topic);
-    $meta_description = addslashes($meta_description);
-    $meta_keywords = addslashes($meta_keywords);
+    $topic = DB_escapeString($topic);
+    $meta_description = DB_escapeString($meta_description);
+    $meta_keywords = DB_escapeString($meta_keywords);
 
     $k = 0; // set up a counter to make sure we do assign a straight line of question id's
     // first dimension of array are the questions
     $num_questions = count($Q);
+    $num_total_votes = 0;
+    $num_questions_exist = 0;
     for ($i = 0; $i < $num_questions; $i++) {
         $Q[$i] = COM_stripslashes($Q[$i]);
+        $Q[$i] = COM_checkHTML($Q[$i]);
+
         if (strlen($Q[$i]) > 0) { // only insert questions that exist
-            $Q[$i] = addslashes($Q[$i]);
+            $num_questions_exist++;
+            
+            $Q[$i] = DB_escapeString($Q[$i]);
             DB_save($_TABLES['pollquestions'], 'qid, pid, question',
                                                "'$k', '$pid', '$Q[$i]'");
             // within the questions, we have another dimensions with answers,
@@ -269,23 +270,34 @@ function savepoll($pid, $old_pid, $Q, $mainpage, $topic, $meta_description, $met
             $num_answers = count($A[$i]);
             for ($j = 0; $j < $num_answers; $j++) {
                 $A[$i][$j] = COM_stripslashes($A[$i][$j]);
+                $A[$i][$j] = COM_checkHTML($A[$i][$j]);
+                $R[$i][$j] = COM_stripslashes($R[$i][$j]);
+                $R[$i][$j] = COM_checkHTML($R[$i][$j]);
+
                 if (strlen($A[$i][$j]) > 0) { // only insert answers etc that exist
                     if (!is_numeric($V[$i][$j])) {
                         $V[$i][$j] = "0";
                     }
-                    $A[$i][$j] = addslashes ($A[$i][$j]);
-                    $R[$i][$j] = addslashes ($R[$i][$j]);
+                    $A[$i][$j] = DB_escapeString($A[$i][$j]);
+                    $R[$i][$j] = DB_escapeString($R[$i][$j]);
                     $sql = "INSERT INTO {$_TABLES['pollanswers']} (pid, qid, aid, answer, votes, remark) VALUES "
                         . "('$pid', '$k', " . ($j+1) . ", '{$A[$i][$j]}', {$V[$i][$j]}, '{$R[$i][$j]}');";
                     DB_query($sql);
+                    
+                    $num_total_votes = $num_total_votes + $V[$i][$j];
                 }
             }
             $k++;
         }
     }
     
-    // determine the number of voters
-    $numvoters = DB_count($_TABLES['pollvoters'], 'pid', $pid);
+    // determine the number of voters (cannot use records in pollvoters table since they get deleted after a time $_PO_CONF['polladdresstime'])
+    if ($num_questions_exist > 0) {
+        $numvoters = $num_total_votes / $num_questions_exist;
+    } else {
+        // This shouldn't happen
+        $numvoters = $num_total_votes;
+    }
     
     // save topics after the questions so we can include question count into table
     $sql = "'$pid','$topic','$meta_description','$meta_keywords',$numvoters, $k, '$created_date', '" . date ('Y-m-d H:i:s');
@@ -314,8 +326,11 @@ function savepoll($pid, $old_pid, $Q, $mainpage, $topic, $meta_description, $met
     if (empty($old_pid) || ($old_pid == $pid)) {
         PLG_itemSaved($pid, 'polls');
     } else {
-        DB_change($_TABLES['comments'], 'sid', addslashes($pid),
-                  array('sid', 'type'), array(addslashes($old_pid), 'polls'));
+        DB_change($_TABLES['comments'], 'sid', DB_escapeString($pid),
+                  array('sid', 'type'), array(DB_escapeString($old_pid), 'polls'));
+        
+        DB_change($_TABLES['pollvoters'], 'pid', DB_escapeString($pid), 'pid', DB_escapeString($old_pid));
+        
         PLG_itemSaved($pid, 'polls', $old_pid);
     }
 
@@ -358,10 +373,7 @@ function editpoll ($pid = '')
         $access = SEC_hasAccess($T['owner_id'],$T['group_id'],$T['perm_owner'],$T['perm_group'],$T['perm_members'],$T['perm_anon']);
         if ($access == 0 OR $access == 2) {
             // User doesn't have access...bail
-            $retval .= COM_startBlock($LANG25[21], '',
-                            COM_getBlockTemplate('_msg_block', 'header'));
-            $retval .= $LANG25[22];
-            $retval .= COM_endBlock(COM_getBlockTemplate('_msg_block', 'footer'));
+            $retval .= COM_showMessageText($LANG25[22], $LANG25[21]);
             COM_accessLog("User {$_USER['username']} tried to illegally submit or edit poll $pid.");
             return $retval;
         }
@@ -565,7 +577,7 @@ function deletePoll ($pid)
 {
     global $_CONF, $_TABLES, $_USER;
 
-    $pid = addslashes ($pid);
+    $pid = DB_escapeString ($pid);
     $result = DB_query ("SELECT owner_id,group_id,perm_owner,perm_group,perm_members,perm_anon FROM {$_TABLES['polltopics']} WHERE pid = '$pid'");
     $Q = DB_fetchArray ($result);
     $access = SEC_hasAccess ($Q['owner_id'], $Q['group_id'], $Q['perm_owner'],
@@ -578,6 +590,7 @@ function deletePoll ($pid)
     DB_delete($_TABLES['polltopics'], 'pid', $pid);
     DB_delete($_TABLES['pollanswers'], 'pid', $pid);
     DB_delete($_TABLES['pollquestions'], 'pid', $pid);
+    DB_delete($_TABLES['pollvoters'], 'pid', $pid);
     DB_delete($_TABLES['comments'], array('sid', 'type'),
                                     array($pid,  'polls'));
 
@@ -596,13 +609,12 @@ if (isset ($_REQUEST['mode'])) {
 }
 
 if ($mode == 'edit') {
-    $display .= COM_siteHeader ('menu', $LANG25[5]);
     $pid = '';
     if (isset ($_GET['pid'])) {
         $pid = COM_applyFilter ($_GET['pid']);
     }
     $display .= editpoll ($pid);
-    $display .= COM_siteFooter ();
+    $display = COM_createHTMLDocument($display, array('pagetitle' => $LANG25[5]));
 } elseif (($mode == $LANG_ADMIN['save']) && !empty($LANG_ADMIN['save'])) {
     $pid = COM_applyFilter($_POST['pid']);
     $old_pid = '';
@@ -643,13 +655,9 @@ if ($mode == 'edit') {
                         $_POST['perm_owner'], $_POST['perm_group'],
                         $_POST['perm_members'], $_POST['perm_anon']);
     } else {
-        $display .= COM_siteHeader ('menu', $LANG25[5]);
-        $display .= COM_startBlock ($LANG21[32], '',
-                            COM_getBlockTemplate ('_msg_block', 'header'));
-        $display .= $LANG25[17];
-        $display .= COM_endBlock(COM_getBlockTemplate ('_msg_block', 'footer'));
-        $display .= editpoll ();
-        $display .= COM_siteFooter ();
+        $display .= COM_showMessageText($LANG25[17], $LANG21[32])
+                 .  editpoll();
+        $display = COM_createHTMLDocument($display, array('pagetitle' => $LANG25[5]));
     }
 } elseif (($mode == $LANG_ADMIN['delete']) && !empty($LANG_ADMIN['delete'])) {
     $pid = '';
@@ -667,7 +675,6 @@ if ($mode == 'edit') {
     }
 } else { // 'cancel' or no mode at all
 
-    $display .= COM_siteHeader ('menu', $LANG25[18]);
     if (isset ($_REQUEST['msg'])) {
         $msg = COM_applyFilter ($_REQUEST['msg'], true);
         if ($msg > 0) {
@@ -675,7 +682,7 @@ if ($mode == 'edit') {
         }
     }
     $display .= listpolls();
-    $display .= COM_siteFooter ();
+    $display = COM_createHTMLDocument($display, array('pagetitle' => $LANG25[18]));
 }
 
 COM_output($display);
