@@ -14,6 +14,7 @@
 // |          Mark Limburg      - mlimburg AT users DOT sourceforge DOT net    |
 // |          Jason Whittenburg - jwhitten AT securitygeeks DOT com            |
 // |          Dirk Haun         - dirk AT haun-online DOT de                   |
+// |          Vincent Furia     - vmf AT abtech DOT org                        |
 // +---------------------------------------------------------------------------+
 // |                                                                           |
 // | This program is free software; you can redistribute it and/or             |
@@ -60,9 +61,8 @@ $display = '';
 
 // Make sure user has access to this page
 if (!SEC_hasRights('user.edit')) {
-    $display .= COM_siteHeader('menu', $MESSAGE[30])
-             . COM_showMessageText($MESSAGE[29], $MESSAGE[30])
-             . COM_siteFooter();
+    $display .= COM_showMessageText($MESSAGE[29], $MESSAGE[30]);
+    $display = COM_createHTMLDocument($display, array('pagetitle' => $MESSAGE[30]));
     COM_accessLog("User {$_USER['username']} tried to illegally access the user administration screen.");
     COM_output($display);
     exit;
@@ -86,10 +86,7 @@ function edituser($uid = '', $msg = '')
     $retval = '';
 
     if (!empty ($msg)) {
-        $retval .= COM_startBlock ($LANG28[22], '',
-                           COM_getBlockTemplate ('_msg_block', 'header'))
-                . $MESSAGE[$msg]
-                . COM_endBlock (COM_getBlockTemplate ('_msg_block', 'footer'));
+        $retval .= COM_showMessageText($MESSAGE[$msg], $LANG28[22]);
     }
 
     if (!empty ($msg) && !empty ($uid) && ($uid > 1)) {
@@ -111,11 +108,9 @@ function edituser($uid = '', $msg = '')
         if (SEC_inGroup('Root',$uid) AND !SEC_inGroup('Root')) {
             // the current admin user isn't Root but is trying to change
             // a root account.  Deny them and log it.
-            $retval .= COM_startBlock ($LANG28[1], '',
-                               COM_getBlockTemplate ('_msg_block', 'header'));
-            $retval .= $LANG_ACCESS['editrootmsg'];
+            $retval .= COM_showMessageText($LANG_ACCESS['editrootmsg'],
+                                           $LANG28[1]);
             COM_accessLog("User {$_USER['username']} tried to edit a Root account with insufficient privileges.");
-            $retval .= COM_endBlock (COM_getBlockTemplate ('_msg_block', 'footer'));
             return $retval;
         }
         $curtime = COM_getUserDateTimeFormat($A['regdate']);
@@ -124,12 +119,29 @@ function edituser($uid = '', $msg = '')
     } else {
         $A['uid'] = '';
         $uid = '';
-        $curtime =  COM_getUserDateTimeFormat();
+        $curtime = COM_getUserDateTimeFormat();
         $lastlogin = '';
         $lasttime = '';
         $A['status'] = USER_ACCOUNT_ACTIVE;
     }
 
+    // POST data can override, in case there was an error while editing a user
+    if (isset($_POST['username'])) {
+        $A['username'] = strip_tags($_POST['username']);
+    }
+    if (isset($_POST['fullname'])) {
+        $A['fullname'] = strip_tags($_POST['fullname']);
+    }
+    if (isset($_POST['email'])) {
+        $A['email'] = strip_tags($_POST['email']);
+    }
+    if (isset($_POST['homepage'])) {
+        $A['homepage'] = strip_tags($_POST['homepage']);
+    }
+    if (isset($_POST['userstatus'])) {
+        $A['status'] = COM_applyFilter($_POST['userstatus'], true);
+    }
+
     $token = SEC_createToken();
 
     $retval .= COM_startBlock($LANG28[1], '',
@@ -306,6 +318,13 @@ function edituser($uid = '', $msg = '')
                 $selected .= ' ' . $def_grp;
             }
         }
+
+        // in case of an error we may have previously selected a different
+        // mix of groups already - reconstruct those from the POST data
+        if (isset($_POST['groups']) && (count($_POST['groups']) > 0)) {
+            $selected = implode(' ', $_POST['groups']);
+        }
+
         $thisUsersGroups = SEC_getUserGroups();
         $remoteGroup = DB_getItem($_TABLES['groups'], 'grp_id',
                                   "grp_name = 'Remote Users'");
@@ -434,7 +453,7 @@ function listusers()
 
     $query_arr = array('table' => 'users',
                        'sql' => $sql,
-                       'query_fields' => array('username', 'email', 'fullname'),
+                       'query_fields' => array('username', 'email', 'fullname', 'homepage'),
                        'default_filter' => "AND {$_TABLES['users']}.uid > 1");
 
     $retval .= ADMIN_list('user', 'ADMIN_getListField_users', $header_arr,
@@ -470,8 +489,9 @@ function saveusers ($uid, $username, $fullname, $passwd, $passwd_conf, $email, $
         COM_errorLog("group size at beginning = " . count($groups), 1);
     }
     
+    $service = DB_getItem($_TABLES['users'], 'remoteservice', "uid = $uid");
     // If remote service then assume blank password
-    if ($A['remoteservice'] != '') {
+    if (! empty($service)) {
         $passwd = '';
         $passwd_conf = '';
     }
@@ -487,8 +507,6 @@ function saveusers ($uid, $username, $fullname, $passwd, $passwd_conf, $email, $
         if (empty($uid)) {
             $nameAndEmailOkay = false; // new users need an email address
         } else {
-            $service = DB_getItem($_TABLES['users'], 'remoteservice',
-                                  "uid = $uid");
             if (empty($service)) {
                 $nameAndEmailOkay = false; // not a remote user - needs email
             }
@@ -501,14 +519,13 @@ function saveusers ($uid, $username, $fullname, $passwd, $passwd_conf, $email, $
             return edituser($uid, 52);
         }
 
-        $uname = addslashes ($username);
+        $uname = DB_escapeString($username);
         if (empty ($uid)) {
             $ucount = DB_getItem ($_TABLES['users'], 'COUNT(*)',
                                   "username = '$uname'");
         } else {
-            $uservice = DB_getItem ($_TABLES['users'], 'remoteservice', "uid = $uid");
-            if ($uservice != '') {
-                $uservice = addslashes($uservice);
+            if (! empty($service)) {
+                $uservice = DB_escapeString($service);
                 $ucount = DB_getItem ($_TABLES['users'], 'COUNT(*)',
                             "username = '$uname' AND uid <> $uid AND remoteservice = '$uservice'");
             } else {
@@ -521,7 +538,7 @@ function saveusers ($uid, $username, $fullname, $passwd, $passwd_conf, $email, $
             return edituser ($uid, 51);
         }
 
-        $emailaddr = addslashes($email);
+        $emailaddr = DB_escapeString($email);
         $exclude_remote = " AND (remoteservice IS NULL OR remoteservice = '')";
         if (empty($uid)) {
             $ucount = DB_getItem($_TABLES['users'], 'COUNT(*)',
@@ -554,21 +571,10 @@ function saveusers ($uid, $username, $fullname, $passwd, $passwd_conf, $email, $
             }
         }
 
-        if (empty ($uid) || !empty ($passwd)) {
-            $passwd = SEC_encryptPassword($passwd);
-        } else {
-            if ($A['remoteservice'] != '') {
-                $passwd = DB_getItem ($_TABLES['users'], 'passwd', "uid = $uid");
-            }
-        }
-
         if (empty ($uid)) {
             if (empty ($passwd)) {
                 // no password? create one ...
-                $passwd = rand ();
-                $passwd = md5 ($passwd);
-                $passwd = substr ($passwd, 1, 8);
-                $passwd = SEC_encryptPassword($passwd);
+                $passwd = SEC_generateRandomPassword();
             }
 
             $uid = USER_createAccount ($username, $email, $passwd, $fullname,
@@ -577,8 +583,8 @@ function saveusers ($uid, $username, $fullname, $passwd, $passwd_conf, $email, $
                 DB_query("UPDATE {$_TABLES['users']} SET status = $userstatus WHERE uid = $uid");
             }
         } else {
-            $fullname = addslashes ($fullname);
-            $homepage = addslashes ($homepage);
+            $fullname = DB_escapeString($fullname);
+            $homepage = DB_escapeString($homepage);
             $curphoto = DB_getItem($_TABLES['users'],'photo',"uid = $uid");
             if (!empty ($curphoto) && ($delete_photo == 'on')) {
                 USER_deletePhoto ($curphoto);
@@ -593,20 +599,21 @@ function saveusers ($uid, $username, $fullname, $passwd, $passwd_conf, $email, $
                     $newphoto = preg_replace ('/' . $curusername . '/',
                                               $username, $curphoto, 1);
                     $imgpath = $_CONF['path_images'] . 'userphotos/';
-                    if (rename ($imgpath . $curphoto,
+                    if (@rename ($imgpath . $curphoto,
                                 $imgpath . $newphoto) === false) {
-                        $display = COM_siteHeader ('menu', $LANG28[22]);
-                        $display .= COM_errorLog ('Could not rename userphoto "'
+                        $retval .= COM_errorLog ('Could not rename userphoto "'
                                         . $curphoto . '" to "' . $newphoto . '".');
-                        $display .= COM_siteFooter ();
-                        return $display;
+                        return $retval;
                     }
                     $curphoto = $newphoto;
                 }
             }
 
-            $curphoto = addslashes ($curphoto);
-            DB_query("UPDATE {$_TABLES['users']} SET username = '$username', fullname = '$fullname', passwd = '$passwd', email = '$email', homepage = '$homepage', photo = '$curphoto', status='$userstatus' WHERE uid = $uid");
+            $curphoto = DB_escapeString($curphoto);
+            DB_query("UPDATE {$_TABLES['users']} SET username = '$username', fullname = '$fullname', email = '$email', homepage = '$homepage', photo = '$curphoto', status='$userstatus' WHERE uid = $uid");
+            if (!empty($passwd)) {
+                SEC_updateUserPassword($passwd, $uid);
+            }
             if ($_CONF['custom_registration'] AND (function_exists('CUSTOM_userSave'))) {
                 CUSTOM_userSave($uid);
             }
@@ -688,22 +695,21 @@ function saveusers ($uid, $username, $fullname, $passwd, $passwd_conf, $email, $
                 21
             );
         } else {
-            $retval .= COM_siteHeader ('menu', $LANG28[22]);
             $retval .= COM_errorLog ('Error in saveusers in '
                                      . $_CONF['site_admin_url'] . '/user.php');
-            $retval .= COM_siteFooter ();
+            $retval = COM_createHTMLDocument($retval, array('pagetitle' => $LANG28[22]));
             echo $retval;
             exit;
         }
     } else {
-        $retval = COM_siteHeader('menu', $LANG28[1]);
         $retval .= COM_showMessageText($LANG28[10]);
-        if (DB_count($_TABLES['users'], 'uid', $uid) > 0) {
+        if (!empty($uid) && ($uid > 1) &&
+                DB_count($_TABLES['users'], 'uid', $uid) > 0) {
             $retval .= edituser($uid);
         } else {
             $retval .= edituser();
         }
-        $retval .= COM_siteFooter();
+        $retval = COM_createHTMLDocument($retval, array('pagetitle' => $LANG28[1]));
         COM_output($retval);
         exit;
     }
@@ -737,19 +743,27 @@ function batchdelete()
     $usr_type = '';
     if (isset($_REQUEST['usr_type'])) {
         $usr_type = COM_applyFilter($_REQUEST['usr_type']);
-    } else {
+    }
+    if (! in_array($usr_type, array('phantom', 'sort', 'old', 'recent'))) {
         $usr_type = 'phantom';
     }
+
     $usr_time_arr = array();
+    // default values, in months
+    $usr_time_arr['phantom'] =  2;
+    $usr_time_arr['short']   =  6;
+    $usr_time_arr['old']     = 24;
+    $usr_time_arr['recent']  =  1;
+
     $usr_time = '';
     if (isset($_REQUEST['usr_time'])) {
-        $usr_time_arr = $_REQUEST['usr_time'];
-    } else {
-        // default values, in months
-        $usr_time_arr['phantom'] =  2;
-        $usr_time_arr['short']   =  6;
-        $usr_time_arr['old']     = 24;
-        $usr_time_arr['recent']  =  1;
+        // 'usr_time' is an array when clicking "Update List" but a single
+        // value when actually deleting users
+        if (is_array($_REQUEST['usr_time'])) {
+            $usr_time_arr = $_REQUEST['usr_time'];
+        } else {
+            $usr_time_arr[$usr_type] = (int) $_REQUEST['usr_time'];
+        }
     }
     $usr_time = $usr_time_arr[$usr_type];
 
@@ -1064,18 +1078,14 @@ function importusers()
         }
     } else {
         // A problem occurred, print debug information
-        $retval = COM_siteHeader ('menu', $LANG28[22]);
-        $retval .= COM_startBlock ($LANG28[24], '',
-                COM_getBlockTemplate ('_msg_block', 'header'));
-        $retval .= $upload->printErrors(false);
-        $retval .= COM_endBlock (COM_getBlockTemplate ('_msg_block', 'footer'));
+        $retval = COM_showMessageText($upload->printErrors(false), $LANG28[24]);
+        $retval = COM_createHTMLDocument($retval, array('pagetitle' => $LANG28[22]));
 
         return $retval;
     }
 
     $users = file ($filename);
 
-    $retval .= COM_siteHeader ('menu', $LANG28[24]);
     $retval .= COM_startBlock ($LANG28[31], '',
             COM_getBlockTemplate ('_admin_block', 'header'));
 
@@ -1107,9 +1117,9 @@ function importusers()
         if (COM_isEmail ($email)) {
             // email is valid form
             $ucount = DB_count ($_TABLES['users'], 'username',
-                                addslashes ($userName));
+                                DB_escapeString($userName));
             $ecount = DB_count ($_TABLES['users'], 'email',
-                                addslashes ($emailAddr));
+                                DB_escapeString($emailAddr));
 
             if (($ucount == 0) && ($ecount == 0)) {
                 // user doesn't already exist - pass in optional true for $batchimport parm
@@ -1150,7 +1160,7 @@ function importusers()
     $retval .= '<p>' . sprintf ($LANG28[32], $successes, $failures);
 
     $retval .= COM_endBlock (COM_getBlockTemplate ('_admin_block', 'footer'));
-    $retval .= COM_siteFooter ();
+    $retval = COM_createHTMLDocument($retval, array('pagetitle' => $LANG28[24]));
 
     return $retval;
 }
@@ -1170,7 +1180,6 @@ function display_batchAddform()
     $retval = '';
 
     $token = SEC_createToken();
-    $retval .= COM_siteHeader('menu', $LANG28[24]);
     $retval .= COM_startBlock ($LANG28[24], '',
                         COM_getBlockTemplate ('_admin_block', 'header'));
 
@@ -1198,7 +1207,7 @@ function display_batchAddform()
             . "\" value=\"{$token}\"" . XHTML . '></div></form>' . LB;
 
     $retval .= COM_endBlock (COM_getBlockTemplate ('_admin_block', 'footer'));
-    $retval .= COM_siteFooter();
+    $retval = COM_createHTMLDocument($retval, array('pagetitle' => $LANG28[24]));
 
     return $retval;
 }
@@ -1239,17 +1248,7 @@ if (isset ($_GET['direction'])) {
     $direction =  COM_applyFilter ($_GET['direction']);
 }
 
-if (isset ($_POST['passwd']) && isset ($_POST['passwd_conf']) &&
-        ($_POST['passwd'] != $_POST['passwd_conf'])) {
-    // entered passwords were different
-    $uid = COM_applyFilter ($_POST['uid'], true);
-    if ($uid > 1) {
-        $display .= COM_refresh ($_CONF['site_admin_url']
-                                 . '/user.php?mode=edit&amp;msg=67&amp;uid=' . $uid);
-    } else {
-        $display .= COM_refresh ($_CONF['site_admin_url'] . '/user.php?msg=67');
-    }
-} elseif (($mode == $LANG_ADMIN['delete']) && !empty ($LANG_ADMIN['delete'])) { // delete
+if (($mode == $LANG_ADMIN['delete']) && !empty ($LANG_ADMIN['delete'])) { // delete
     $uid = COM_applyFilter($_POST['uid'], true);
     if ($uid <= 1) {
         COM_errorLog('Attempted to delete user uid=' . $uid);
@@ -1277,19 +1276,23 @@ if (isset ($_POST['passwd']) && isset ($_POST['passwd_conf']) &&
         echo COM_refresh($_CONF['site_admin_url'] . '/index.php');
         exit;
     } else {
+        $passwd = '';
+        if (isset($_POST['passwd'])) {
+            $passwd = $_POST['passwd'];
+        }
+        $passwd_conf = '';
+        if (isset($_POST['passwd_conf'])) {
+            $passwd_conf = $_POST['passwd_conf'];
+        }
         $display = saveusers($uid, $_POST['username'], $_POST['fullname'],
-                    $_POST['passwd'], $_POST['passwd_conf'], $_POST['email'],
-                    $_POST['regdate'], $_POST['homepage'], $_POST['groups'],
-                    $delphoto, $_POST['userstatus'], $_POST['oldstatus']);
+                    $passwd, $passwd_conf, $_POST['email'], $_POST['regdate'],
+                    $_POST['homepage'], $_POST['groups'], $delphoto,
+                    $_POST['userstatus'], $_POST['oldstatus']);
         if (!empty($display)) {
-            $tmp = COM_siteHeader('menu', $LANG28[22]);
-            $tmp .= $display;
-            $tmp .= COM_siteFooter();
-            $display = $tmp;
+            $display = COM_createHTMLDocument($display, array('pagetitle' => $LANG28[22]));
         }
     }
 } elseif ($mode == 'edit') {
-    $display .= COM_siteHeader('menu', $LANG28[1]);
     $msg = '';
     if (isset($_GET['msg'])) {
         $msg = COM_applyFilter($_GET['msg'], true);
@@ -1301,35 +1304,28 @@ if (isset ($_POST['passwd']) && isset ($_POST['passwd_conf']) &&
     if ($uid == 1) {
         echo COM_refresh($_CONF['site_admin_url'] . '/index.php');
         exit;
-    } else {
-        $display .= edituser($uid, $msg);
-        $display .= COM_siteFooter();
     }
+    $display .= edituser($uid, $msg);
+    $display = COM_createHTMLDocument($display, array('pagetitle' => $LANG28[1]));
 } elseif (($mode == 'import') && SEC_checkToken()) {
     $display .= importusers();
 } elseif ($mode == 'importform') {
     $display .= display_batchAddform();
 } elseif ($mode == 'batchdelete') {
-    $display .= COM_siteHeader ('menu', $LANG28[54]);
     $display .= batchdelete();
-    $display .= COM_siteFooter();
+    $display = COM_createHTMLDocument($display, array('pagetitle' => $LANG28[54]));
 } elseif (($mode == $LANG28[78]) && !empty($LANG28[78]) && SEC_checkToken()) {
     $msg = batchreminders();
-    $display .= COM_siteHeader ('menu', $LANG28[11])
-        . COM_showMessage($msg)
-        . batchdelete()
-        . COM_siteFooter();
+    $display .= COM_showMessage($msg) . batchdelete();
+    $display = COM_createHTMLDocument($display, array('pagetitle' => $LANG28[11]));
 } elseif (($mode == 'batchdeleteexec') && SEC_checkToken()) {
     $msg = batchdeleteexec();
-    $display .= COM_siteHeader ('menu', $LANG28[11])
-        . COM_showMessage($msg)
-        . batchdelete()
-        . COM_siteFooter();
+    $display .= COM_showMessage($msg) . batchdelete();
+    $display = COM_createHTMLDocument($display, array('pagetitle' => $LANG28[11]));
 } else { // 'cancel' or no mode at all
-    $display .= COM_siteHeader('menu', $LANG28[11]);
     $display .= COM_showMessageFromParameter();
     $display .= listusers();
-    $display .= COM_siteFooter();
+    $display = COM_createHTMLDocument($display, array('pagetitle' => $LANG28[11]));
 }
 
 COM_output($display);
