@@ -65,9 +65,16 @@ $order = '';
 $query = '';
 $reply = '';
 $page = 0;
+$mode = '';
 if (isset ($_POST['mode'])) {
-    $sid = COM_applyFilter ($_POST['story']);
     $mode = COM_applyFilter ($_POST['mode']);
+} else if (isset ($_POST['format'])) {
+    $mode = COM_applyFilter ($_POST['format']);
+}
+if (!empty($mode)) {
+    if (isset ($_POST['story'])) {
+        $sid = COM_applyFilter ($_POST['story']);
+    }
     if (isset ($_POST['order'])) {
         $order = COM_applyFilter ($_POST['order']);
     }
@@ -98,10 +105,19 @@ if (isset ($_POST['mode'])) {
     }
 }
 
-if (empty ($sid)) {
-    echo COM_refresh ($_CONF['site_url'] . '/index.php');
-    exit();
+if (!empty ($_REQUEST['sid'])) {
+    $sid = COM_applyFilter ($_REQUEST['sid']);
 }
+if (empty ($sid) && !empty ($_POST['cmt_sid'])) {
+    $sid = COM_applyFilter ($_POST['cmt_sid']);
+}
+if (empty ($sid)) {
+    COM_handle404();
+}
+
+// Get topic
+TOPIC_getTopic('article', $sid);
+
 if ((strcasecmp ($order, 'ASC') != 0) && (strcasecmp ($order, 'DESC') != 0)) {
     $order = '';
 }
@@ -136,21 +152,13 @@ if ($A['count'] > 0) {
     }
 
     if ($output == STORY_PERMISSION_DENIED) {
-        $display .= COM_siteHeader ('menu', $LANG_ACCESS['accessdenied'])
-                 . COM_startBlock ($LANG_ACCESS['accessdenied'], '',
-                           COM_getBlockTemplate ('_msg_block', 'header'))
-                 . $LANG_ACCESS['storydenialmsg']
-                 . COM_endBlock (COM_getBlockTemplate ('_msg_block', 'footer'))
-                 . COM_siteFooter ();
+        $display = COM_showMessageText($LANG_ACCESS['storydenialmsg'], $LANG_ACCESS['accessdenied']);
+        $display = COM_createHTMLDocument($display, array('pagetitle' => $LANG_ACCESS['accessdenied']));
     } elseif ( $output == STORY_INVALID_SID ) {
-        $display .= COM_refresh($_CONF['site_url'] . '/index.php');
+        COM_handle404();
     } elseif (($mode == 'print') && ($_CONF['hideprintericon'] == 0)) {
-        $story_template = new Template($_CONF['path_layout'] . 'article');
+        $story_template = COM_newTemplate($_CONF['path_layout'] . 'article');
         $story_template->set_file('article', 'printable.thtml');
-        $story_template->set_var('xhtml', XHTML);
-        $story_template->set_var('site_url', $_CONF['site_url']);
-        $story_template->set_var('site_admin_url', $_CONF['site_admin_url']);
-        $story_template->set_var('layout_url', $_CONF['layout_url']);
         if (XHTML != '') {
             $story_template->set_var('xmlns',
                                      ' xmlns="http://www.w3.org/1999/xhtml"');
@@ -244,10 +252,20 @@ if ($A['count'] > 0) {
                     . XHTML . '>';
 
         // Meta Tags
-        If ($_CONF['meta_tags'] > 0) {
-            $meta_description  = $story->DisplayElements('meta_description');
-            $meta_keywords  = $story->DisplayElements('meta_keywords');        
-            $headercode .= COM_createMetaTags($meta_description, $meta_keywords);
+        if ($_CONF['meta_tags'] > 0) {
+            $headercode .= LB . PLG_getMetaTags(
+                'article', $story->getSid(),
+                array(
+                    array(
+                        'name'    => 'description',
+                        'content' => $story->DisplayElements('meta_description')
+                    ),
+                    array(
+                        'name'    => 'keywords',
+                        'content' => $story->DisplayElements('meta_keywords')
+                    )
+                )
+            );
         }
 
         if ($story->DisplayElements('trackbackcode') == 0) {
@@ -261,8 +279,6 @@ if ($A['count'] > 0) {
                 header('X-Pingback: ' . $_CONF['site_url'] . '/pingback.php');
             }
         }
-        
-        $display .= COM_siteHeader('menu', $pagetitle, $headercode);
 
         if (isset($_GET['msg'])) {
             $msg = COM_applyFilter($_GET['msg'], true);
@@ -275,17 +291,16 @@ if ($A['count'] > 0) {
             }
         }
 
-        DB_query ("UPDATE {$_TABLES['stories']} SET hits = hits + 1 WHERE (sid = '".$story->getSid()."') AND (date <= NOW()) AND (draft_flag = 0)");
+		// Don't count views for the author of the article (feature request #0001572)
+		if (COM_isAnonUser() || ($_USER['uid'] != $story->displayElements('uid'))) {
+			DB_query("UPDATE {$_TABLES['stories']} SET hits = hits + 1 WHERE (sid = '" . DB_escapeString($story->getSid()) . "') AND (date <= NOW()) AND (draft_flag = 0)");
+		}
 
         // Display whats related
 
-        $story_template = new Template($_CONF['path_layout'] . 'article');
+        $story_template = COM_newTemplate($_CONF['path_layout'] . 'article');
         $story_template->set_file('article','article.thtml');
 
-        $story_template->set_var('xhtml', XHTML);
-        $story_template->set_var('site_url', $_CONF['site_url']);
-        $story_template->set_var('site_admin_url', $_CONF['site_admin_url']);
-        $story_template->set_var('layout_url', $_CONF['layout_url']);
         $story_template->set_var('story_id', $story->getSid());
         $story_template->set_var('story_title', $pagetitle);
         $story_options = array ();
@@ -333,7 +348,7 @@ if ($A['count'] > 0) {
 
             // also check permissions for the topic
             $topic_anon = DB_getItem($_TABLES['topics'], 'perm_anon',
-                "tid = '" . addslashes($story->displayElements('tid')) . "'");
+                "tid = '" . DB_escapeString($story->displayElements('tid')) . "'");
 
             // check special case: no link when Trackbacks are disabled for this
             // story AND pinging weblog directories is disabled
@@ -356,7 +371,7 @@ if ($A['count'] > 0) {
     */
         $related = STORY_whatsRelated($story->displayElements('related'),
                                       $story->displayElements('uid'),
-                                      $story->displayElements('tid'));
+                                      $story->getSid());
         if (!empty ($related)) {
             $related = COM_startBlock ($LANG11[1], '',
                 COM_getBlockTemplate ('whats_related_block', 'header'))
@@ -378,27 +393,39 @@ if ($A['count'] > 0) {
         $story_template->set_var ('whats_related_story_options',
                                   $related . $optionsblock);
 
+        // Another option here could be to figure out if story is first on page
+        $tmpl = $_CONF['showfirstasfeatured'] ? 'featuredstorytext.thtml' : '';
         $story_template->set_var ('formatted_article',
-                                  STORY_renderArticle ($story, 'n', '', $query));
+                                  STORY_renderArticle ($story, 'n', $tmpl, $query));
 
         // display comments or not?
-        if ( (is_numeric($mode)) and ($_CONF['allow_page_breaks'] == 1) )
-        {
-            $story_page = $mode;
-            $mode = '';
+        if ($_CONF['allow_page_breaks'] == 1) {
+            if (!is_numeric($mode)){
+                $story_page = 1;
+            } else {
+                $story_page = $mode;
+                $mode = '';
+            }
+
             if( $story_page <= 0 ) {
                 $story_page = 1;
             }
+
             $article_arr = explode( '[page_break]', $story->displayElements('bodytext'));
-            $conf = $_CONF['page_break_comments'];
-            if  (
-                 ($conf == 'all') or
-                 ( ($conf =='first') and ($story_page == 1) ) or
-                 ( ($conf == 'last') and (count($article_arr) == ($story_page)) )
-                ) {
-                $show_comments = true;
+            $page_break_count = count($article_arr);
+            if ($page_break_count > 1) {
+                $conf = $_CONF['page_break_comments'];
+                if  (
+                     ($conf == 'all') or
+                     ( ($conf =='first') and ($story_page == 1) ) or
+                     ( ($conf == 'last') and ($page_break_count == $story_page) )
+                    ) {
+                    $show_comments = true;
+                } else {
+                    $show_comments = false;
+                }
             } else {
-                $show_comments = false;
+                $show_comments = true;
             }
         } else {
             $show_comments = true;
@@ -408,7 +435,6 @@ if ($A['count'] > 0) {
         if (($story->displayElements('commentcode') >= 0) and $show_comments) {
             $delete_option = (SEC_hasRights('story.edit') && ($story->getAccess() == 3)
                              ? true : false);
-            require_once ( $_CONF['path_system'] . 'lib-comment.php' );
             $story_template->set_var ('commentbar',
                     CMT_userComments ($story->getSid(), $story->displayElements('title'), 'article',
                                       $order, $mode, 0, $page, false, $delete_option, $story->displayElements('commentcode')));
@@ -437,10 +463,13 @@ if ($A['count'] > 0) {
             $story_template->set_var ('trackback', '');
         }
         $display .= $story_template->finish ($story_template->parse ('output', 'article'));
-        $display .= COM_siteFooter ();
+
+        $breadcrumbs = TOPIC_breadcrumbs('article', $story->getSid());
+
+        $display = COM_createHTMLDocument($display, array('pagetitle' => $pagetitle, 'breadcrumbs' => $breadcrumbs, 'headercode' => $headercode));
     }
 } else {
-    $display .= COM_refresh($_CONF['site_url'] . '/index.php');
+    COM_handle404();  
 }
 
 COM_output($display);
