@@ -35,7 +35,7 @@
 require_once '../lib-common.php';
 
 if (!in_array('calendar', $_PLUGINS)) {
-    echo COM_refresh($_CONF['site_url'] . '/index.php');
+    COM_handle404();
     exit;
 }
 
@@ -108,7 +108,7 @@ function adduserevent ($eid)
         $cal_template->set_var('lang_description', $LANG_CAL_1[5]);
         $description = stripslashes ($A['description']);
         if (empty($A['postmode']) || ($A['postmode'] == 'plaintext')) {
-            $description = nl2br ($description);
+            $description = COM_nl2br($description);
         }
         $cal_template->set_var ('event_description',
                                 PLG_replaceTags ($description));
@@ -290,7 +290,7 @@ function editpersonalevent ($A)
 
     $cal_templates->set_var('lang_description', $LANG_CAL_1[5]);
     $cal_templates->set_var('event_description',
-                            nl2br (stripslashes ($A['description'])));
+                            COM_nl2br(stripslashes($A['description'])));
 
     $cal_templates->set_var('lang_htmlnotallowed', $LANG_CAL_1[44]);
     $cal_templates->set_var('lang_submit', $LANG_CAL_1[45]);
@@ -353,16 +353,13 @@ if (isset ($_REQUEST['action'])) {
 switch ($action) {
 case 'addevent':
     if (($_CA_CONF['personalcalendars'] == 1) && !COM_isAnonUser()) {
-        $display .= COM_siteHeader ();
-
         $eid = COM_applyFilter ($_GET['eid']);
         if (!empty ($eid)) {
             $display .= adduserevent ($eid);
         } else {
             $display .= COM_showMessage (23);
         }
-
-        $display .= COM_siteFooter ();
+        $display = COM_createHTMLDocument($display);
     } else {
         $display = COM_refresh ($_CONF['site_url'] . '/index.php');
     }
@@ -374,9 +371,8 @@ case 'saveuserevent':
         if (!empty ($eid)) {
             $display .= saveuserevent ($eid);
         } else {
-            $display .= COM_siteHeader ();
             $display .= COM_showMessage (23);
-            $display .= COM_siteFooter ();
+            $display = COM_createHTMLDocument($display);
         }
     } else {
         $display = COM_refresh ($_CONF['site_url'] . '/index.php');
@@ -417,11 +413,10 @@ case 'edit':
             $result = DB_query ("SELECT * FROM {$_TABLES['personal_events']} WHERE (eid = '$eid') AND (uid = {$_USER['uid']})");
             if (DB_numRows ($result) == 1) {
                 $A = DB_fetchArray ($result);
-                $display .= COM_siteHeader ('menu', $LANG_CAL_2[38])
-                         . COM_startBlock ($LANG_CAL_2[38])
+                $display .= COM_startBlock ($LANG_CAL_2[38])
                          . editpersonalevent ($A)
-                         . COM_endBlock ()
-                         . COM_siteFooter ();
+                         . COM_endBlock ();
+                $display = COM_createHTMLDocument($display, array('pagetitle' => $LANG_CAL_2[38]));
             } else {
                 $display = COM_refresh ($_CONF['site_url'] . '/index.php');
             }
@@ -462,7 +457,6 @@ default:
             DB_query ("UPDATE {$_TABLES['events']} SET hits = hits + 1 WHERE eid = '$eid'");
         }
 
-        $display .= COM_siteHeader('menu', $pagetitle);
         if (isset($_GET['msg'])) {
             $msg = COM_applyFilter($_GET['msg'], true);
             if ($msg > 0) {
@@ -492,7 +486,6 @@ default:
 
         $pagetitle = $LANG_CAL_2[10] . ' ' . strftime ($_CONF['shortdate'],
                                          mktime (0, 0, 0, $month, $day, $year));
-        $display .= COM_siteHeader ('menu', $pagetitle);
         $display .= COM_startBlock ($pagetitle);
 
         $thedate = sprintf ('%4d-%02d-%02d', $year, $month, $day);
@@ -663,7 +656,7 @@ default:
                 $cal_templates->set_var('lang_description', $LANG_CAL_1[5]);
                 $description = stripslashes($A['description']);
                 if (empty($A['postmode']) || ($A['postmode'] == 'plaintext')) {
-                    $description = nl2br($description);
+                    $description = COM_nl2br($description);
                 }
                 $description = PLG_replaceTags($description);
                 if (!empty($query)) {
@@ -720,7 +713,8 @@ default:
         $display .= $cal_templates->finish ($cal_templates->get_var ('output'));
     }
 
-    $display .= COM_endBlock() . COM_siteFooter();
+    $display .= COM_endBlock();
+    $display = COM_createHTMLDocument($display, array('pagetitle' => $pagetitle));
 
 } // end switch
 
