@@ -61,7 +61,7 @@ function edituser()
                                    'username'      => 'username.thtml',
                                    'password'      => 'password.thtml',
                                    'current_password'      => 'current_password.thtml',
-                                   'resynch'      => 'resynch.thtml',
+                                   'resynch'       => 'resynch.thtml',
                                    'deleteaccount' => 'deleteaccount.thtml'));
 
     include ($_CONF['path_system'] . 'classes/navbar.class.php');
@@ -312,36 +312,28 @@ function confirmAccountDelete ($form_reqid)
         return COM_refresh ($_CONF['site_url'] . '/index.php');
     }
 
-    // to change the password, email address, or cookie timeout,
-    // we need the user's current password
-    $current_password = DB_getItem($_TABLES['users'], 'passwd',
-                                   "uid = {$_USER['uid']}");
-    if (empty($_POST['old_passwd']) ||
-            (SEC_encryptPassword($_POST['old_passwd']) != $current_password)) {
-         return COM_refresh($_CONF['site_url']
-                            . '/usersettings.php?msg=84');
+    // Do not check current password for remote users. At some point we should reauthenticate with the service when deleting the account
+    if ($_USER['remoteservice'] == '') {
+        // verify the password
+        if (empty($_POST['old_passwd']) ||
+                (SEC_encryptUserPassword($_POST['old_passwd'], $_USER['uid']) < 0)) {
+             return COM_refresh($_CONF['site_url']
+                                . '/usersettings.php?msg=84');
+        }
     }
-
+    
     $reqid = substr (md5 (uniqid (rand (), 1)), 1, 16);
     DB_change ($_TABLES['users'], 'pwrequestid', "$reqid",
                                   'uid', $_USER['uid']);
-
-    $retval = '';
-
-    $retval .= COM_siteHeader ('menu', $LANG04[97]);
-    $retval .= COM_startBlock ($LANG04[97], '',
-                               COM_getBlockTemplate ('_msg_block', 'header'));
-    $retval .= '<p>' . $LANG04[98] . '</p>' . LB;
-    $retval .= '<form action="' . $_CONF['site_url']
-            . '/usersettings.php" method="post"><div>' . LB;
-    $retval .= '<p align="center"><input type="submit" name="btnsubmit" value="'
-            . $LANG04[96] . '"' . XHTML . '></p>' . LB;
-    $retval .= '<input type="hidden" name="mode" value="deleteconfirmed"' . XHTML . '>' . LB;
-    $retval .= '<input type="hidden" name="account_id" value="' . $reqid
-            . '"' . XHTML . '>' . LB;
-    $retval .= '</div></form>' . LB;
-    $retval .= COM_endBlock (COM_getBlockTemplate ('_msg_block', 'footer'));
-    $retval .= COM_siteFooter ();
+    $msg = '<p>' . $LANG04[98] . '</p>' . LB . '<form action="' . $_CONF['site_url']
+         . '/usersettings.php" method="post"><div>' . LB
+         . '<p align="center"><input type="submit" name="btnsubmit" value="'
+         . $LANG04[96] . '"' . XHTML . '></p>' . LB
+         . '<input type="hidden" name="mode" value="deleteconfirmed"' . XHTML . '>' . LB
+         . '<input type="hidden" name="account_id" value="' . $reqid . '"' . XHTML . '>' . LB
+         . '</div></form>' . LB;
+    $retval = COM_showMessageText($msg, $LANG04[97]);
+    $retval = COM_createHTMLDocument($retval, array('pagetitle' => $LANG04[97]));
 
     return $retval;
 }
@@ -491,8 +483,13 @@ function editpreferences()
             $userlang = $_USER['language'];
         }
 
-        // Get available languages
-        $language = MBYTE_languageList ($_CONF['default_charset']);
+        // if multi-language content return just languages supported (assume config options are setup correctly and both contain the same language mappings)
+        if (!empty($_CONF['languages']) && !empty($_CONF['language_files'])) {
+            $language = MBYTE_languageList ($_CONF['default_charset'], true);
+        } else {
+            // Get available languages
+            $language = MBYTE_languageList ($_CONF['default_charset']);
+        }
 
         $has_valid_language = count (array_keys ($language, $userlang));
         if ($has_valid_language == 0) {
@@ -565,6 +562,30 @@ function editpreferences()
 
     if ($_CONF['advanced_editor'] == 1) {
         $preferences->set_var('lang_advanced_editor', $LANG04[165]);
+        $name = '';
+        $editor = $_CONF['advanced_editor_name'];
+        if (file_exists($_CONF['path_editors'] . $editor . '/functions.php')) {
+            require_once $_CONF['path_editors'] . $editor . '/functions.php';
+            $function = 'adveditor_config_' . $editor;
+            if (function_exists($function)) {
+                $config = $function();
+                $name = $config['name'];
+            }
+        }
+        if (empty($name)) {
+            $words = explode('_', $editor);
+            $bwords = array();
+            foreach ($words as $th) {
+                if ((strtolower($th[0]) == $th[0]) &&
+                    (strtolower($th[1]) == $th[1])) {
+                    $bwords[] = ucfirst($th);
+                } else {
+                    $bwords[] = $th;
+                }
+            }
+            $name = implode(' ', $bwords);
+        }
+        $preferences->set_var('adveditor_name', $name);
         if ($A['advanced_editor'] == 1) {
             $preferences->set_var('advanced_editor_checked', 'checked="checked"');
         } else {
@@ -624,10 +645,7 @@ function editpreferences()
     $preferences->parse ('privacy_block', 'privacy', true);
 
     // excluded items block
-    $permissions = COM_getPermSQL ('');
-    $preferences->set_var ('exclude_topic_checklist',
-        COM_checkList($_TABLES['topics'], 'tid,topic', $permissions, $A['tids'],
-                      'topics'));
+    $preferences->set_var ('exclude_topic_checklist', TOPIC_checkList($A['tids'], 'topics'));
 
     if (($_CONF['contributedbyline'] == 1) &&
         ($_CONF['hide_author_exclusion'] == 0)) {
@@ -647,7 +665,7 @@ function editpreferences()
             $B = DB_fetchArray ($query);
             $selauthors .= '<option value="' . $B['uid'] . '"';
             if (in_array (sprintf ('%d', $B['uid']), $authors)) {
-               $selauthors .= ' selected';
+               $selauthors .= ' selected="selected"';
             }
             $selauthors .= '>' . COM_getDisplayName ($B['uid'], $B['username'],
                                                      $B['fullname'])
@@ -676,10 +694,8 @@ function editpreferences()
         } elseif ($user_etids == '-') { // this means "no topics"
             $user_etids = '';
         }
-        $tmp = COM_checkList($_TABLES['topics'], 'tid,topic', $permissions,
-                             $user_etids, 'etids');
-        $preferences->set_var('email_topic_checklist',
-                str_replace($_TABLES['topics'], 'etids', $tmp));
+        $preferences->set_var ('email_topic_checklist', TOPIC_checkList($user_etids, 'etids'));
+        
         $preferences->parse('digest_block', 'digest', true);
     } else {
         $preferences->set_var('digest_block', '');
@@ -755,7 +771,7 @@ function emailAddressExists ($email, $uid)
         return false;
     }
 
-    $email = addslashes($email);
+    $email = DB_escapeString($email);
     $result = DB_query("SELECT uid FROM {$_TABLES['users']} WHERE email = '$email' AND uid <> '$uid' AND (remoteservice IS NULL OR remoteservice = '')");
     if (DB_numRows($result) > 0) {
         // email address is already in use for another non-remote account
@@ -807,13 +823,8 @@ function handlePhotoUpload ($delete_photo = '')
                                          'image/png'   => '.png'
                                  )      );
     if (!$upload->setPath ($_CONF['path_images'] . 'userphotos')) {
-        $display = COM_siteHeader ('menu', $LANG24[30]);
-        $display .= COM_startBlock ($LANG24[30], '',
-                COM_getBlockTemplate ('_msg_block', 'header'));
-        $display .= $upload->printErrors (false);
-        $display .= COM_endBlock (COM_getBlockTemplate ('_msg_block',
-                                                        'footer'));
-        $display .= COM_siteFooter ();
+        $display .= COM_showMessageText($upload->printErrors(false), $LANG24[30]);
+        $display = COM_createHTMLDocument($display, array('pagetitle' => $LANG24[30]));
         COM_output($display);
         exit; // don't return
     }
@@ -870,13 +881,8 @@ function handlePhotoUpload ($delete_photo = '')
         $upload->uploadFiles ();
 
         if ($upload->areErrors ()) {
-            $display = COM_siteHeader ('menu', $LANG24[30]);
-            $display .= COM_startBlock ($LANG24[30], '',
-                    COM_getBlockTemplate ('_msg_block', 'header'));
-            $display .= $upload->printErrors (false);
-            $display .= COM_endBlock (COM_getBlockTemplate ('_msg_block',
-                                                            'footer'));
-            $display .= COM_siteFooter ();
+            $display = COM_showMessageText($upload->printErrors (false), $LANG24[30]);
+            $display = COM_createHTMLDocument($display, array('pagetitle' => $LANG24[30]));
             COM_output($display);
             exit; // don't return
         }
@@ -928,12 +934,11 @@ function saveuser($A)
     // we need the user's current password
     $service = DB_getItem ($_TABLES['users'], 'remoteservice', "uid = {$_USER['uid']}"); 
     if ($service == '') {
-        $current_password = DB_getItem($_TABLES['users'], 'passwd',
-                                       "uid = {$_USER['uid']}");
         if (!empty ($A['passwd']) || ($A['email'] != $_USER['email']) ||
                 ($A['cooktime'] != $_USER['cookietimeout'])) {
+            // verify password
             if (empty($A['old_passwd']) ||
-                    (SEC_encryptPassword($A['old_passwd']) != $current_password)) {
+                    (SEC_encryptUserPassword($A['old_passwd'], $_USER['uid']) < 0)) {
     
                 return COM_refresh ($_CONF['site_url']
                                     . '/usersettings.php?msg=83');
@@ -974,7 +979,7 @@ function saveuser($A)
         $A['new_username'] = COM_applyFilter ($A['new_username']);
         if (!empty ($A['new_username']) &&
                 ($A['new_username'] != $_USER['username'])) {
-            $A['new_username'] = addslashes ($A['new_username']);
+            $A['new_username'] = DB_escapeString($A['new_username']);
             if (DB_count ($_TABLES['users'], 'username', $A['new_username']) == 0) {
                 if ($_CONF['allow_user_photo'] == 1) {
                     $photo = DB_getItem ($_TABLES['users'], 'photo',
@@ -985,14 +990,13 @@ function saveuser($A)
                         $imgpath = $_CONF['path_images'] . 'userphotos/';
                         if (rename ($imgpath . $photo,
                                     $imgpath . $newphoto) === false) {
-                            $display = COM_siteHeader ('menu', $LANG04[21]);
-                            $display .= COM_errorLog ('Could not rename userphoto "' . $photo . '" to "' . $newphoto . '".');
-                            $display .= COM_siteFooter ();
+                            $display = COM_errorLog ('Could not rename userphoto "' . $photo . '" to "' . $newphoto . '".');
+                            $display = COM_createHTMLDocument($display, array('pagetitle' => $LANG04[21]));
 
                             return $display;
                         }
                         DB_change ($_TABLES['users'], 'photo',
-                               addslashes ($newphoto), "uid", $_USER['uid']);
+                               DB_escapeString($newphoto), "uid", $_USER['uid']);
                     }
                 }
 
@@ -1043,10 +1047,8 @@ function saveuser($A)
         if ($service == '') {
             if (!empty($A['passwd'])) {
                 if (($A['passwd'] == $A['passwd_conf']) &&
-                        (SEC_encryptPassword($A['old_passwd']) == $current_password)) {
-                    $passwd = SEC_encryptPassword($A['passwd']);
-                    DB_change($_TABLES['users'], 'passwd', "$passwd",
-                              "uid", $_USER['uid']);
+                        (SEC_encryptUserPassword($A['old_passwd'], $_USER['uid']) == 0)) {
+                    SEC_updateUserPassword($A['passwd'], $_USER['uid']);
                     if ($A['cooktime'] > 0) {
                         $cooktime = $A['cooktime'];
                     } else {
@@ -1054,7 +1056,7 @@ function saveuser($A)
                     }
                     SEC_setCookie($_CONF['cookie_password'], $passwd,
                                   time() + $cooktime);
-                } elseif (SEC_encryptPassword($A['old_passwd']) != $current_password) {
+                } elseif (SEC_encryptUserPassword($A['old_passwd'], $_USER['uid']) < 0) {
                     return COM_refresh ($_CONF['site_url']
                                         . '/usersettings.php?msg=68');
                 } elseif ($A['passwd'] != $A['passwd_conf']) {
@@ -1105,15 +1107,15 @@ function saveuser($A)
                     $A['homepage'] = 'http:' . substr ($A['homepage'], $pos + 1);
                 }
             }
-            $A['homepage'] = addslashes ($A['homepage']);
+            $A['homepage'] = DB_escapeString($A['homepage']);
         }
 
-        $A['fullname'] = addslashes ($A['fullname']);
-        $A['email'] = addslashes ($A['email']);
-        $A['location'] = addslashes ($A['location']);
-        $A['sig'] = addslashes ($A['sig']);
-        $A['about'] = addslashes ($A['about']);
-        $A['pgpkey'] = addslashes ($A['pgpkey']);
+        $A['fullname'] = DB_escapeString($A['fullname']);
+        $A['email'] = DB_escapeString($A['email']);
+        $A['location'] = DB_escapeString($A['location']);
+        $A['sig'] = DB_escapeString($A['sig']);
+        $A['about'] = DB_escapeString($A['about']);
+        $A['pgpkey'] = DB_escapeString($A['pgpkey']);
 
         if (!empty ($filename)) {
             if (!file_exists ($_CONF['path_images'] . 'userphotos/' . $filename)) {
@@ -1130,44 +1132,31 @@ function saveuser($A)
         }
 
         PLG_userInfoChanged ($_USER['uid']);
-
-        $msg = 5;
-        // Re Sync data if needed
-        if (isset($A['resynch'])) {
-            if ($_CONF['user_login_method']['oauth'] && (strpos($_USER['remoteservice'], 'oauth.') === 0)) {       
+        
+        // at this point, the user information has been saved, but now we're going to check to see if
+        // the user has requested resynchronization with their remoteservice account
+        $msg = 5; // default msg = Your account information has been successfully saved
+        if (isset($A['resynch']) ) {
+            if ($_CONF['user_login_method']['oauth'] && (strpos($_USER['remoteservice'], 'oauth.') === 0)) {
                 $modules = SEC_collectRemoteOAuthModules();
-
                 $active_service = (count($modules) == 0) ? false : in_array(substr($_USER['remoteservice'], 6), $modules);
                 if (!$active_service) {
                     $status = -1;
                     $msg = 115; // Remote service has been disabled.
                 } else {
-                    $query[] = '';
-                    $callback_url = $_CONF['site_url'] . '/usersettings.php?mode=synch&oauth_login=' . $service;
-
-                    if ($service == 'oauth.facebook') {
-                        // facebook does resynch during refresh
-                        return COM_refresh($callback_url);
-                    } else {
-                        // all other services use reauth/callback method
-                        // send request to OAuth Service for user information
-                        require_once $_CONF['path_system'] . 'classes/oauthhelper.class.php';
-            
-                        $consumer = new OAuthConsumer($service);
-    
-                        $url = $consumer->find_identity_info($callback_url, $query);
-                        if (empty($url)) {
-                            $msg = 110; // Can not get URL for authentication.'
-                        } else {
-                            header('Location: ' . $url);
-                            exit;
-                        }
-                    }
-                }            
+                    require_once $_CONF['path_system'] . 'classes/oauthhelper.class.php';
+                    $service = substr($_USER['remoteservice'], 6);
+                    $consumer = new OAuthConsumer($service);
+                    $callback_url = $_CONF['site_url'];
+                    $consumer->setRedirectURL($callback_url);
+                    $user = $consumer->authenticate_user();
+                    $consumer->doSynch($user);
+                }
             }
-            
+
             if ($msg != 5) {
                 $msg = 114; // Account saved but re-synch failed.
+                COM_errorLog($MESSAGE[$msg]);
             }
         }
         
@@ -1253,7 +1242,7 @@ function savepreferences($A)
     $tids = '';
     if (count($TIDS) > 0) {
         // the array_intersect mitigates the need to scrub the TIDS input
-        $tids = addslashes (implode (' ', array_intersect ($AETIDS, $TIDS)));
+        $tids = DB_escapeString(implode (' ', array_intersect ($AETIDS, $TIDS)));
     }
 
     $aids = '';
@@ -1262,7 +1251,7 @@ function savepreferences($A)
         foreach ($AIDS as $key => $val) {
             $AIDS[$key] = COM_applyFilter($val, true);
         }
-        $aids = addslashes (implode (' ', $AIDS));
+        $aids = DB_escapeString(implode (' ', $AIDS));
     }
 
     $selectedblocks = '';
@@ -1271,7 +1260,7 @@ function savepreferences($A)
         foreach ($BOXES as $key => $val) {
             $BOXES[$key] = COM_applyFilter($val, true);
         }
-        $boxes = addslashes (implode (',', $BOXES));
+        $boxes = DB_escapeString(implode (',', $BOXES));
 
         $blockresult = DB_query("SELECT bid,name FROM {$_TABLES['blocks']} WHERE bid NOT IN ($boxes)");
         $numRows = DB_numRows($blockresult);
@@ -1290,7 +1279,7 @@ function savepreferences($A)
     $etids = '';
     if (($_CONF['emailstories'] == 1) && (count($ETIDS) > 0)) {
         // the array_intersect mitigates the need to scrub the ETIDS input
-        $etids = addslashes (implode (' ', array_intersect ($AETIDS, $ETIDS)));
+        $etids = DB_escapeString(implode (' ', array_intersect ($AETIDS, $ETIDS)));
     }
 
     if (isset ($A['tzid'])) {
@@ -1315,8 +1304,8 @@ function savepreferences($A)
 
     // Save theme, when doing so, put in cookie so we can set the user's theme
     // even when they aren't logged in
-    $theme = addslashes ($A['theme']);
-    $language = addslashes ($A['language']);
+    $theme = DB_escapeString($A['theme']);
+    $language = DB_escapeString($A['language']);
     DB_query("UPDATE {$_TABLES['users']} SET theme='$theme',language='$language' WHERE uid = '{$_USER['uid']}'");
     setcookie ($_CONF['cookie_theme'], $A['theme'], time() + 31536000,
                $_CONF['cookie_path'], $_CONF['cookiedomain'],
@@ -1340,13 +1329,13 @@ function savepreferences($A)
     if (empty ($A['commentmode'])) {
         $A['commentmode'] = $_CONF['comment_mode'];
     }
-    $A['commentmode'] = addslashes ($A['commentmode']);
+    $A['commentmode'] = DB_escapeString($A['commentmode']);
 
     $A['commentorder'] = COM_applyFilter ($A['commentorder']);
     if (empty ($A['commentorder'])) {
         $A['commentorder'] = 'ASC';
     }
-    $A['commentorder'] = addslashes ($A['commentorder']);
+    $A['commentorder'] = DB_escapeString($A['commentorder']);
 
     $A['commentlimit'] = COM_applyFilter ($A['commentlimit'], true);
     if ($A['commentlimit'] <= 0) {
@@ -1417,7 +1406,86 @@ if (! COM_isAnonUser()) {
         $display = COM_refresh ($_CONF['site_url']
                                 . '/usersettings.php?msg=5');
         break;
-        
+
+    case 'synch':
+        // This case is the result of a callback from an OAuth service.
+        // The user has made a request to resynch their glFusion user account with the remote OAuth service
+        if ($_CONF['user_login_method']['oauth'] && (strpos($_USER['remoteservice'], 'oauth.') === 0) && isset($_GET['oauth_login'])) {
+            $msg = 5;
+
+            $modules = SEC_collectRemoteOAuthModules();
+            $active_service = (count($modules) == 0) ? false : in_array(substr($_GET['oauth_login'], 6), $modules);
+            if (!$active_service) {
+                $status = -1;
+                $msg = 114; // resynch with remote account has failed but your other account information has been successfully saved.
+            } else {
+                $query = array_merge($_GET, $_POST);
+                $service = $query['oauth_login'];
+                // COM_errorLog("-------------------------------------------------------------------------");
+                // COM_errorLog("usersettings.php?mode=resynch&oauth_login={$service}");
+                // COM_errorLog("-------------------------------------------------------------------------");
+
+                require_once $_CONF['path_system'] . 'classes/oauthhelper.class.php';
+
+                $consumer = new OAuthConsumer($service);
+
+                if($service == 'oauth.facebook') {
+                    // facebook resynchronizations are simple to perform
+                    $oauth_userinfo = $consumer->refresh_userinfo();
+                    if (empty($oauth_userinfo)) {
+                        $msg = 114; // Account saved but re-synch failed.
+                        COM_errorLog($MESSAGE[$msg]);
+                    } else {
+                        $consumer->doSynch($oauth_userinfo);
+                    }
+                } else {
+                    // other OAuth services are more complex
+                    // setup what we need to callback and authenticate
+                    $callback_query_string = $consumer->getCallback_query_string();
+                    // COM_errorLog("callback_query_string={$callback_query_string}");
+                    $cancel_query_string = $consumer->getCancel_query_string();
+                    // COM_errorLog("cancel_query_string={$cancel_query_string}");
+                    $callback_url = $_CONF['site_url'] . '/usersettings.php?mode=synch&oauth_login=' . $service;
+                    // COM_errorLog("callback_url={$callback_url}");
+
+                    // authenticate with the remote service
+                    if (!isset($query[$callback_query_string]) && (empty($cancel_query_string) || !isset($query[$cancel_query_string]))) {
+                        $msg = 114; // Resynch with remote account has failed but other account information has been successfully saved
+                    // elseif the callback query string is set, then we have successfully authenticated
+                    } elseif (isset($query[$callback_query_string])) {
+                        // COM_errorLog("authenticated with remote service, retrieve userinfo");
+                        // foreach($query as $key=>$value) {
+                        //     COM_errorLog("query[{$key}]={$value}");
+                        // }
+                        $oauth_userinfo = $consumer->sreq_userinfo_response($query);
+                        if (empty($oauth_userinfo)) {
+                            $msg = 111; // Authentication error.
+                        } else {
+                            // COM_errorLog("resynchronizing userinfo");
+                            // foreach($oauth_userinfo as $key=>$value) {
+                            //     COM_errorLog("oauth_user_info[{$key}] set");
+                            // }
+                            $consumer->doSynch($oauth_userinfo);
+                        }
+                    } elseif (!empty($cancel_query_string) && isset($query[$cancel_query_string])) {
+                        $msg = 112; // Certification has been cancelled.
+                    } else {
+                        $msg = 91; // You specified an invalid identity URL.
+                    }
+                }
+            }
+
+            if ($msg == 5) {
+                $display = COM_refresh ($_CONF['site_url'] . '/users.php?mode=profile&amp;uid=' . $_USER['uid'] . '&amp;msg=5');
+            } else {
+                COM_errorLog($MESSAGE[$msg]);
+                $display = COM_refresh ($_CONF['site_url'] . '/usersettings.php?msg=' . $msg);
+            }
+            break;
+        }
+
+        // If OAuth is disabled, drop into default case
+/*        
     case 'synch':
         // This mode is the result of a callback from an OAuth service. The user has made a request to resynch their Geeklog user account with the OAuth service they used to login with.
         if ($_CONF['user_login_method']['oauth'] && (strpos($_USER['remoteservice'], 'oauth.') === 0) && isset($_GET['oauth_login'])) {
@@ -1484,20 +1552,18 @@ if (! COM_isAnonUser()) {
         }
         
         // Go right into default
-
+*/
     default: // also if $mode == 'edit', 'preferences', or 'comments'
-        $display .= COM_siteHeader('menu', $LANG04[16]);
         $display .= COM_showMessageFromParameter();
         $display .= edituser();
-        $display .= COM_siteFooter();
+        $display = COM_createHTMLDocument($display, array('pagetitle' => $LANG04[16]));
         break;
     }
 } else {
-    $display .= COM_siteHeader ('menu');
-    $display .= COM_startBlock ($LANG04[70] . '!');
-    $display .= '<br' . XHTML . '>' . $LANG04[71] . '<br' . XHTML . '><br' . XHTML . '>';
+    $display .= COM_startBlock ($LANG04[70]);
+    $display .= '<p>' . $LANG04[71] . '</p>';
     $display .= COM_endBlock ();
-    $display .= COM_siteFooter ();
+    $display = COM_createHTMLDocument($display);
 }
 
 COM_output($display);
