@@ -62,6 +62,12 @@ class config {
      */
     var $conf_type;
     
+    /**
+     * Whether support new theme format for the later Geeklog 2.0 or not
+     * @var boolean
+     */
+    var $flag_version_2;
+    
     /**
      * List of validation rules. Append entries for validation as 
      * ('field_name' => '/^perl_compat_regexp$/') that have to match
@@ -111,7 +117,8 @@ class config {
     /**
      * Constructor
      */
-    function __construct() {
+    function __construct()
+    {
         $this->config_array = array();
         
         $this->conf_tab_arr = null;
@@ -120,7 +127,7 @@ class config {
     }
 
     /**
-     * This mthod will return an instance of the config class. If an
+     * This method will return an instance of the config class. If an
      * instance with the given group/reference name does not exist, then it
      * will create a new one. This function insures    that there is only one
      * instance for a given group name.
@@ -131,7 +138,7 @@ class config {
      *
      *    @return config           The newly created or referenced config object
      */
-    function &get_instance()
+    public static function &get_instance()
     {
         static $instance;
 
@@ -282,6 +289,7 @@ class config {
                 [$tabs[$row[2]][$row[4]][$row[5]]][$row[5]][$row[0]] = $row[0];
             }
         }
+        $this->_post_initconfig();
         $this->_post_configuration();
 
         return $this->config_array;
@@ -337,15 +345,14 @@ class config {
     {
         global $_TABLES;
 
-        $escaped_val = addslashes(serialize($value));
-        $escaped_name = addslashes($name);
-        $escaped_grp = addslashes($group);
+        $escaped_val = DB_escapeString(serialize($value));
+        $escaped_name = DB_escapeString($name);
+        $escaped_grp = DB_escapeString($group);
         $sql = "UPDATE {$_TABLES['conf_values']} " .
                "SET value = '{$escaped_val}' WHERE " .
                "name = '{$escaped_name}' AND group_name = '{$escaped_grp}'";
         $this->_DB_escapedQuery($sql);
         $this->config_array[$group][$name] = $value;
-        $this->_post_configuration();
     }
 
     /**
@@ -362,9 +369,9 @@ class config {
     {
         global $_TABLES;
 
-        $escaped_val = addslashes(serialize($value));
-        $escaped_name = addslashes($name);
-        $escaped_grp = addslashes($group);
+        $escaped_val = DB_escapeString(serialize($value));
+        $escaped_name = DB_escapeString($name);
+        $escaped_grp = DB_escapeString($group);
         $sql = "UPDATE {$_TABLES['conf_values']} " .
                "SET default_value = '{$escaped_val}' WHERE " .
                "name = '{$escaped_name}' AND group_name = '{$escaped_grp}'";
@@ -392,15 +399,15 @@ class config {
             return false;
         }
 
-        $escaped_name = addslashes($name);
-        $escaped_grp = addslashes($group);
+        $escaped_name = DB_escapeString($name);
+        $escaped_grp = DB_escapeString($group);
 
         $result = DB_query("SELECT value, default_value FROM {$_TABLES['conf_values']} WHERE name = '{$escaped_name}' AND group_name = '{$escaped_grp}'");
         list($value, $default_value) = DB_fetchArray($result);
 
         $sql = "UPDATE {$_TABLES['conf_values']} ";
         if ($value == 'unset') {
-            $default_value = addslashes($default_value);
+            $default_value = DB_escapeString($default_value);
             $sql .= "SET value = '{$default_value}', default_value = 'unset:{$default_value}'";
         } else {
             $sql .= "SET value = default_value";
@@ -431,13 +438,13 @@ class config {
             return false;
         }
 
-        $escaped_name = addslashes($name);
-        $escaped_grp = addslashes($group);
+        $escaped_name = DB_escapeString($name);
+        $escaped_grp = DB_escapeString($group);
         $default_value = DB_getItem($_TABLES['conf_values'], 'default_value',
                 "name = '{$escaped_name}' AND group_name = '{$escaped_grp}'");
         $sql = "UPDATE {$_TABLES['conf_values']} SET value = 'unset'";
         if (substr($default_value, 0, 6) == 'unset:') {
-            $default_value = addslashes(substr($default_value, 6));
+            $default_value = DB_escapeString(substr($default_value, 6));
             $sql .= ", default_value = '{$default_value}'";
         }
         $sql .= " WHERE name = '{$escaped_name}' AND group_name = '{$escaped_grp}'";
@@ -502,7 +509,7 @@ class config {
             $columns .= ', tab';
             $Qargs[9] = $tab;
         }
-        $Qargs = array_map('addslashes', $Qargs);
+        $Qargs = array_map('DB_escapeString', $Qargs);
 
         // Now add in config item
         $sql = "INSERT INTO {$_TABLES['conf_values']} ($columns) VALUES ("
@@ -536,7 +543,7 @@ class config {
     {
         DB_delete($GLOBALS['_TABLES']['conf_values'],
                   array('name', 'group_name'),
-                  array(addslashes($param_name), addslashes($group)));
+                  array(DB_escapeString($param_name), DB_escapeString($group)));
         unset($this->config_array[$group][$param_name]);
     }
 
@@ -598,31 +605,31 @@ class config {
 
     /**
      * Changes any config settings that depend on other configuration settings.
-     * Called by config::initConfig and config::set
+     * Called by config::initConfig
+     * 
+     * @return voif
+     */
+    function _post_initconfig()
+    {
+        global $_USER;
+
+        $theme = $this->config_array['Core']['theme'];
+        if ($this->config_array['Core']['allow_user_themes'] == 1 && !empty($_USER['theme'])) {
+            $theme = $_USER['theme'];
+        }
+        $this->config_array['Core']['path_themes'] =  $this->config_array['Core']['path_html'] . 'layout/'; // Cannot be set by admin anymore
+        $this->config_array['Core']['path_layout'] = $this->config_array['Core']['path_themes'] . $theme . '/';
+        $this->config_array['Core']['layout_url'] = $this->config_array['Core']['site_url'] . '/layout/' . $theme;
+    }
+
+    /**
+     * Changes any config settings that depend on other configuration settings.
+     * Called by config::initConfig and config::updateConfig
      * 
      * @return voif
      */
     function _post_configuration()
     {
-        global $_USER;
-
-        if (empty($_USER['theme'])) {
-            if (! empty($this->config_array['Core']['theme'])) {
-                $theme = $this->config_array['Core']['theme'];
-            }
-        } else {
-            $theme = $_USER['theme'];
-        }
-
-        if (! empty($theme)) {
-            if (! empty($this->config_array['Core']['path_themes'])) {
-                $this->config_array['Core']['path_layout'] = $this->config_array['Core']['path_themes'] . $theme . '/';
-            }
-            if (! empty($this->config_array['Core']['site_url'])) {
-                $this->config_array['Core']['layout_url'] = $this->config_array['Core']['site_url'] . '/layout/' . $theme;
-            }
-        }
-
         $methods = array('standard', 'openid', '3rdparty', 'oauth');
         $methods_disabled = 0;
         foreach ($methods as $m) {
@@ -793,7 +800,15 @@ class config {
         $js .= $this->_UI_js_image_spinner();        
         $js .= "var frmGroupAction = '" . $_CONF['site_admin_url'] . "/configuration.php';";
         $_SCRIPTS->setJavaScript($js, true);
-        $_SCRIPTS->setJavaScriptFile('admin.configuration', '/javascript/admin.configuration.js');
+
+        $this->flag_version_2 = version_compare($_CONF['supported_version_theme'], '2.0.0', '>=');
+
+        if ($this->flag_version_2 == true) {
+            $_SCRIPTS->setJavaScriptFile('admin.configuration', '/javascript/admin.configuration.js');
+        } else {
+            $_SCRIPTS->setJavaScriptFile('admin.configuration', '/javascript/ver.1.8/admin.configuration.js');
+        }
+
         
         $t->set_var('search_configuration_label', $LANG_CONFIG['search_configuration_label']);
         if (isset($_POST['search-configuration-cached'])) {
@@ -874,28 +889,56 @@ class config {
                 if ($e['type'] == 'fieldset' AND $e['fieldset'] != $current_fs) {
                     $fs_flag = true;
                     if ($current_fs != '') {
-                        $tab_contents .= '</table></fieldset><!-- END fieldset -->';
+
+                        if ($this->flag_version_2 == true) {
+                            $tab_contents .= '</div></fieldset><!-- END fieldset -->';
+                        } else {
+                            $tab_contents .= '</table></fieldset><!-- END fieldset -->';
+                        }
+
                         $table_flag = false;
                     }
-                    // $tab_contents .= '<!-- BEGIN fieldset --><fieldset style="margin-top:10px;"><legend>{fs_display}</legend>';
-                    $tab_contents .= '<!-- BEGIN fieldset --><fieldset style="margin-top:10px;"><legend>' . $LANG_fs[$grp][$e['display_name']] . '</legend>';
+                    $tab_contents .= '<!-- BEGIN fieldset --><fieldset><legend>' . $LANG_fs[$grp][$e['display_name']] . '</legend>';
                     $current_fs = $e['fieldset'];
                 }
                 if (!$table_flag) {
-                    $tab_contents .= '<table class="inputTable">';
+
+                    if ($this->flag_version_2 == true) {
+                        $tab_contents .= '<div class="inputTable">';
+                    } else {
+                        $tab_contents .= '<table class="inputTable">';
+                    }
+
                     $table_flag = true;
                 }
-                $tab_contents .=
-                    $this->_UI_get_conf_element($grp, $name,
-                                               $e['display_name'],
-                                               $e['type'],
-                                               $e['value'],
-                                               $e['selectionArray'], false,
-                                               $e['reset']);
+
+                if ($this->flag_version_2 == true) {
+                    $tab_contents .=
+                        $this->_UI_get_conf_element_2($grp, $name,
+                                                   $e['display_name'],
+                                                   $e['type'],
+                                                   $e['value'],
+                                                   $e['selectionArray'], false,
+                                                   $e['reset']);
+                } else {
+                    $tab_contents .=
+                        $this->_UI_get_conf_element($grp, $name,
+                                                   $e['display_name'],
+                                                   $e['type'],
+                                                   $e['value'],
+                                                   $e['selectionArray'], false,
+                                                   $e['reset']);
+                }
             }
+
             if ($table_flag) {
-                $tab_contents .= '</table>';
+                if ($this->flag_version_2 == true) {
+                    $tab_contents .= '</div>';
+                } else {
+                    $tab_contents .= '</table>';
+                }
             }
+
             if ($fs_flag) {
                 $tab_contents .= '</fieldset><!-- END fieldset -->';
             }
@@ -915,9 +958,9 @@ class config {
         $t->set_var('tab_li', $tab_li);
         
         $_SCRIPTS->setJavaScriptLibrary('jquery.ui.autocomplete');
+        $_SCRIPTS->setJavaScriptLibrary('jquery.ui.menu');	// Required by 'jquery.ui.autocomplete'
         $_SCRIPTS->setJavaScriptLibrary('jquery.ui.tabs');
         
-        $display  = COM_siteHeader('none', $LANG_CONFIG['title']);
         $t->set_var('config_menu',$this->_UI_configmanager_menu($grp,$sg));
         
         // message box
@@ -935,8 +978,8 @@ class config {
             $t->set_var('error_validation_class', ' error_validation');
         }
         
-        $display .= $t->finish($t->parse("OUTPUT", "main"));
-        $display .= COM_siteFooter(false);
+        $display = $t->finish($t->parse("OUTPUT", "main"));
+        $display = COM_createHTMLDocument($display, array('what' => 'none', 'pagetitle' => $LANG_CONFIG['title'], 'rightblock' => false));
 
         return $display;
     }
@@ -1073,9 +1116,8 @@ class config {
     {
         global $_USER, $MESSAGE;
 
-        $display = COM_siteHeader('menu', $MESSAGE[30])
-                 . COM_showMessageText($MESSAGE[29], $MESSAGE[30])
-                 . COM_siteFooter();
+        $display = COM_showMessageText($MESSAGE[29], $MESSAGE[30]);
+        $display = COM_createHTMLDocument($display, array('pagetitle' => $MESSAGE[30]));
         COM_accessLog("User {$_USER['username']} tried to illegally access the config administration screen.");
 
         return $display;
@@ -1094,7 +1136,7 @@ class config {
      * @param  mixed  $selectionArray Array of option of select element
      * @param  bool   $deleteable If configuration is deleteable
      * @param  bool   $allow_reset Allow set and unset of configuration
-     * @return
+     * @return string
      */
     function _UI_get_conf_element($group, $name, $display_name, $type, $val,
                                   $selectionArray = null , $deletable = false,
@@ -1261,6 +1303,202 @@ class config {
         }
     }
 
+    /**
+     * Get a parsed config element based on group $group, name $name,
+     * type $type, value to be shown $val and label $display_name to be shown  
+     * on the left based on language.
+     * 
+     * @param  string $group Configuration group.
+     * @param  string $name Configuration name on table.
+     * @param  string $display_name Configuration display name based on language.
+     * @param  string $type Configuration type such as select, text, textarea, @select, etc.
+     * @param  string $val Value of configuration
+     * @param  mixed  $selectionArray Array of option of select element
+     * @param  bool   $deleteable If configuration is deleteable
+     * @param  bool   $allow_reset Allow set and unset of configuration
+     * @return string
+     */
+    function _UI_get_conf_element_2($group, $name, $display_name, $type, $val,
+                                  $selectionArray = null , $deletable = false,
+                                  $allow_reset = false)
+    {
+        global $_CONF, $LANG_CONFIG;
+
+        $t = COM_newTemplate($GLOBALS['_CONF']['path_layout'] . 'admin/config');
+        $t -> set_file('element', 'config_element_2.thtml');
+
+        $blocks = array('delete-button', 'text-element', 'placeholder-element',
+                        'select-element', 'list-element', 'unset-param',
+                        'keyed-add-button', 'unkeyed-add-button', 'text-area',
+                        'validation_error_block');
+        foreach ($blocks as $block) {
+            $t->set_block('element', $block);
+        }
+
+        $t->set_var('lang_restore', $LANG_CONFIG['restore']);
+        $t->set_var('lang_enable', $LANG_CONFIG['enable']);
+        $t->set_var('lang_add_element', $LANG_CONFIG['add_element']);
+
+        $t->set_var('name', $name);
+        $t->set_var('id_name', str_replace(array('[', ']'), array('_', ''), $name));
+        $t->set_var('display_name', $display_name);
+        
+        // check tmp values
+        if ( isset($this->tmpValues[$group][$name]) ) {
+            $val = $this->tmpValues[$group][$name];
+        }
+        
+        if (!is_array($val)) {
+            if (is_float($val)) {
+                /**
+                * @todo FIXME: for Locales where the comma is the decimal
+                *              separator, patch output to a decimal point
+                *              to prevent it being cut off by COM_applyFilter
+                */
+                $t->set_var('value', str_replace(',', '.', $val));
+            } else {
+                $t->set_var('value', htmlspecialchars($val));
+            }
+        }
+        
+        // if there is a error message to shown
+        if ( isset($this->validationErrors[$group][$name]) ) {
+            $t->set_var('validation_error_message', $this->validationErrors[$group][$name]);
+            $t->set_var('error_block', $t->parse('output', 'validation_error_block'));
+            $t->set_var('error_class', ' input_error');
+            $t->set_var('value', $this->validationErrorValues[$group][$name]);
+        } else {
+            $t->set_var('error_class', '');
+            $t->set_var('error_block', '');
+        }
+        
+        if ($deletable) {
+            $t->set_var('delete', $t->parse('output', 'delete-button'));
+        } else {
+            if ($allow_reset) {
+                $t->set_var('unset_link',
+                        "(<a href=\"#{$name}\" class=\"unset_param\" title='"
+                        . $LANG_CONFIG['disable'] . "'>X</a>)");
+            }
+            if (($a = strrchr($name, '[')) !== FALSE) {
+                $on = substr($a, 1, -1);
+                $o = str_replace(array('[', ']'), array('_', ''), $name);
+            } else {
+                $o = $name;
+                $on = $name;
+            }
+            if (! is_numeric($on)) {
+                $this->_set_ConfigHelp($t, $group, $o);
+            }
+        }
+        // if $name is like "blah[0]", separate name and index
+        $n = explode('[', $name);
+        $index = null;
+        $nc = count($n);
+        if ($nc > 1) {
+            $i = explode(']', $n[$nc-1]);
+            $index = $i[0];
+        }
+        if (!empty($index) && ($index == 'placeholder' || $display_name == 'skeleton')) {
+            $t->set_var('hide_row', ' style="display:none;"');
+        }
+
+        $prefix = substr($type, 0, 1);
+        if ($type == "unset") {
+            return $t->finish($t->parse('output', 'unset-param'));
+        } elseif ($type == "text") {
+            return $t->finish($t->parse('output', 'text-element'));
+        } elseif ($type == "textarea") {
+            return $t->finish($t->parse('output', 'text-area'));
+        } elseif ($type == "placeholder") {
+            return $t->finish($t->parse('output', 'placeholder-element'));
+        } elseif ($type == 'select') {
+
+            // if $name is like "blah[0]", separate name and index
+            $n = explode('[', $name);
+            $name = $n[0];
+            $type_name = $type . '_' . $name;
+            if ($group == 'Core') {
+                $fn = 'configmanager_' . $type_name . '_helper';
+            } else {
+                $fn = 'plugin_configmanager_' . $type_name . '_' . $group;
+            }
+            if (function_exists($fn)) {
+                if ($index === null) {
+                    $selectionArray = $fn();
+                } else {
+                    $selectionArray = $fn($index);
+                }
+            } else if (is_array($selectionArray)) {
+                // leave sorting to the function otherwise
+                uksort($selectionArray, 'strcasecmp');
+            }
+            if (! is_array($selectionArray)) {
+                return $t->finish($t->parse('output', 'text-element'));
+            }
+
+            $t->set_block('select-element', 'select-options', 'myoptions');
+            foreach ($selectionArray as $sName => $sVal) {
+                if (is_bool($sVal)) {
+                    $t->set_var('opt_value', $sVal ? 'b:1' : 'b:0');
+                } else {
+                    $t->set_var('opt_value', $sVal);
+                }
+                $t->set_var('opt_name', $sName);
+                $t->set_var('selected', ($val == $sVal ? 'selected="selected"' : ''));
+                $t->parse('myoptions', 'select-options', true);
+            }
+            return $t->parse('output', 'select-element');
+        } elseif ($prefix == '@') {
+            $result = '';
+            foreach ($val as $valkey => $valval) {
+                $result .= config::_UI_get_conf_element_2($group,
+                                $name . '[' . $valkey . ']',
+                                $display_name . '[' . $valkey . ']',
+                                substr($type, 1), $valval, $selectionArray,
+                                false);
+            }
+            return $result;
+        } elseif ($prefix == '*' || $prefix == '%') {
+            $t->set_var('arr_name', $name);
+            $t->set_var('array_type', $type);
+            $button = $t->parse('output', ($prefix == '*' ?
+                                           'keyed-add-button' :
+                                           'unkeyed-add-button'));
+            $t->set_var('my_add_element_button', $button);
+            $result = "";
+
+            $base_type = str_replace(array('*', '%'), '', $type);
+            if (in_array($base_type, array('select', 'text', 'placeholder'))) {
+                $result .= config::_UI_get_conf_element_2($group,
+                                $name . '[placeholder]', 'skeleton',
+                                substr($type, 1), 'placeholder', $selectionArray,
+                                true);
+            }
+
+            if ($display_name == 'skeleton') {
+                $val = array();
+            }
+            if (!is_array($val)) {
+                $val = array();
+            }
+
+            foreach ($val as $valkey => $valval) {
+                $result .= config::_UI_get_conf_element_2($group,
+                                $name . '[' . $valkey . ']', $valkey,
+                                substr($type, 1), $valval, $selectionArray,
+                                true);
+            }
+            $t->set_var('my_elements', $result);
+            // if the values are indexed numerically, add a class to the div
+            // for identification. The UI code can take advantage of it
+            $t->set_var('arr_class_list', ($prefix == '%' ?
+                                           'numerical_config_list' :
+                                           'named_config_list'));
+            return $t->parse('output', 'list-element');
+        }
+    }
+
     /**
      * This function takes $_POST input and evaluates it
      *
@@ -1288,12 +1526,20 @@ class config {
             $this->config_array['Core']['language'] = unserialize($value);
 
             /**
-             * Same with $_CONF['cookiedomain'], which is overwritten in
+             * Same with $_CONF['cookiedomain'], which is overwritten
              * in lib-sessions.php (if empty).
              */
             $value = DB_getItem($_TABLES['conf_values'], 'value',
                                 "group_name='Core' AND name='cookiedomain'");
             $this->config_array['Core']['cookiedomain'] = unserialize($value);
+
+            /**
+             * Same with $_CONF['doctype'], which is overwritten
+             * with the theme's configuration in lib-common.php.
+             */
+            $value = DB_getItem($_TABLES['conf_values'], 'value',
+                                "group_name='Core' AND name='doctype'");
+            $this->config_array['Core']['doctype'] = unserialize($value);
         }
         
         $this->_extract_permissible_conf($change_array, $group, $change_array['sub_group']);
@@ -1322,18 +1568,21 @@ class config {
                 } else if ( is_array($change_array[$param_name]) ) {
                     /* if array such as mail settings */
                     $_changed = false;
-                    foreach ( $change_array[$param_name] as $_param_name => $_param_value ) {
-                        if  ( $change_array[$param_name][$_param_name] != 
-                              $this->config_array[$group][$param_name][$_param_name] )
-                        {
-                            $_changed = true;
-                            if ( $this->_validates($param_name . '[' . $_param_name . ']', 
-                                 $group, $change_array[$param_name][$_param_name], $change_array[$param_name]) )
-                            {
-                                $this->changedArray[$group][$param_name][$_param_name] = true;
-                            }
-                        }
+                    if (count($this->config_array[$group][$param_name]) !=  count($change_array[$param_name])) {
+                        $_changed = true;
                     }
+                    foreach ( $change_array[$param_name] as $_param_name => $_param_value ) {
+                         if (!isset($this->config_array[$group][$param_name][$_param_name])) {
+                             $_changed = true;
+                         } elseif ( $change_array[$param_name][$_param_name] != $this->config_array[$group][$param_name][$_param_name] ) {
+                             $_changed = true;
+                         }
+                         if ($_changed) {
+                             if ( $this->_validates($param_name . '[' . $_param_name . ']', $group, $change_array[$param_name][$_param_name], $change_array[$param_name]) ) {
+                                 $this->changedArray[$group][$param_name][$_param_name] = true;
+                             }
+                         }
+                     }
                     
                     if ( $_changed ) {
                         $pass_validation[$param_name] = $change_array[$param_name];
@@ -1352,9 +1601,47 @@ class config {
         if ( empty($this->validationErrors) ) {
             // only set if there is no validation error
             foreach ( $pass_validation as $param => $val ) {
+                if ($group === 'Core') {
+                    switch ($param) {
+                        case 'site_name':
+                        case 'site_slogan':
+                        case 'owner_name':
+                        case 'meta_description':
+                        case 'meta_keywords':
+                        case 'rdf_language':
+                        case 'locale':
+                        case 'date':
+                        case 'daytime':
+                        case 'shortdate':
+                        case 'dateonly':
+                        case 'timeonly':
+                        case 'cookie_session':
+                        case 'cookie_name':
+                        case 'cookie_password':
+                        case 'cookie_theme':
+                        case 'cookie_language':
+                        case 'cookie_tzid':
+                        case 'cookie_anon_name':
+                            $val = strip_tags($val);
+                            break;
+
+                        case 'site_disabled_msg':
+                        case 'comment_feeds_article_tag':
+                        case 'comment_feeds_article_author_tag':
+                        case 'comment_feeds_comment_author_tag':
+                        case 'search_separator':
+                            $val = COM_checkHTML($val);
+                            break;
+
+                        default:
+                            break;
+                    }
+                }
+
                 $this->set($param, $val, $group);
                 $success_array[$param] = true;
             }
+            $this->_post_configuration();
         } else {
             // temporaly save the changed values
             foreach ( $pass_validation as $param => $val ) {
@@ -1402,7 +1689,7 @@ class config {
             $is_num = true;
             $max_key = -1;
             foreach ($input_val as $key => $val) {
-                if ($key !== 'placeholder') {
+                if ($key !== 'placeholder' && $key !== 'nameholder') {
                     $r[$key] = $this->_validate_input($config, $group, $val);
                     if (is_numeric($key)) {
                         if ($key > $max_key) {
@@ -1588,12 +1875,19 @@ class config {
                     $group_display = $LANG_configsections[$group]['label'];
                 }
                 // Create a menu item for each config group - disable the link for the current selected one
-                if ($conf_group == $group) {
-                    $link = "<div>$group_display</div>";
+                if ($this->flag_version_2 == true) {
+                    if ($conf_group == $group) {
+                        $link = "<li class=\"configoption_off\">$group_display</li>";
+                    } else {
+                        $link = "<li class=\"configoption\"><a href=\"#\" onclick='open_group(\"$group\");return false;'>$group_display</a></li>";
+                    }
                 } else {
-                    $link = "<div><a href=\"#\" onclick='open_group(\"$group\");return false;'>$group_display</a></div>";
+                    if ($conf_group == $group) {
+                        $link = "<div>$group_display</div>";
+                    } else {
+                        $link = "<div><a href=\"#\" onclick='open_group(\"$group\");return false;'>$group_display</a></div>";
+                    }
                 }
-
                 if ($group == 'Core') {
                     $retval .= $link;
                 } else {
@@ -1607,8 +1901,13 @@ class config {
             $retval .= $link;
         }
 
-        $retval .= '<div><a href="' . $_CONF['site_admin_url'] . '">'
-                . $LANG_ADMIN['admin_home'] . '</a></div>';
+        if ($this->flag_version_2 == true) {
+            $retval .= '<li class="configoption"><a href="' . $_CONF['site_admin_url'] . '">'
+                    . $LANG_ADMIN['admin_home'] . '</a></li>';
+        } else {
+            $retval .= '<div><a href="' . $_CONF['site_admin_url'] . '">'
+                    . $LANG_ADMIN['admin_home'] . '</a></div>';
+        }
         $retval .= COM_endBlock(COM_getBlockTemplate('configmanager_block',
                                                      'footer'));
 
@@ -1634,10 +1933,18 @@ class config {
                     $group_display = $sgname;
                 }
                 // Create a menu item for each sub config group - disable the link for the current selected one
-                if ($sgroup == $sg) {
-                    $retval .= "<div>$group_display</div>";
+                if ($this->flag_version_2 == true) {
+                    if ($sgroup == $sg) {
+                        $retval .= "<li class=\"configoption_off\">$group_display</li>";
+                    } else {
+                        $retval .= "<li class=\"configoption\"><a href=\"#\" onclick='open_subgroup(\"$conf_group\",\"$sgroup\");return false;'>$group_display</a></li>";
+                    }
                 } else {
-                    $retval .= "<div><a href=\"#\" onclick='open_subgroup(\"$conf_group\",\"$sgroup\");return false;'>$group_display</a></div>";
+                    if ($sgroup == $sg) {
+                        $retval .= "<div>$group_display</div>";
+                    } else {
+                        $retval .= "<div><a href=\"#\" onclick='open_subgroup(\"$conf_group\",\"$sgroup\");return false;'>$group_display</a></div>";
+                    }
                 }
                 $i++;
             }
@@ -1744,7 +2051,7 @@ class config {
     {
         global $_DB, $_DB_dbms;
 
-        if ($_DB_dbms == 'mssql') {
+        if (($_DB_dbms == 'mssql') || ($_DB_dbms == 'pgsql')) {
             $sql = str_replace("\\'", "''", $sql);
             $sql = str_replace('\\"', '"', $sql);
             $_DB->dbQuery($sql, 0, 1);
@@ -1763,6 +2070,7 @@ class config {
     */
     function _set_ConfigHelp(&$t, $group, $option)
     {
+        global $_SCRIPTS;
         static $docUrl;
 
         if (!isset($docUrl)) {
@@ -1775,22 +2083,27 @@ class config {
         if (empty($configtext)) {
             if ($group == 'Core') {
                 $configtext = NULL;
-                if (!empty($GLOBALS['_CONF']['site_url']) &&
-                        !empty($GLOBALS['_CONF']['path_html'])) {
-                    $baseUrl = $GLOBALS['_CONF']['site_url'];
-                    $doclang = COM_getLanguageName();
-                    $cfg = 'docs/' . $doclang . '/config.html';
-                    if (file_exists($GLOBALS['_CONF']['path_html'] . $cfg)) {
-                        $url = $baseUrl . '/' . $cfg;
+            }
+            if (empty($docUrl[$group])) {
+                if ($group == 'Core') {
+                    if (!empty($GLOBALS['_CONF']['site_url']) &&
+                            !empty($GLOBALS['_CONF']['path_html'])) {
+                        $baseUrl = $GLOBALS['_CONF']['site_url'];
+                        $doclang = COM_getLanguageName();
+                        $cfg = 'docs/' . $doclang . '/config.html';
+                        if (file_exists($GLOBALS['_CONF']['path_html'] . $cfg)) {
+                            $url = $baseUrl . '/' . $cfg;
+                        } else {
+                            $url = $baseUrl . '/docs/english/config.html';
+                        }
                     } else {
-                        $url = $baseUrl . '/docs/english/config.html';
+                        $url = 'http://www.geeklog.net/docs/english/config.html';
                     }
-                } else {
-                    $url = 'http://www.geeklog.net/docs/english/config.html';
+                    $docUrl['Core'] = $url;
+                } else { // plugin            
+                    $docUrl[$group] = PLG_getDocumentationUrl($group, 'config');
                 }
-                $docUrl['Core'] = $url;
-            } else { // plugin            
-                $docUrl[$group] = PLG_getDocumentationUrl($group, 'config');
+                $_SCRIPTS->setJavaScript('var glConfigDocUrl = "' . $docUrl[$group] . '";', true);
             }
             $descUrl = $docUrl[$group];
 
@@ -1801,13 +2114,24 @@ class config {
                 
                 $t->set_var('doc_url', $descUrl);
                 
-                // Does hack need to be used?
-                if (gettype($configtext) == "NULL") {
-                    $t->set_var('doc_link',
-                            '(<a href="' . $descUrl . '" target="help" class="tooltip">?</a>)');                    
+                if ($this->flag_version_2 == true) {
+                    // Does hack need to be used?
+                    if (gettype($configtext) == "NULL") {
+                        $t->set_var('doc_link',
+                                '(<a href="javascript:void(0);" id="desc_' . $option . '" class="tooltip">?</a>)');
+                    } else {
+                        $t->set_var('doc_link',
+                                '(<a href="javascript:void(0);" id="desc_' . $option . '">?</a>)');
+                    }
                 } else {
-                    $t->set_var('doc_link',
-                            '(<a href="' . $descUrl . '" target="help">?</a>)');
+                    // Does hack need to be used?
+                    if (gettype($configtext) == "NULL") {
+                        $t->set_var('doc_link',
+                                '(<a href="' . $descUrl . '" target="help" class="tooltip">?</a>)');
+                    } else {
+                        $t->set_var('doc_link',
+                                '(<a href="' . $descUrl . '" target="help">?</a>)');
+                    }
                 }
             }              
         } else {
