@@ -2,16 +2,16 @@
 
 /* Reminder: always indent with 4 spaces (no tabs). */
 // +---------------------------------------------------------------------------+
-// | Geeklog 1.4                                                               |
+// | Geeklog 1.6                                                               |
 // +---------------------------------------------------------------------------+
 // | upload.class.php                                                          |
 // |                                                                           |
 // | Geeklog file upload class library.                                        |
 // +---------------------------------------------------------------------------+
-// | Copyright (C) 2002-2006 by the following authors:                         |
+// | Copyright (C) 2002-2009 by the following authors:                         |
 // |                                                                           |
-// | Authors: Tony Bibbs       - tony@tonybibbs.com                            |
-// |          Dirk Haun        - dirk@haun-online.de                           |
+// | Authors: Tony Bibbs       - tony AT tonybibbs DOT com                     |
+// |          Dirk Haun        - dirk AT haun-online DOT de                    |
 // +---------------------------------------------------------------------------+
 // |                                                                           |
 // | This program is free software; you can redistribute it and/or             |
@@ -29,15 +29,13 @@
 // | Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.           |
 // |                                                                           |
 // +---------------------------------------------------------------------------+
-//
-// $Id: upload.class.php,v 1.50 2007/11/25 06:59:56 ospiess Exp $
 
 /**
 * This class will allow you to securely upload one or more files from a form
 * submitted via POST method.  Please read documentation as there are a number of
 * security related features that will come in handy for you.
 *
-* @author       Tony Bibbs <tony@tonybibbs.com>
+* @author       Tony Bibbs, tony AT tonybibbs DOT com
 *
 */
 class upload
@@ -93,6 +91,10 @@ class upload
     /**
     * @access private
     */
+    var $_jpegQuality = 0;                // int (0-100)
+    /**
+    * @access private
+    */
     var $_pathToMogrify = '';             // String
     /**
     * @access private
@@ -154,6 +156,10 @@ class upload
     * @access private
     */
     var $_imageIndex = 0;                 // Integer
+    /**
+    * @access private
+    */
+    var $_ignoreMimeTest = false;       // Boolean
 
     /**
     * @access private
@@ -255,27 +261,28 @@ class upload
     */
     function _setAvailableMimeTypes($mimeTypes = array())
     {
-        if (sizeof($mimeTypes) == 0) {
+        if (count($mimeTypes) == 0) {
             $this->_availableMimeTypes =
             array(
                 'application/x-gzip-compressed'     => '.tar.gz,.tgz',
-                'application/x-zip-compressed'         => '.zip',
-                'application/x-tar'                    => '.tar',
+                'application/x-zip-compressed'      => '.zip',
+                'application/x-tar'                 => '.tar',
+                'application/x-gtar'                => '.tar',
                 'text/plain'                        => '.phps,.txt,.inc',
-                'text/html'                            => '.html,.htm',
+                'text/html'                         => '.html,.htm',
                 'image/bmp'                         => '.bmp,.ico',
                 'image/gif'                         => '.gif',
-                'image/pjpeg'                        => '.jpg,.jpeg',
+                'image/pjpeg'                       => '.jpg,.jpeg',
                 'image/jpeg'                        => '.jpg,.jpeg',
-                'image/png'                            => '.png',
-                'image/x-png'                        => '.png',
+                'image/png'                         => '.png',
+                'image/x-png'                       => '.png',
                 'audio/mpeg'                        => '.mp3',
-                'audio/wav'                            => '.wav',
-                'application/pdf'                    => '.pdf',
+                'audio/wav'                         => '.wav',
+                'application/pdf'                   => '.pdf',
                 'application/x-shockwave-flash'     => '.swf',
                 'application/msword'                => '.doc',
-                'application/vnd.ms-excel'            => '.xls',
-                'application/octet-stream'            => '.fla,.psd'
+                'application/vnd.ms-excel'          => '.xls',
+                'application/octet-stream'          => '.fla,.psd'
             );
         } else {
             $this->_availableMimeTypes = $mimeTypes;
@@ -428,7 +435,7 @@ class upload
     *
     * @access   private
     * @param    string  $filename   name of uploaded file
-    * @return   bool                true: okay, false: an error occured
+    * @return   boolean             true: okay, false: an error occured
     *
     */
     function _keepOriginalFile ($filename)
@@ -519,7 +526,21 @@ class upload
                 $sizeOK = false;
             }
         }
-        $returnMove = move_uploaded_file($this->_currentFile['tmp_name'], $this->_fileUploadDirectory . '/' . $this->_getDestinationName());
+
+        if (isset($this->_currentFile['non_upload']) && $this->_currentFile['non_upload'] == true) {
+            // Not from the upload file dialogue so just move
+            $returnMove = rename($this->_currentFile['tmp_name'], $this->_fileUploadDirectory . '/' . $this->_getDestinationName());
+        } else {
+            if (isset($this->_currentFile['_gl_data_dir']) &&
+                    $this->_currentFile['_gl_data_dir']) {
+                // uploaded file was involved in a recreated POST after an expired
+                // token - can't use move_uploaded_file() here
+                $returnMove = rename($this->_currentFile['tmp_name'], $this->_fileUploadDirectory . '/' . $this->_getDestinationName());
+            } else {
+                $returnMove = move_uploaded_file($this->_currentFile['tmp_name'], $this->_fileUploadDirectory . '/' . $this->_getDestinationName());
+            }
+        }
+
         if (!($sizeOK)) {
             // OK, resize
             $sizefactor = $this->_calcSizefactor ($imageInfo['width'],
@@ -530,8 +551,13 @@ class upload
                                  . $newheight . ' using ' . $this->_imageLib);
 
             if ($this->_imageLib == 'imagemagick') {
+
                 $newsize = $newwidth . 'x' . $newheight;
-                $cmd = $this->_pathToMogrify . ' -resize '. $newsize . ' "' . $this->_fileUploadDirectory . '/' . $this->_getDestinationName() . '" 2>&1';
+                $quality = '';
+                if ($this->_jpegQuality > 0) {
+                    $quality = sprintf(' -quality %d', $this->_jpegQuality);
+                }
+                $cmd = $this->_pathToMogrify . $quality . ' -resize '. $newsize . ' "' . $this->_fileUploadDirectory . '/' . $this->_getDestinationName() . '" 2>&1';
                 $this->_addDebugMsg('Attempting to resize with this command (imagemagick): ' . $cmd);
 
                 $filename = $this->_fileUploadDirectory . '/'
@@ -548,13 +574,19 @@ class upload
                 $filename = $this->_fileUploadDirectory . '/' . $this->_getDestinationName();
                 $cmd_end = " '" . $filename . "' | " . $this->_pathToNetPBM . 'pnmscale -xsize=' . $newwidth . ' -ysize=' . $newheight . ' | ' . $this->_pathToNetPBM;
                 // convert to pnm, resize, convert back
-                if (eregi ('\.png', $filename)) {
+                if (($this->_currentFile['type'] == 'image/png') ||
+                    ($this->_currentFile['type'] == 'image/x-png')) {
                     $tmpfile = $this->_fileUploadDirectory . '/tmp.png';
                     $cmd .= 'pngtopnm ' . $cmd_end . 'pnmtopng > ' . $tmpfile;
-                } else if (eregi ('\.(jpg|jpeg)', $filename)) {
+                } elseif (($this->_currentFile['type'] == 'image/jpeg') ||
+                          ($this->_currentFile['type'] == 'image/pjpeg')) {
                     $tmpfile = $this->_fileUploadDirectory . '/tmp.jpg';
-                    $cmd .= 'jpegtopnm ' . $cmd_end . 'pnmtojpeg > ' . $tmpfile;
-                }  else if (eregi ('\.gif', $filename)) {
+                    $quality = '';
+                    if ($this->_jpegQuality > 0) {
+                        $quality = sprintf(' -quality=%d', $this->_jpegQuality);
+                    }
+                    $cmd .= 'jpegtopnm ' . $cmd_end . 'pnmtojpeg' . $quality . ' > ' . $tmpfile;
+                } elseif ($this->_currentFile['type'] == 'image/gif') {
                     $tmpfile = $this->_fileUploadDirectory . '/tmp.gif';
                     $cmd .= 'giftopnm ' . $cmd_end . 'ppmquant 256 | '
                          . $this->_pathToNetPBM . 'ppmtogif > ' . $tmpfile;
@@ -593,6 +625,12 @@ class upload
                     exit;
                 }
 
+                if (!function_exists('gd_info')) {
+                    $this->_addError('GD library does not seem to be enabled.');
+                    $this->printErrors();
+                    exit;
+                }
+
                 if (($this->_currentFile['type'] == 'image/png') OR
                     ($this->_currentFile['type'] == 'image/x-png')) {
                     if (!function_exists ('imagecreatefrompng')) {
@@ -653,15 +691,19 @@ class upload
                 $image_dest = @ImageCreateTrueColor($newwidth, $newheight);
                 if (!$image_dest) {
                     $thumb = imagecreate ($newwidth, $newheight);
-                    imageJPEG ($thumb, $filename);
+                    if ($this->_jpegQuality > 0) {
+                        imagejpeg($thumb, $filename, $this->_jpegQuality);
+                    } else {
+                        imagejpeg($thumb, $filename);
+                    }
                     imagedestroy ($thumb);
                     $image_dest = @imagecreatefromjpeg ($filename);
                     unlink ($filename);
                 }
 
-                imagecopyresized ($image_dest, $image_source, 0, 0, 0, 0,
-                                  $newwidth, $newheight, $imageInfo['width'],
-                                  $imageInfo['height']);
+                imagecopyresampled($image_dest, $image_source, 0, 0, 0, 0,
+                                   $newwidth, $newheight, $imageInfo['width'],
+                                   $imageInfo['height']);
                 if (($this->_currentFile['type'] == 'image/png') OR
                     ($this->_currentFile['type'] == 'image/x-png')) {
                     if (!imagepng ($image_dest, $filename)) {
@@ -671,7 +713,13 @@ class upload
                     }
                 } elseif (($this->_currentFile['type'] == 'image/jpeg') OR
                           ($this->_currentFile['type'] == 'image/pjpeg')) {
-                    if (!imagejpeg ($image_dest, $filename)) {
+                    if ($this->_jpegQuality > 0) {
+                        $jpsuccess = imagejpeg($image_dest, $filename,
+                                               $this->_jpegQuality);
+                    } else {
+                        $jpsuccess = imagejpeg($image_dest, $filename);
+                    }
+                    if (!$jpsuccess) {
                         $this->_addError ('Could not create JPEG: '. $filename);
                         $this->printErrors ();
                         exit;
@@ -683,6 +731,7 @@ class upload
                         exit;
                     }
                 }
+
             }
 
             if ($retval > 0) {
@@ -721,7 +770,7 @@ class upload
     }
 
     /**
-    * Sets the path to where the mogrify ImageMagic function is
+    * Sets the path to where the mogrify ImageMagick function is
     *
     * @param     string    $path_to_mogrify    Absolute path to mogrify
     * @return    boolean   True if set, false otherwise
@@ -798,7 +847,7 @@ class upload
     */
     function setMaxDimensions($width_pixels, $height_pixels)
     {
-        if (!is_numeric($width_pixels) AND !is_numeric($height_pixels)) {
+        if (!is_numeric($width_pixels) OR !is_numeric($height_pixels)) {
             return false;
         }
 
@@ -835,6 +884,27 @@ class upload
         return true;
     }
 
+    /**
+    * Set JPEG quality
+    *
+    * NOTE:     The 'quality' is an arbitrary value used by the IJG library.
+    *           It is not a percent value! The default (and a good value) is 75.
+    *
+    * @param    int       $quality  JPEG quality (0-100)
+    * @return   boolean   true if we set values OK, otherwise false
+    *
+    */
+    function setJpegQuality($quality)
+    {
+        if (($quality < 0) || ($quality > 100)) {
+            return false;
+        }
+
+        $this->_jpegQuality = $quality;
+
+        return true;
+    }
+
     /**
     * Extra security option that forces all attempts to upload a file to be done
     * so from a set of VERY specific IP's.  This is only good for those who are
@@ -876,7 +946,7 @@ class upload
     /**
     * Sets log file
     *
-    * @param    string  $fileName   fully qualified path to log files
+    * @param    string  $logFile    fully qualified path to log files
     * @return   boolean returns true if we set the log file, otherwise false
     *
     */
@@ -939,6 +1009,22 @@ class upload
         }
     }
 
+    /**
+    * If enabled will ignore the MIME checks on file uploads
+    *
+    * @param    boolean     $switch     flag, true or false
+    *
+    */
+    function setIgnoreMimeCheck($switch)
+    {
+        if ($switch) {
+            $this->_ignoreMimeTest = true;
+        } else {
+            $this->_ignoreMimeTest = false;
+        }
+    }
+
+
     /**
     * This function will print any errors out.  This is useful in debugging
     *
@@ -981,7 +1067,7 @@ class upload
     }
 
     /**
-    * This function will print any debmug messages out.
+    * This function will print any debug messages out.
     *
     */
     function printDebugMsgs()
@@ -1041,6 +1127,10 @@ class upload
     */
     function checkMimeType()
     {
+        if ($this->_ignoreMimeTest) {
+            return true;
+        }
+
         $sc = strpos ($this->_currentFile['type'], ';');
         if ($sc > 0) {
             $this->_currentFile['type'] = substr ($this->_currentFile['type'], 0, $sc);
@@ -1048,7 +1138,12 @@ class upload
         $mimeTypes = $this->getAllowedMimeTypes ();
         foreach ($mimeTypes as $mimeT => $extList) {
             if ($mimeT == $this->_currentFile['type']) {
-                $extensions = explode (',', $extList);
+                // Each defined Mime Type can have multiple possible extesions - need to test each
+                if (is_array($extList)) {   // Used if allowedMimeTypes is being defined using the Online Config Manager
+                    $extensions = array_keys($extList);
+                } else {
+                    $extensions = explode (',', $extList);
+                }
                 $fileName = $this->_currentFile['name'];
                 foreach ($extensions as $ext) {
                     $ext = trim($ext);
@@ -1204,7 +1299,7 @@ class upload
         }
 
         // Verify allowed mime types exist
-        if (!$this->_allowedMimeTypes) {
+        if (!$this->_ignoreMimeTest AND !$this->_allowedMimeTypes) {
             $this->_addError('No allowed mime types specified, use setAllowedMimeTypes() method');
         }
 
