@@ -2,13 +2,13 @@
 
 /* Reminder: always indent with 4 spaces (no tabs). */
 // +---------------------------------------------------------------------------+
-// | Geeklog 1.6                                                               |
+// | Geeklog 2.0                                                               |
 // +---------------------------------------------------------------------------+
 // | mysql.class.php                                                           |
 // |                                                                           |
 // | mysql database class                                                      |
 // +---------------------------------------------------------------------------+
-// | Copyright (C) 2000-2009 by the following authors:                         |
+// | Copyright (C) 2000-2013 by the following authors:                         |
 // |                                                                           |
 // | Authors: Tony Bibbs, tony AT tonybibbs DOT com                            |
 // +---------------------------------------------------------------------------+
@@ -39,7 +39,7 @@
 class database {
 
     // PRIVATE PROPERTIES
-    
+
     /**
     * @access private
     */
@@ -82,6 +82,10 @@ class database {
     var $_mysql_version = 0;
 
     // PRIVATE METHODS
+    /**
+    * @access private
+    */
+    var $_use_innodb = FALSE;
 
     /**
     * Logs messages
@@ -110,6 +114,8 @@ class database {
     */
     function _connect()
     {
+        global $_TABLES, $use_innodb;
+
         if ($this->isVerbose()) {
             $this->_errorlog("\n*** Inside database->_connect ***");
         }
@@ -137,12 +143,28 @@ class database {
             $this->dbError();
         }
 
-        if ($this->_mysql_version >= 40100) {
-            if (strcasecmp($this->_charset, 'utf-8') == 0) {
+        if ($this->_charset == 'utf-8') {
+            if (($this->_mysql_version >= 50007) &&
+                    function_exists('mysql_set_charset')) {
+                @mysql_set_charset('utf8', $this->_db);
+            } else {
                 @mysql_query ("SET NAMES 'utf8'", $this->_db);
             }
         }
 
+        // Checks if db engine is InnoDB.  During the installation
+        // $_TABLES['vars'] is not yet created, so we use $use_innodb instead.
+        if (isset($use_innodb)) {
+            $this->_use_innodb = (boolean) $use_innodb;
+        } else {
+            $result = $this->dbQuery("SELECT value FROM {$_TABLES['vars']} WHERE (name = 'database_engine')");
+
+            if (($result !== FALSE) AND ($this->dbNumRows($result) == 1)) {
+                $A = $this->dbFetchArray($result, FALSE);
+                $this->_use_innodb = (strcasecmp($A['value'], 'InnoDB') === 0);
+            }
+        }
+
         if ($this->isVerbose()) {
             $this->_errorlog("\n***leaving database->_connect***");
         }
@@ -173,6 +195,7 @@ class database {
         $this->_errorlog_fn = $errorlogfn;
         $this->_charset = strtolower($charset);
         $this->_mysql_version = 0;
+        $this->_use_innodb = FALSE;
 
         $this->_connect();
     }
@@ -253,6 +276,38 @@ class database {
             $this->_errorlog("\n*** sql to execute is $sql ***");
         }
 
+        // Modifies "CREATE TABLE" SQL
+        if (preg_match('/create\s+table\s/i', $sql)) {
+            $p = strrpos($sql, ')');
+
+            if ($p !== FALSE) {
+                $option = substr($sql, $p + 1);
+
+                if (($option !== '') AND ($option !== FALSE)) {
+                    // Replaces engine type
+                    $sql    = substr($sql, 0, $p + 1);
+                    $option = rtrim($option, " \t\n\r\0\x0b;");
+                    $option = str_ireplace('type', 'ENGINE', $option);
+
+                    if ($this->_use_innodb === TRUE) {
+                        $option = str_ireplace('MyISAM', 'InnoDB', $option);
+                    }
+                } else {
+                    // Appends engine type
+                    $option = ' ENGINE='
+                            . (($this->_use_innodb === TRUE) ? 'InnoDB' : 'MyISAM');
+                }
+
+                // Appends default charset if necessary
+                if (($this->_charset === 'utf-8') AND
+                        !preg_match('/DEFAULT\s+(CHARSET|CHARACTER\s+SET)/i', $option)) {
+                    $option .= ' DEFAULT CHARSET=utf8';
+                }
+
+                $sql .= $option;
+            }
+        }
+
         // Run query
         if ($ignore_errors == 1) {
             $result = @mysql_query($sql,$this->_db);
@@ -689,7 +744,28 @@ class database {
     function dbError($sql='')
     {
         if (mysql_errno()) {
-            $this->_errorlog(@mysql_errno() . ': ' . @mysql_error() . ". SQL in question: $sql");        
+            $fn = '';
+            $btr = debug_backtrace();
+            if (! empty($btr)) {
+                for ($i = 0; $i < 100; $i++) {
+                    if (isset($btr[$i])) {
+                        $b = $btr[$i];
+                        if ($b['function'] == 'DB_query') {
+                            if (!empty($b['file']) && !empty($b['line'])) {
+                                $fn = $b['file'] . ':' . $b['line'];
+                            }
+                            break;
+                        }
+                    } else {
+                        break;
+                    }
+                }
+            }
+            if (empty($fn)) {
+                $this->_errorlog(@mysql_errno() . ': ' . @mysql_error() . ". SQL in question: $sql");
+            } else {
+                $this->_errorlog(@mysql_errno() . ': ' . @mysql_error() . " in $fn. SQL in question: $sql");
+            }
             if ($this->_display_error) {
                 return  @mysql_errno() . ': ' . @mysql_error();
             } else {
@@ -758,6 +834,19 @@ class database {
         return @mysql_get_server_info();
     }
 
+    /**
+    * Escapes a string so that it can be safely used in a query
+    *
+    * @param   string   $str          a string to be escaped
+    * @return  string
+    */
+    function dbEscapeString($str)
+    {
+        $retval = mysql_real_escape_string($str, $this->_db);
+
+        return $retval;
+    }
+
 }
 
 ?>
