@@ -833,16 +833,37 @@ class database {
     */
     function dbError($sql = '')
     {
+        $fn = '';
+        $btr = debug_backtrace();
+        if (! empty($btr)) {
+            for ($i = 0; $i < count($btr); $i++) {
+                if (isset($btr[$i])) {
+                    $b = $btr[$i];
+                    if ($b['function'] == 'DB_query') {
+                        if (!empty($b['file']) && !empty($b['line'])) {
+                            $fn = $b['file'] . ':' . $b['line'];
+                        }
+                        break;
+                    }
+                } else {
+                    break;
+                }
+            }
+            if (! empty($fn)) {
+                $fn = ' in ' . $fn;
+            }
+        }
+
         $result = pg_get_result($this->_db);
         if ($this->_pgsql_version >= 7.4) {
             // this provides a much more detailed error report
             if (pg_result_error_field($result, PGSQL_DIAG_SOURCE_LINE)) {
                 $this->_errorlog('You have an error in your SQL query on line '
                     . pg_result_error_field($result, PGSQL_DIAG_SOURCE_LINE)
-                    . "\nSQL in question: $sql");
+                    . "$fn\nSQL in question: $sql");
                 $this->_errorlog('Error: '
                     . pg_result_error_field($result, PGSQL_DIAG_SQLSTATE)
-                    . "\nDescription: "
+                    . "$fn\nDescription: "
                     . pg_result_error_field($result, PGSQL_DIAG_MESSAGE_DETAIL));
                 if ($this->_display_error) {
                     $error = "An SQL error has occurred in the following SQL: $sql";
@@ -854,7 +875,7 @@ class database {
         } else {
             if (pg_result_error($result)) {
                 $this->_errorlog(pg_result_error($result)
-                    . ". SQL in question: $sql");        
+                    . "$fn. SQL in question: $sql");        
                 if ($this->_display_error) {
                     $error = 'Error ' . pg_result_error($result);
                 } else {
@@ -894,6 +915,19 @@ class database {
         return $v['server'];
     }
 
+    /**
+    * Escapes a string so that it can be safely used in a query
+    *
+    * @param   string   $str          a string to be escaped
+    * @return  string
+    */
+    function dbEscapeString($str)
+    {
+        $retval = pg_escape_string($this->_db, $str);
+
+        return $retval;
+    }
+
 }
 
 ?>
