@@ -2,7 +2,7 @@
 
 /* Reminder: always indent with 4 spaces (no tabs). */
 // +---------------------------------------------------------------------------+
-// | Geeklog 1.7                                                               |
+// | Geeklog 1.8                                                               |
 // +---------------------------------------------------------------------------+
 // | lib-custom.php                                                            |
 // |                                                                           |
@@ -20,7 +20,7 @@
 // | not include lib-common.php in this file.                                  |
 // |                                                                           |
 // +---------------------------------------------------------------------------+
-// | Copyright (C) 2000-2010 by the following authors:                         |
+// | Copyright (C) 2000-2011 by the following authors:                         |
 // |                                                                           |
 // | Authors: Tony Bibbs       - tony AT tonybibbs DOT com                     |
 // |          Blaine Lang      - blaine AT portalparts DOT com                 |
@@ -59,13 +59,6 @@ $_CST_VERBOSE = false;
  */
 require_once('custom/custom_cellular.php');
 
-/**
-* 日本語メール対応
-*
-* GL-1.4.1以降でUTF-8に変更されたメールの文字セットをISO-2022-JP(JIS)
-* に戻します。
-*/
-//require_once('custom/custom_mail_jp.php');
 
 /**
 * Sample PHP Block function
@@ -213,17 +206,17 @@ function CUSTOM_userCreate($uid, $bulkimport = false)
     }
 
     // Ensure all data is prepared correctly before inserts, quotes may need to
-    // be escaped with addslashes()
+    // be escaped with DB_escapeString()
     $email = '';
     if (isset ($_POST['email'])) {
         $email = COM_applyFilter ($_POST['email']);
-        $email = addslashes ($email);
+        $email = DB_escapeString ($email);
     }
 
     $homepage = '';
     if (isset ($_POST['homepage'])) {
         $homepage = COM_applyFilter ($_POST['homepage']);
-        $homepage = addslashes ($homepage);
+        $homepage = DB_escapeString($homepage);
     }
 
     $fullname = '';
@@ -231,7 +224,7 @@ function CUSTOM_userCreate($uid, $bulkimport = false)
         // COM_applyFilter would strip special characters, e.g. quotes, so
         // we only strip HTML
         $fullname = strip_tags ($_POST['fullname']);
-        $fullname = addslashes ($fullname);
+        $fullname = DB_escapeString($fullname);
     }
 
     // Note: In this case, we can trust the $uid variable to contain the new
@@ -251,7 +244,7 @@ function CUSTOM_userDelete($uid)
  * This function can now return any extra fields that need to be shown.
  * Output is then replaced in {customfields} -- This variable needs to be added
  * to your templates
- * Template: path_layout/users/profile/profile.thtml
+ * Template: path_layout/users/profile.thtml
  */
 function CUSTOM_userDisplay($uid)
 {
@@ -556,7 +549,7 @@ function CUSTOM_handleError($errno, $errstr, $errfile, $errline, $errcontext)
                 "An error has occurred: $errno $errstr @ $errline of $errfile");
         COM_errorLog("Error Handler: $errno $errstr @ $errline of $errfile");
     }
-    echo("
+    echo "
         <html>
             <head>
                 <title>{$_CONF['site_name']} - An error occurred.</title>
@@ -583,7 +576,7 @@ function CUSTOM_handleError($errno, $errstr, $errfile, $errline, $errcontext)
                 </div>
             </body>
         </html>
-        ");
+        ";
     exit;
 }
 */
