@@ -2,13 +2,13 @@
 
 /* Reminder: always indent with 4 spaces (no tabs). */
 // +---------------------------------------------------------------------------+
-// | Geeklog 1.5                                                               |
+// | Geeklog 1.8                                                               |
 // +---------------------------------------------------------------------------+
 // | lib-database.php                                                          |
 // |                                                                           |
 // | Geeklog database library.                                                 |
 // +---------------------------------------------------------------------------+
-// | Copyright (C) 2000-2008 by the following authors:                         |
+// | Copyright (C) 2000-2011 by the following authors:                         |
 // |                                                                           |
 // | Authors: Tony Bibbs, tony AT tonybibbs DOT com                            |
 // +---------------------------------------------------------------------------+
@@ -28,8 +28,6 @@
 // | Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.           |
 // |                                                                           |
 // +---------------------------------------------------------------------------+
-//
-// $Id: lib-database.php,v 1.54 2008/09/21 08:37:11 dhaun Exp $
 
 /**
 * This is the high-level database layer for Geeklog (for the low-level stuff,
@@ -54,8 +52,11 @@ $_TABLES['access']              = $_DB_table_prefix . 'access';
 $_TABLES['article_images']      = $_DB_table_prefix . 'article_images';
 $_TABLES['blocks']              = $_DB_table_prefix . 'blocks';
 $_TABLES['commentcodes']        = $_DB_table_prefix . 'commentcodes';
+$_TABLES['commentedits']        = $_DB_table_prefix . 'commentedits';
 $_TABLES['commentmodes']        = $_DB_table_prefix . 'commentmodes';
+$_TABLES['commentnotifications']= $_DB_table_prefix . 'commentnotifications';
 $_TABLES['comments']            = $_DB_table_prefix . 'comments';
+$_TABLES['commentsubmissions']  = $_DB_table_prefix . 'commentsubmissions';
 $_TABLES['conf_values']         = $_DB_table_prefix . 'conf_values';
 $_TABLES['cookiecodes']         = $_DB_table_prefix . 'cookiecodes';
 $_TABLES['dateformats']         = $_DB_table_prefix . 'dateformats';
@@ -76,6 +77,7 @@ $_TABLES['stories']             = $_DB_table_prefix . 'stories';
 $_TABLES['storysubmission']     = $_DB_table_prefix . 'storysubmission';
 $_TABLES['syndication']         = $_DB_table_prefix . 'syndication';
 $_TABLES['tokens']              = $_DB_table_prefix . 'tokens';
+$_TABLES['topic_assignments']   = $_DB_table_prefix . 'topic_assignments';
 $_TABLES['topics']              = $_DB_table_prefix . 'topics';
 $_TABLES['trackback']           = $_DB_table_prefix . 'trackback';
 $_TABLES['trackbackcodes']      = $_DB_table_prefix . 'trackbackcodes';
@@ -128,16 +130,23 @@ $_TABLES['userevent']           = $_DB_table_prefix . 'userevent';
 * Include appropriate DBMS object
 *
 */
-require_once $_CONF['path_system'] . 'databases/'. $_DB_dbms . '.class.php';
+if (($_DB_dbms === 'mysql') AND class_exists('MySQLi')) {
+    require_once $_CONF['path_system'] . 'databases/mysqli.class.php';
+} else {
+    require_once $_CONF['path_system'] . 'databases/'. $_DB_dbms . '.class.php';
+}
 
 // Instantiate the database object
 $_DB = new database($_DB_host, $_DB_name, $_DB_user, $_DB_pass, 'COM_errorLog',
                     $_CONF['default_charset']);
+if (isset($_CONF['rootdebug']) && $_CONF['rootdebug']) {
+    DB_displayError(true);
+}
 
 // +---------------------------------------------------------------------------+
 // | These are the library functions.  In all cases they turn around and make  |
 // | calls to the DBMS specific functions.  These ARE to be used directly in   |
-// | the code...do NOT use the $_DB methods directly
+// | the code...do NOT use the $_DB methods directly                           |
 // +---------------------------------------------------------------------------+
 
 /**
@@ -154,7 +163,7 @@ $_DB = new database($_DB_host, $_DB_name, $_DB_user, $_DB_pass, 'COM_errorLog',
 * @param        boolean     $flag       true or false
 *
 */
-function DB_setdebug($flag)
+function DB_setDebug($flag)
 {
     global $_DB;
 
@@ -283,7 +292,7 @@ function DB_getItem($table,$what,$selection='')
 * @param        string          $value_to_set       Value to set abovle field to
 * @param        array|string    $id                 field name(s) to use in where clause
 * @param        array|string    $value              Value(s) to use in where clause
-* @param	    string          $return_page        page to send user to when done with change
+* @param        string          $return_page        page to send user to when done with change
 * @param        boolean         $supress_quotes     whether or not to use single quotes in where clause
 *
 */
@@ -327,7 +336,7 @@ function DB_count($table,$id='',$value='')
 * @param        string          $fields         Comma delmited list of fields to copy over
 * @param        string          $values         Values to store in database field
 * @param        string          $tablefrom      Table to get record from
-* @param        array|string   	$id             Field name(s) to use in where clause
+* @param        array|string    $id             Field name(s) to use in where clause
 * @param        array|string    $value          Value(s) to use in where clause
 * @param        string          $return_page    Page to send user to when done
 *
@@ -452,11 +461,11 @@ function DB_fetchArray($recordset, $both = true)
 * @return   int                             Returns the last ID auto-generated
 *
 */
-function DB_insertId($link_identifier = '')
+function DB_insertId($link_identifier = '',$sequence='')
 {
     global $_DB;
 
-    return $_DB->dbInsertId($link_identifier);
+    return $_DB->dbInsertId($link_identifier,$sequence);
 }
 
 /**
@@ -556,13 +565,114 @@ function DB_checkTableExists($table)
             $exists = true;
         }
     } elseif ($_DB_dbms == 'mssql') {
-        $result = DB_Query("SELECT 1 FROM sysobjects WHERE name='{$_TABLES[$table]}' AND xtype='U'");
+        $result = DB_query("SELECT 1 FROM sysobjects WHERE name='{$_TABLES[$table]}' AND xtype='U'");
         if (DB_numRows ($result) > 0) {
             $exists = true;
         }
     }
+    elseif ($_DB_dbms == 'pgsql') {
+        $result = DB_query("select check_table('{$_TABLES[$table]}', 'public');");
+        $row=DB_fetchArray($result);
+        if(!empty($row[0])){
+            $exists = true;
+        }
+    }
 
     return $exists;
 }
 
+/**
+* Parse a CSV-like SQL string, as used by DB_save
+*
+* This function will help parse the CVS-like strings that are used by DB_save.
+* Those are specific to MySQL and have to be handled separately by other DBs.
+*
+* Since nothing can do this properly, I had to write it myself.
+* Trick is that a string csv may have a comma within a delimited csv field
+* which explode can't handle.
+*
+* @param    string  $csv    The string to parse
+* @return   array           parsed string contents
+* @author   Randy Kolenko
+* @see      DB_save
+* @internal to be used by the DB drivers only
+*
+*/
+function DBINT_parseCsvSqlString($csv)
+{
+    $len = strlen($csv);
+    $mode = 0;  // mode=0 for non string, mode=1 for string
+    $retArray = array();
+    $thisValue = '';
+    for ($x = 0; $x < $len; $x++) {
+        // loop thru the string
+        if ($csv[$x] == "'") {
+            if ($x != 0) {
+                if ($csv[$x-1] != "\\") {
+                    /**
+                    * this means that the preceeding char is not escape..
+                    * thus this is either the end of a mode 1 or the beginning
+                    * of a mode 1
+                    */
+                    if ($mode == 1) {
+                        $mode = 0;
+                        // this means that we are done this string value
+                        // don't add this character to the string
+                    } else {
+                        $mode = 1;
+                        // don't add this character to the string....
+                    }
+                } else {
+                    //this is a character to add.....
+                    $thisValue = $thisValue . $csv[$x];
+                }
+            } else {
+                // x==0
+                $mode = 1;
+            }
+        } elseif ($csv[$x] == ",") {
+            if ($mode == 1) {
+                // this means that the comma falls INSIDE of a string.
+                // its a keeper
+                $thisValue = $thisValue . $csv[$x];
+            } else {
+                // this is the dilineation between fields.. pop this value
+                array_push($retArray, $thisValue);
+                $thisValue = '';
+                $mode = 0;
+            }
+        } else {
+            // just add it!
+            $thisValue = $thisValue . $csv[$x];
+        }
+    }
+    array_push($retArray, $thisValue);
+
+    return $retArray;
+}
+
+/**
+* @return     string     the version of the database server
+*/
+
+function DB_getVersion()
+{
+    global $_DB;
+
+    return $_DB->dbGetVersion();
+}
+
+/**
+* Escapes a string so that it can be safely used in a query
+*
+* @param   string   $str          a string to be escaped
+* @return  string
+*/
+function DB_escapeString($str)
+{
+    global $_DB;
+
+	return $_DB->dbEscapeString($str);
+}
+
 ?>
