@@ -14,7 +14,7 @@
 // |          Mark Limburg     - mlimburg AT users DOT sourceforge DOT net     |
 // |          Vincent Furia    - vmf AT abtech DOT org                         |
 // |          Michael Jervis   - mike AT fuckingbrit DOT com                   |
-// |          Dirk Haun        - dirk AT haun-online DOT de
+// |          Dirk Haun        - dirk AT haun-online DOT de                    |
 // +---------------------------------------------------------------------------+
 // |                                                                           |
 // | This program is free software; you can redistribute it and/or             |
@@ -113,7 +113,7 @@ function SEC_getUserGroups($uid='')
     $result = DB_query("SELECT ug_main_grp_id,grp_name FROM {$_TABLES["group_assignments"]},{$_TABLES["groups"]}"
             . " WHERE grp_id = ug_main_grp_id AND ug_uid = $uid",1);
 
-    if ($result == -1) {
+    if ($result === false) {
         return $groups;
     }
 
@@ -273,22 +273,73 @@ function SEC_isModerator()
 
 /**
 * Checks to see if current user has access to a configuration
-* 
+*
 * @return   boolean     returns if user has any config. rights
 */
-function SEC_hasConfigAcess() {
+function SEC_hasConfigAccess()
+{
     global $_CONF_FT;
-    
+
     if (SEC_hasRights($_CONF_FT, 'OR')) {
         return true;
     }
-    
+
     return false;
 }
 
 /**
-* Checks to see if current user has access to a topic
+* Deprecated - use SEC_hasConfigAccess instead
 *
+* @deprecated since Geeklog 2.0.0
+* @see SEC_hasConfigAccess
+*/
+function SEC_hasConfigAcess()
+{
+    return SEC_hasConfigAccess();
+}
+
+/**
+* Checks to see if current user has access to a admin moderation page
+*
+* @return       boolean 	
+*
+*/
+function SEC_hasModerationAccess()
+{
+    global $_CONF;
+    
+    $hasAccess = false;
+    
+    if (SEC_hasRights('story.moderate')) {
+        $hasAccess = true;
+    }
+
+    if ($_CONF['listdraftstories'] == 1) {
+        if (SEC_hasRights('story.edit')) {
+            $hasAccess = true;
+        }
+    }
+    
+    if ($_CONF['commentsubmission'] == 1) {
+        if (SEC_hasRights('comment.moderate')) {
+            $hasAccess = true;
+        }
+    }
+
+    if ($_CONF['usersubmission'] == 1) {
+        if (SEC_hasRights('user.edit') && SEC_hasRights('user.delete')) {
+            $hasAccess = true;
+        }
+    }
+    
+    if (PLG_isModerator()) {
+        $hasAccess = false;
+    }
+    
+    return $hasAccess;
+}
+
+/**
 * Checks to see if current user has access to a topic
 *
 * @param        string      $tid        ID for topic to check on
@@ -323,22 +374,25 @@ function SEC_hasTopicAccess($tid)
 * @param        int     $perm_group     Permissions the gorup has
 * @param        int     $perm_members   Permissions logged in members have
 * @param        int     $perm_anon      Permissions anonymous users have
+* @param        int     $uid            User id or 0 = current user
 * @return       int 	returns 3 for read/edit 2 for read only 0 for no access
 *
 */
-function SEC_hasAccess($owner_id,$group_id,$perm_owner,$perm_group,$perm_members,$perm_anon)
+function SEC_hasAccess($owner_id,$group_id,$perm_owner,$perm_group,$perm_members,$perm_anon, $uid = 0)
 {
     global $_USER;
 
-    // Cache current user id
-    if (empty($_USER['uid'])) {
-        $uid = 1;
-    } else {
-        $uid = $_USER['uid'];
+    if ($uid == 0) {
+        // Cache current user id
+        if (empty($_USER['uid'])) {
+            $uid = 1;
+        } else {
+            $uid = $_USER['uid'];
+        }
     }
-
+    
     // If user is in Root group then return full access
-    if (SEC_inGroup('Root')) {
+    if (SEC_inGroup('Root', $uid)) {
         return 3;
     }
 
@@ -346,7 +400,7 @@ function SEC_hasAccess($owner_id,$group_id,$perm_owner,$perm_group,$perm_members
     if ($uid == $owner_id) return $perm_owner;
 
     // Not private, if user is in group then give access
-    if (SEC_inGroup($group_id)) {
+    if (SEC_inGroup($group_id, $uid)) {
         return $perm_group;
     } else {
         if ($uid == 1) {
@@ -514,7 +568,7 @@ function SEC_getUserPermissions($grp_id='', $uid='')
         }
     }
 
-    if ((empty ($_USER['uid']) && ($uid == 1)) || ($uid == $_USER['uid'])) {
+    if ((empty ($_USER['uid']) && ($uid == 1)) || (!empty ($_USER['uid']) && ($uid == $_USER['uid']))) {
         if (empty ($_GROUPS)) {
             $_GROUPS = SEC_getUserGroups ($uid);
         }
@@ -726,9 +780,9 @@ function SEC_authenticate($username, $password, &$uid)
         $U = DB_fetchArray($result);
         $uid = $U['uid'];
         if ($U['status'] == USER_ACCOUNT_DISABLED) {
-            // banned, jump to here to save an md5 calc.
+            // banned, jump to here to save an password hash calc.
             return USER_ACCOUNT_DISABLED;
-        } elseif ($U['passwd'] != SEC_encryptPassword($password)) {
+        } elseif (SEC_encryptUserPassword($password, $uid) < 0) {
             return -1; // failed login
         } elseif ($U['status'] == USER_ACCOUNT_AWAITING_APPROVAL) {
             return USER_ACCOUNT_AWAITING_APPROVAL;
@@ -742,7 +796,7 @@ function SEC_authenticate($username, $password, &$uid)
         }
     } else {
         $tmp = $LANG01[32] . ": '" . $username . "'";
-        COM_errorLog($tmp, 1);
+        COM_accessLog($tmp);
         return -1;
     }
 }
@@ -816,8 +870,8 @@ function SEC_remoteAuthentication(&$loginname, $passwd, $service, &$uid)
     global $_CONF, $_TABLES;
 
     /* First try a local cached login */
-    $remoteusername = addslashes($loginname);
-    $remoteservice = addslashes($service);
+    $remoteusername = DB_escapeString($loginname);
+    $remoteservice = DB_escapeString($service);
     $result = DB_query("SELECT passwd, status, uid FROM {$_TABLES['users']} WHERE remoteusername='$remoteusername' AND remoteservice='$remoteservice'");
     $tmp = DB_error();
     $nrows = DB_numRows($result);
@@ -853,7 +907,7 @@ function SEC_remoteAuthentication(&$loginname, $passwd, $service, &$uid)
                                                                  $service);
                     }
                 }
-                USER_createAccount($loginname, $authmodule->email, SEC_encryptPassword($passwd), $authmodule->fullname, $authmodule->homepage, $remoteusername, $remoteservice);
+                USER_createAccount($loginname, $authmodule->email, $passwd, $authmodule->fullname, $authmodule->homepage, $remoteusername, $remoteservice);
                 $uid = DB_getItem($_TABLES['users'], 'uid', "remoteusername = '$remoteusername' AND remoteservice='$remoteservice'");
                 // Store full remote account name:
                 DB_query("UPDATE {$_TABLES['users']} SET remoteusername='$remoteusername', remoteservice='$remoteservice', status=3 WHERE uid='$uid'");
@@ -1048,7 +1102,7 @@ function SEC_getGroupDropdown ($group_id, $access)
     if ($access == 3) {
         $usergroups = SEC_getUserGroups ();
 
-        $groupdd .= '<select name="group_id">' . LB;
+        $groupdd .= '<select id="group_id" name="group_id">' . LB;
         foreach ($usergroups as $ug_name => $ug_id) {
             $groupdd .= '<option value="' . $ug_id . '"';
             if ($group_id == $ug_id) {
@@ -1061,27 +1115,229 @@ function SEC_getGroupDropdown ($group_id, $access)
         // They can't set the group then
         $groupdd .= DB_getItem ($_TABLES['groups'], 'grp_name',
                                 "grp_id = '$group_id'")
-                 . '<input type="hidden" name="group_id" value="' . $group_id
+                 . '<input type="hidden" id="group_id" name="group_id" value="' . $group_id
                  . '"' . XHTML . '>';
     }
 
     return $groupdd;
 }
 
+/**
+ * Class defining constants for encryptions algorithms. These values are stored
+ * in the user database to indicate the hash function the user's password is
+ * encrypted with.
+ */
+class HashFunction {
+    const md5      = 0;
+    const sha1     = 1;
+    const sha256   = 2;
+    const sha512   = 3;
+    const blowfish = 4;
+}
+
 /**
 * Encrypt password
 *
-* For now, this is only a wrapper function to get all the direct calls to
-* md5() out of the core code so that we can switch to another method of
-* encoding / encrypting our passwords in some future release ...
+* Encrypts $password using the specified salt, hash algorithm, and stretch
+* count.
 *
 * @param    string  $password   the password to encrypt, in clear text
+* @param    string  $salt       salt to prepend to the password prior to hashing
+* @param    int     $algorithm  hash algorithm to use to encrypt the password
+* @param    int     $stretch    number of times hash function should be applied
+*                               to the password.
 * @return   string              encrypted password
 *
 */
-function SEC_encryptPassword($password)
+function SEC_encryptPassword($password, $salt = '', $algorithm = null, $stretch = null)
 {
-    return md5($password);
+    global $_CONF;
+
+    /* grab defaults if not specified, default salt is empty */
+    if ( is_null($algorithm) ) {
+        $algorithm = $_CONF['pass_alg'];
+    }
+    if ( is_null($stretch) ) {
+        $stretch = $_CONF['pass_stretch'];
+    }
+
+    /* A stretch of less than one implies no encryption, do not allow that */
+    if ($stretch < 1) {
+        $stretch = 1;
+    }
+
+    /* encrypt password based on algorithm */
+    switch ($algorithm) {
+    case HashFunction::md5:
+        $hash = $password;
+        for ($i = 0; $i < $stretch; $i++) {
+            $hash = md5($hash . $salt, false);
+        }
+        break;
+
+    case HashFunction::sha1:
+        $hash = $password;
+        for ($i = 0; $i < $stretch; $i++) {
+            $hash = sha1($hash . $salt, false);
+        }
+        break;
+
+    case HashFunction::sha256:
+        if ($stretch < 1000) $stretch = 1000;
+        $salt = '$5$rounds=' . $stretch . '$' . $salt . '$';
+        $hash = crypt($password, $salt);
+        break;
+
+    case HashFunction::sha512:
+        if ($stretch < 1000) $stretch = 1000;
+        $salt = '$6$rounds=' . $stretch . '$' . $salt . '$';
+        $hash = crypt($password, $salt);
+        break;
+
+    case HashFunction::blowfish:
+        $stretch = log($stretch, 2);       /* blow fish crypt uses a log 2 number for cost */
+        if ($stretch < 4) $stretch = 4;    /* crypt defined minimum */
+        if ($stretch > 31) $stretch = 31;  /* crypt defined maximum */
+        $salt = '$2a$' . sprintf('%02d', $stretch) . '$' . $salt . '$';
+        $hash = crypt($password, $salt);
+        break;
+
+    default:  /* unrecognized algorithm error */
+        return -1;
+    }
+
+    return $hash;
+}
+
+/**
+ * Generate password salt
+ *
+ * This function produces a random string of 22 characters from a 64 character set.
+ * The size is needed for password salting, but is useful any function that needs a
+ * random set of human readable characters.
+ *
+ * @return  string  generated salt
+ */
+function SEC_generateSalt() {
+    static $charset = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz1234567890';
+
+    $salt = '';
+    for ($i = 0; $i < 22; $i++) {
+        $salt .= $charset[mt_rand(0,61)];
+    }
+
+    return $salt;
+}
+
+/**
+ * Encrypt User Password
+ *
+ * Verify that the provided password authenticates the specified user (defualts
+ * to the current user).
+ *
+ * @param  string  $password  password to verify
+ * @param  int     $uid       user id to authenticate
+ * @return int     0 for success, non-zero for failure or error
+ */
+function SEC_encryptUserPassword($password, $uid = '')
+{
+    global $_USER, $_CONF, $_TABLES;
+
+    // if $uid is empty, assume current user
+    if (empty($uid)) {
+        $uid = $_USER['uid'];
+    }
+
+    // validate $uid nonempty and valid user (anonymous, uid = 1, not valid)
+    if (empty($uid) || $uid < 1) {
+        return -1;
+    }
+
+    /* get passwd, algorithm, stretch, and salt from $_USER if possible, else
+     * get them from the DB
+     */
+    if ( ( isset($_USER['uid']) && ($uid == $_USER['uid']) && isset($_USER['passwd']) &&
+           isset($_USER['algorithm']) && isset($_USER['stretch']) && isset($_USER['salt']) ) ) {
+        $passwd    = $_USER['passwd'];
+        $algorithm = $_USER['algorithm'];
+        $stretch   = $_USER['stretch'];
+        $salt      = $_USER['salt'];
+    } else {
+        $query = "SELECT passwd, salt, algorithm, stretch FROM " . $_TABLES['users']
+               . " WHERE uid = $uid";
+        $result = DB_query($query);
+        list($passwd, $salt, $algorithm, $stretch) = DB_fetchArray($result);
+    }
+
+    /* verify we have good data */
+    if (empty($passwd) || is_null($salt) || !is_numeric($algorithm) || empty($stretch)) {
+        return -1;
+    }
+
+    // calculate hash to verify password
+    $newhash = SEC_encryptPassword($password, $salt, $algorithm, $stretch);
+
+    /* if the hash checks out, update hash if needed and return success, otherwise return an error */
+    if ($newhash == $passwd) {
+        if ($algorithm != $_CONF['pass_alg'] || $stretch != $_CONF['pass_stretch'] || empty($salt)) {
+            SEC_updateUserPassword($password, $uid);
+        }
+        return 0;
+    } else {
+        return -255;
+    }
+}
+
+/**
+ * Generate Random Password
+ *
+ * Generates a random string of human readable characters.
+ *
+ * @return  string  generated random password
+ */
+function SEC_generateRandomPassword() {
+    // SEC_generateSalt is used here as it creates a random string using readable characters
+    return substr(SEC_generateSalt(), 0, 12);
+}
+
+/**
+ * Update User Password
+ *
+ * Updates the users password for current hash algorithm and stretch site settings.
+ * If not password is specified, a random password will be generated.
+ *
+ * @param  string  $password  Password to encrypt
+ * @param  int     $uid       User id to update
+ * @return int     0 for success, non-zero indicates error.
+ */
+function SEC_updateUserPassword(&$password = '', $uid = '') {
+    global $_TABLES, $_CONF, $_USER;
+
+    // if no password is specified, generate a random one
+    if (empty($password)) {
+        $password = SEC_generateRandomPassword();
+    }
+
+    // if $uid is empty, assume current user
+    if (empty($uid)) {
+        $uid = $_USER['uid'];
+    }
+
+    // validate $uid nonempty and valid user (anonymous, uid = 1, not valid)
+    if (empty($uid) || $uid < 1) {
+        return -1;
+    }
+
+    // update the database with the new password using algorithm and stretch from $_CONF
+    $salt = SEC_generateSalt();
+    $newhash = SEC_encryptPassword($password, $salt, $_CONF['pass_alg'], $_CONF['pass_stretch']);
+    $query = 'UPDATE ' . $_TABLES['users'] . " SET passwd = '$newhash', "
+        . "salt = '$salt', algorithm ='" . $_CONF['pass_alg'] . "', " 
+        . 'stretch = ' . $_CONF['pass_stretch'] . " WHERE uid = $uid";
+    DB_query($query);
+
+    // return success
+    return 0;
 }
 
 /**
@@ -1113,7 +1369,7 @@ function SEC_createToken($ttl = 1200)
     
     /* Generate the token */
     $token = md5($uid.$pageURL.uniqid (rand (), 1));
-    $pageURL = addslashes($pageURL);
+    $pageURL = DB_escapeString($pageURL);
     
     /* Destroy exired tokens: */
     $sql['mssql'] = "DELETE FROM {$_TABLES['tokens']} WHERE (DATEADD(ss, ttl, created) < NOW())"
@@ -1124,10 +1380,12 @@ function SEC_createToken($ttl = 1200)
            . " AND (ttl > 0)";                           
     DB_query($sql);
     
-    /* Destroy tokens for this user/url combination */
-    $sql = "DELETE FROM {$_TABLES['tokens']} WHERE owner_id='{$uid}' AND urlfor='$pageURL'";
-    DB_query($sql);
-    
+    /* Destroy tokens for this user/url combination. Since annonymous user share same id do not delete */
+    if ($uid != 1) {
+         $sql = "DELETE FROM {$_TABLES['tokens']} WHERE owner_id = '{$uid}' AND urlfor= '$pageURL'";
+         DB_query($sql);
+     }
+     
     /* Create a token for this user/url combination */
     /* NOTE: TTL mapping for PageURL not yet implemented */
     $sql = "INSERT INTO {$_TABLES['tokens']} (token, created, owner_id, urlfor, ttl) "
@@ -1185,10 +1443,9 @@ function SEC_checkToken()
         $files = serialize($_FILES);
     }
 
-    $display = COM_siteHeader('menu', $LANG20[1])
-             . COM_showMessageText($LANG_ADMIN['token_expired'])
-             . SECINT_authform($returnurl, $method, $postdata, $getdata, $files)
-             . COM_siteFooter();
+    $display = COM_showMessageText($LANG_ADMIN['token_expired'])
+             . SECINT_authform($returnurl, $method, $postdata, $getdata, $files);
+    $display = COM_createHTMLDocument($display, array('pagetitle' => $LANG20[1]));
 
     COM_output($display);
     exit;
@@ -1243,7 +1500,8 @@ function SECINT_checkToken()
              *  token is not expired.
              *  the http referer is the url for which the token was created.
              */
-            if( $_USER['uid'] != $tokendata['owner_id'] ) {
+            $uid = isset($_USER['uid']) ? $_USER['uid'] : 1;
+            if ($uid != $tokendata['owner_id']) {             
                 $return = false;
             } else if($tokendata['urlfor'] != $_SERVER['HTTP_REFERER']) {
                 $return = false;
@@ -1596,10 +1854,11 @@ function SEC_loginRequiredForm()
 */
 function SEC_loginForm($use_config = array())
 {
-    global $_CONF, $LANG01, $LANG04;
+    global $_CONF, $LANG01, $LANG04, $_SCRIPTS;
 
     $retval = '';
 
+    $have_remote_login = false;
     $default_config = array(
         // display options
         'hide_forgotpw_link' => false,
@@ -1647,6 +1906,8 @@ function SEC_loginForm($use_config = array())
         $loginform->set_var('forgetpassword_link', $forget);
     }
     $loginform->set_var('lang_login', $config['button_text']);
+    $loginform->set_var('lang_remote_login', $LANG04[167]);
+    $loginform->set_var('lang_remote_login_desc', $LANG04[168]);
     $loginform->set_var('end_block', COM_endBlock());
 
     // 3rd party remote authentification.
@@ -1691,6 +1952,8 @@ function SEC_loginForm($use_config = array())
     if (!$config['no_openid_login'] && $_CONF['user_login_method']['openid'] &&
             ($_CONF['usersubmission'] == 0) &&
             !$_CONF['disable_new_user_registration']) {
+        $have_remote_login = true;
+        $_SCRIPTS->setJavascriptFile('login', '/javascript/login.js');
         $loginform->set_file('openid_login', '../loginform_openid.thtml');
         $loginform->set_var('lang_openid_login', $LANG01[128]);
         $loginform->set_var('input_field_size', 40);
@@ -1712,6 +1975,8 @@ function SEC_loginForm($use_config = array())
     if (!$config['no_oauth_login'] && $_CONF['user_login_method']['oauth'] && 
             ($_CONF['usersubmission'] == 0) &&
             !$_CONF['disable_new_user_registration']) {
+        $have_remote_login = true;
+        $_SCRIPTS->setJavascriptFile('login', '/javascript/login.js');
         $modules = SEC_collectRemoteOAuthModules();
         if (count($modules) == 0) {
             $loginform->set_var('oauth_login', '');
@@ -1720,9 +1985,9 @@ function SEC_loginForm($use_config = array())
             foreach ($modules as $service) {
                 $loginform->set_file('oauth_login', '../loginform_oauth.thtml');
                 $loginform->set_var('oauth_service', $service);
+                $loginform->set_var('lang_oauth_service', $LANG01[$service]);
                 // for sign in image
-                $loginform->set_var('oauth_sign_in_image', $_CONF['site_url'] . '/images/login-with-' . $service . '.png');
-                $loginform->set_var('oauth_sign_in_image_style', '');
+                $loginform->set_var('oauth_sign_in_image', $_CONF['site_url'] . '/images/' . $service . '-login-icon.png');
                 $loginform->parse('output', 'oauth_login');
                 $html_oauth .= $loginform->finish($loginform->get_var('output'));
             }
@@ -1732,6 +1997,10 @@ function SEC_loginForm($use_config = array())
         $loginform->set_var('oauth_login', '');
     }
 
+    if ($have_remote_login) {
+        $loginform->set_var('remote_login_class', 'remote-login-enabled');
+    }
+
     if (! $config['no_plugin_vars']) {
         PLG_templateSetVars('loginform', $loginform);
     }
@@ -1752,43 +2021,28 @@ function SEC_collectRemoteOAuthModules()
 {
     global $_CONF;
 
+    $available_modules = array('facebook','google','twitter','microsoft','linkedin','yahoo');
+
     $modules = array();
-    
-    // Check for OpenSSL PHP extension which is required
+
     if (extension_loaded('openssl')) {
-        $modulespath = $_CONF['path_system'] . 'classes/oauth/';
-        if (is_dir($modulespath)) {
-            $folder = opendir($modulespath);
-            while (($filename = @readdir($folder)) !== false) {
-                $pos = strpos($filename, '.auth.class.php');
-                if ($pos && (substr($filename, strlen($filename) - 4) == '.php')) {
-                    $mod = substr($filename, 0, $pos);
-                    $def_thtml = $_CONF['path_layout'] . 'loginform_oauth.thtml';
-                    $thtml = $_CONF['path_layout'] . 'loginform_' . $mod . '.thtml';
-                    if (file_exists($def_thtml) || file_exists($thtml)) {
-                        // Check to see if there is a config value to enable or disable login method
-                        if (isset($_CONF[$mod . '_login'])) {
-                            if ($_CONF[$mod . '_login']) {
-                                // Now check if a Consumer Key and Secret exist and are set
-                                if (isset($_CONF[$mod . '_consumer_key'])) {
-                                    if ($_CONF[$mod . '_consumer_key'] != '') {
-                                        if (isset($_CONF[$mod . '_consumer_secret'])) {
-                                            if ($_CONF[$mod . '_consumer_secret'] != '') {
-                                                $modules[] = $mod;
-                                            }
-                                        }                                
-                                    }
-                                }                                
+        foreach ($available_modules as $mod) {
+            if (isset($_CONF[$mod . '_login'])) {
+                if ($_CONF[$mod . '_login']) {
+                    // Now check if a Consumer Key and Secret exist and are set
+                    if (isset($_CONF[$mod . '_consumer_key'])) {
+                        if ($_CONF[$mod . '_consumer_key'] != '') {
+                            if (isset($_CONF[$mod . '_consumer_secret'])) {
+                                if ($_CONF[$mod . '_consumer_secret'] != '') {
+                                    $modules[] = $mod;
+                                }
                             }
-                        } else {
-                            $modules[] = $mod;
                         }
                     }
                 }
             }
         }
     }
-    
     return $modules;
 }
 
