@@ -2,13 +2,13 @@
 
 /* Reminder: always indent with 4 spaces (no tabs). */
 // +---------------------------------------------------------------------------+
-// | Geeklog 1.5                                                               |
+// | Geeklog 1.7                                                               |
 // +---------------------------------------------------------------------------+
 // | lib-sessions.php                                                          |
 // |                                                                           |
 // | Geeklog session library.                                                  |
 // +---------------------------------------------------------------------------+
-// | Copyright (C) 2000-2008 by the following authors:                         |
+// | Copyright (C) 2000-2010 by the following authors:                         |
 // |                                                                           |
 // | Authors: Tony Bibbs       - tony AT tonybibbs DOT com                     |
 // |          Mark Limburg     - mlimburg AT users DOT sourceforge DOT net     |
@@ -29,8 +29,6 @@
 // | Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.           |
 // |                                                                           |
 // +---------------------------------------------------------------------------+
-//
-// $Id: lib-sessions.php,v 1.45 2008/05/11 07:25:08 dhaun Exp $
 
 /**
 * This is the session management library for Geeklog.  Some of this code was
@@ -41,8 +39,8 @@
 // Turn this on if you want to see various debug messages from this library
 $_SESS_VERBOSE = false;
 
-if (strpos ($_SERVER['PHP_SELF'], 'lib-sessions.php') !== false) {
-    die ('This file can not be used on its own!');
+if (strpos(strtolower($_SERVER['PHP_SELF']), 'lib-sessions.php') !== false) {
+    die('This file can not be used on its own!');
 }
 
 if (empty ($_CONF['cookiedomain'])) {
@@ -96,7 +94,7 @@ function SESS_sessionCheck()
         $_COOKIE[$_CONF['cookie_session']] = CUSTOM_MOBILE_load_session();
         CUSTOM_MOBILE_debug("cookie_session in SESS_sessionCheck: " . $_COOKIE[$_CONF['cookie_session']]);
     }
-    
+
     // Check for a cookie on the users's machine.  If the cookie exists, build
     // an array of the users info and setup the theme.
 
@@ -114,17 +112,23 @@ function SESS_sessionCheck()
 
         if ($userid > 1) {
             // Check user status
-            SEC_checkUserStatus($userid);
-            $user_logged_in = 1;
-            SESS_updateSessionTime($sessid, $_CONF['cookie_ip']);
-            $userdata = SESS_getUserDataFromId($userid);
-            if ($_SESS_VERBOSE) {
-                COM_errorLog("Got " . count($userdata) . " pieces of data from userdata",1);
-                COM_errorLog(COM_debug($userdata),1);
-                // COM_debug($userdata);
+            $status = SEC_checkUserStatus($userid);
+            if (($status == USER_ACCOUNT_ACTIVE) ||
+                    ($status == USER_ACCOUNT_AWAITING_ACTIVATION)) {
+                $user_logged_in = 1;
+
+                SESS_updateSessionTime($sessid, $_CONF['cookie_ip']);
+                $userdata = SESS_getUserDataFromId($userid);
+                if ($_SESS_VERBOSE) {
+                    COM_errorLog("Got " . count($userdata) . " pieces of data from userdata", 1);
+                    COM_errorLog(COM_debug($userdata), 1);
+                }
+                $_USER = $userdata;
+                $_USER['auto_login'] = false;
             }
-            $_USER = $userdata;
-            $_USER['auto_login'] = false;
+        } elseif ($userid == 1) {
+            // Anonymous User has session so update any information
+            SESS_updateSessionTime($sessid, $_CONF['cookie_ip']);
         } else {
             // Session probably expired, now check permanent cookie
             if (isset ($_COOKIE[$_CONF['cookie_name']])) {
@@ -132,27 +136,67 @@ function SESS_sessionCheck()
                 if (empty ($userid) || ($userid == 'deleted')) {
                     unset ($userid);
                 } else {
+                    if ($_SESS_VERBOSE) {
+                        COM_errorLog("Got $userid as User ID from the permanent cookie",1);
+                    }
+                    
                     $userid = COM_applyFilter ($userid, true);
                     $cookie_password = '';
                     $userpass = '';
-                    if ($userid > 1) {
+                    if (($userid > 1) &&
+                            isset($_COOKIE[$_CONF['cookie_password']])) {
                         $cookie_password = $_COOKIE[$_CONF['cookie_password']];
-                        $userpass = DB_getItem ($_TABLES['users'], 'passwd',
-                                                "uid = $userid");
+                        $userpass = DB_getItem($_TABLES['users'], 'passwd',
+                                               "uid = $userid");
                     }
-                    if (empty ($cookie_password) || ($cookie_password <> $userpass)) {
-                        // User may have modified their UID in cookie, ignore them
+                    if (empty($cookie_password) || ($cookie_password <> $userpass)) {
+                        if ($_SESS_VERBOSE) {
+                            COM_errorLog("Password comparison failed or cookie password missing",1);
+                        }
+                        
+                        // Invalid or manipulated cookie data
+                        SEC_setCookie($_CONF['cookie_session'], '',
+                                      time() - 10000);
+                        SEC_setCookie($_CONF['cookie_password'], '',
+                                      time() - 10000);
+                        SEC_setCookie($_CONF['cookie_name'], '', time() - 10000);
+
+                        COM_clearSpeedlimit($_CONF['login_speedlimit'], 'login');
+                        if (COM_checkSpeedlimit('login', $_CONF['login_attempts']) > 0) {
+                            if (! defined('XHTML')) { define('XHTML', ''); }
+                            COM_displayMessageAndAbort(82, '', 403, 'Access denied');
+                        }
+                        COM_updateSpeedlimit('login');
                     } else if ($userid > 1) {
+                        if ($_SESS_VERBOSE) {
+                            COM_errorLog("Password comparison passed",1);
+                        }                        
                         // Check user status
-                        SEC_checkUserStatus ($userid);
-                        $user_logged_in = 1;
-                        $sessid = SESS_newSession ($userid, $_SERVER['REMOTE_ADDR'], $_CONF['session_cookie_timeout'], $_CONF['cookie_ip']);
-                        SESS_setSessionCookie ($sessid, $_CONF['session_cookie_timeout'], $_CONF['cookie_session'], $_CONF['cookie_path'], $_CONF['cookiedomain'], $_CONF['cookiesecure']);
-                        $userdata = SESS_getUserDataFromId ($userid);
-                        $_USER = $userdata;
-                        $_USER['auto_login'] = true;
+                        $status = SEC_checkUserStatus ($userid);
+                        if (($status == USER_ACCOUNT_ACTIVE) ||
+                                ($status == USER_ACCOUNT_AWAITING_ACTIVATION)) {
+                            $user_logged_in = 1;
+
+                            if ($_SESS_VERBOSE) {
+                                COM_errorLog("Create new session and write cookie",1);
+                            }                               
+                            $sessid = SESS_newSession($userid, $_SERVER['REMOTE_ADDR'], $_CONF['session_cookie_timeout'], $_CONF['cookie_ip']);
+                            SESS_setSessionCookie($sessid, $_CONF['session_cookie_timeout'], $_CONF['cookie_session'], $_CONF['cookie_path'], $_CONF['cookiedomain'], $_CONF['cookiesecure']);
+                            $userdata = SESS_getUserDataFromId($userid);
+                            $_USER = $userdata;
+                            $_USER['auto_login'] = true;
+                        }
                     }
                 }
+            } else {
+                if ($_SESS_VERBOSE) {
+                    COM_errorLog('perm cookie not found from lib-sessions.php',1);
+                }                
+                
+                // Anonymous user has session id but it has been expired and wiped from the db so reset
+                $userid = 1;
+                $sessid = SESS_newSession($userid, $_SERVER['REMOTE_ADDR'], $_CONF['session_cookie_timeout'], $_CONF['cookie_ip']);
+                SESS_setSessionCookie($sessid, $_CONF['session_cookie_timeout'], $_CONF['cookie_session'], $_CONF['cookie_path'], $_CONF['cookiedomain'], $_CONF['cookiesecure']);
             }
         }
     } else {
@@ -161,7 +205,6 @@ function SESS_sessionCheck()
         }
 
         // Check if the persistent cookie exists
-
         if (isset ($_COOKIE[$_CONF['cookie_name']])) {
             // Session cookie doesn't exist but a permanent cookie does.
             // Start a new session cookie;
@@ -173,29 +216,66 @@ function SESS_sessionCheck()
             if (empty ($userid) || ($userid == 'deleted')) {
                 unset ($userid);
             } else {
+                if ($_SESS_VERBOSE) {
+                    COM_errorLog("Got $userid as User ID from the permanent cookie",1);
+                }
+                
                 $userid = COM_applyFilter ($userid, true);
                 $cookie_password = '';
                 $userpass = '';
-                if ($userid > 1) {
-                    $userpass = DB_getItem ($_TABLES['users'], 'passwd',
-                                            "uid = $userid");
+                if (($userid > 1) && isset($_COOKIE[$_CONF['cookie_password']])) {
+                    $userpass = DB_getItem($_TABLES['users'], 'passwd',
+                                           "uid = $userid");
                     $cookie_password = $_COOKIE[$_CONF['cookie_password']];
                 }
-                if (empty ($cookie_password) || ($cookie_password <> $userpass)) {
-                    // User could have modified UID in cookie, don't do shit
-                } else if ($userid > 1) {
-                    // Check user status
-                    SEC_checkUserStatus ($userid);
-                    $user_logged_in = 1;
+                if (empty($cookie_password) || ($cookie_password <> $userpass)) {
+                    if ($_SESS_VERBOSE) {
+                        COM_errorLog("Password comparison failed or cookie password missing",1);
+                    }
+                    
+                    // Invalid or manipulated cookie data
+                    SEC_setCookie($_CONF['cookie_session'], '', time() - 10000);
+                    SEC_setCookie($_CONF['cookie_password'], '', time() - 10000);
+                    SEC_setCookie($_CONF['cookie_name'], '', time() - 10000);
 
-                    // Create new session and write cookie
-                    $sessid = SESS_newSession ($userid, $_SERVER['REMOTE_ADDR'], $_CONF['session_cookie_timeout'], $_CONF['cookie_ip']);
-                    SESS_setSessionCookie ($sessid, $_CONF['session_cookie_timeout'], $_CONF['cookie_session'], $_CONF['cookie_path'], $_CONF['cookiedomain'], $_CONF['cookiesecure']);
-                    $userdata = SESS_getUserDataFromId ($userid);
-                    $_USER = $userdata;
-                    $_USER['auto_login'] = true;
+                    COM_clearSpeedlimit($_CONF['login_speedlimit'], 'login');
+                    if (COM_checkSpeedlimit('login', $_CONF['login_attempts']) > 0) {
+                        if (! defined('XHTML')) { define('XHTML', ''); }
+                        COM_displayMessageAndAbort(82, '', 403, 'Access denied');
+                    }
+                    COM_updateSpeedlimit('login');
+                } else if ($userid > 1) {
+                    if ($_SESS_VERBOSE) {
+                        COM_errorLog("Password comparison passed",1);
+                    }                        
+                    
+                    // Check user status
+                    $status = SEC_checkUserStatus($userid);
+                    if (($status == USER_ACCOUNT_ACTIVE) ||
+                            ($status == USER_ACCOUNT_AWAITING_ACTIVATION)) {
+                        $user_logged_in = 1;
+
+                        if ($_SESS_VERBOSE) {
+                            COM_errorLog("Create new session and write cookie",1);
+                        }                        
+                        // Create new session and write cookie
+                        $sessid = SESS_newSession($userid, $_SERVER['REMOTE_ADDR'], $_CONF['session_cookie_timeout'], $_CONF['cookie_ip']);
+                        SESS_setSessionCookie($sessid, $_CONF['session_cookie_timeout'], $_CONF['cookie_session'], $_CONF['cookie_path'], $_CONF['cookiedomain'], $_CONF['cookiesecure']);
+                        $userdata = SESS_getUserDataFromId($userid);
+                        $_USER = $userdata;
+                        $_USER['auto_login'] = true;
+                    }
                 }
             }
+        } else {
+            if ($_SESS_VERBOSE) {
+                COM_errorLog('perm cookie not found from lib-sessions.php',1);
+            }
+            
+            // New Anonymous user so create new session and write cookie
+            $userid = 1;
+            $sessid = SESS_newSession($userid, $_SERVER['REMOTE_ADDR'], $_CONF['session_cookie_timeout'], $_CONF['cookie_ip']);
+            SESS_setSessionCookie($sessid, $_CONF['session_cookie_timeout'], $_CONF['cookie_session'], $_CONF['cookie_path'], $_CONF['cookiedomain'], $_CONF['cookiesecure']);            
         }
     }
 
@@ -203,9 +283,10 @@ function SESS_sessionCheck()
         COM_errorLog("***Leaving SESS_sessionCheck***",1);
     }
 
+    $_USER['session_id'] = $sessid;
+    
     // Ensure $_USER is set to avoid warnings (path exposure...)
-    if(isset($_USER))
-    {
+    if (isset($_USER)) {
         return $_USER;
     } else {
         return NULL;
@@ -233,7 +314,6 @@ function SESS_newSession($userid, $remote_ip, $lifespan, $md5_based=0)
         COM_errorLog("*************inside new_session*****************",1);
         COM_errorLog("Args to new_session: userid = $userid, remote_ip = $remote_ip, lifespan = $lifespan, md5_based = $md5_based",1);
     }
-    mt_srand((double)microtime()*1000000);
     $sessid = mt_rand();
 
     // For added security we are adding the option to build a IP-based
@@ -251,10 +331,17 @@ function SESS_newSession($userid, $remote_ip, $lifespan, $md5_based=0)
     $expirytime = (string) (time() - $lifespan);
     if (!isset($_COOKIE[$_CONF['cookie_session']])) {
         // ok, delete any old sessons for this user
-        DB_query("DELETE FROM {$_TABLES['sessions']} WHERE uid = $userid");
+        if ($userid > 1) {
+            DB_delete($_TABLES['sessions'], 'uid', $userid);
+        } else {
+            DB_delete($_TABLES['sessions'], array('uid', 'remote_ip'),
+                                            array(1, $remote_ip));
+        }
     } else {
+        DB_lockTable($_TABLES['sessions']);
         $deleteSQL = "DELETE FROM {$_TABLES['sessions']} WHERE (start_time < $expirytime)";
         $delresult = DB_query($deleteSQL);
+        DB_unlockTable($_TABLES['sessions']);
 
         if ($_SESS_VERBOSE) {
             COM_errorLog("Attempted to delete rows from session table with following SQL\n$deleteSQL\n",1);
@@ -265,35 +352,41 @@ function SESS_newSession($userid, $remote_ip, $lifespan, $md5_based=0)
             die("Delete failed in new_session()");
         }
     }
-    // Remove the anonymous sesssion for this user
-    DB_query("DELETE FROM {$_TABLES['sessions']} WHERE uid = 1 AND remote_ip = '$remote_ip'");
-
+    // Remove the anonymous session for this user
+    if ($userid > 1) {
+        // Retrieve any session variables that we need to add to the new logged in session
+        // To come
+        // Delete record
+        DB_delete($_TABLES['sessions'], array('uid', 'remote_ip'),
+                                        array(1, $remote_ip));
+    }
+    
     // Create new session
     if (empty ($md5_sessid)) {
-        $sql = "INSERT INTO {$_TABLES['sessions']} (sess_id, uid, start_time, remote_ip) VALUES ($sessid, $userid, $currtime, '$remote_ip')";
+        $sql = "INSERT INTO {$_TABLES['sessions']} (sess_id, uid, start_time, remote_ip, whos_online) VALUES ($sessid, $userid, $currtime, '$remote_ip', 1)";
     } else {
-        $sql = "INSERT INTO {$_TABLES['sessions']} (sess_id, md5_sess_id, uid, start_time, remote_ip) VALUES ($sessid, '$md5_sessid', $userid, $currtime, '$remote_ip')";
+        $sql = "INSERT INTO {$_TABLES['sessions']} (sess_id, md5_sess_id, uid, start_time, remote_ip, whos_online) VALUES ($sessid, '$md5_sessid', $userid, $currtime, '$remote_ip', 1)";
     }
     $result = DB_query($sql);
     if ($result) {
         if ($_CONF['lastlogin'] == true) {
-            // Update userinfo record to record the date and time as lastlogin
+            // Update userinfo record to record the date and time as lastlogin 
             DB_query("UPDATE {$_TABLES['userinfo']} SET lastlogin = UNIX_TIMESTAMP() WHERE uid=$userid");
         }
         if ($_SESS_VERBOSE) COM_errorLog("Assigned the following session id: $sessid",1);
         if ($_SESS_VERBOSE) COM_errorLog("*************leaving SESS_newSession*****************",1);
         if ($md5_based == 1) {
             // Cellular phones IP address is changed frequently. So, seve it.
-        	if( function_exists( 'CUSTOM_MOBILE_is_cellular' ) && CUSTOM_MOBILE_is_cellular()) {
+            if( function_exists( 'CUSTOM_MOBILE_is_cellular' ) && CUSTOM_MOBILE_is_cellular()) {
                 CUSTOM_MOBILE_save_session($md5_sessid, $remote_ip);
             }
             return $md5_sessid;
         } else {
             // Cellular phones IP address is changed frequently. So, save it.
-        	if( function_exists( 'CUSTOM_MOBILE_is_cellular' ) && CUSTOM_MOBILE_is_cellular()) {
+            if( function_exists( 'CUSTOM_MOBILE_is_cellular' ) && CUSTOM_MOBILE_is_cellular()) {
                 CUSTOM_MOBILE_save_session($sessid, $remote_ip);
             }
-        	return $sessid;
+            return $sessid;
         }
     } else {
         echo DB_error().": ".DB_error()."<br" . XHTML . ">";
@@ -327,9 +420,9 @@ function SESS_setSessionCookie($sessid, $cookietime, $cookiename, $cookiepath, $
         COM_errorLog ("Setting session cookie: setcookie($cookiename, $sessid, 0, $cookiepath, $cookiedomain, $cookiesecure);", 1);
     }
 
-    if (setcookie ($cookiename, $sessid, 0, $cookiepath, $cookiedomain,
-                   $cookiesecure) === false) {
-        COM_errorLog ('Failed to set session cookie.', 1);
+    if (SEC_setCookie($cookiename, $sessid, 0, $cookiepath, $cookiedomain,
+                      $cookiesecure) === false) {
+        COM_errorLog('Failed to set session cookie.', 1);
     }
 }
 
@@ -359,10 +452,10 @@ function SESS_getUserIdFromSession($sessid, $cookietime, $remote_ip, $md5_based=
     // Cellular phones IP address is changed frequently. So, load saived one.
     if( function_exists( 'CUSTOM_MOBILE_is_cellular' ) && CUSTOM_MOBILE_is_cellular()) {
         CUSTOM_MOBILE_debug("remote_ip: $remote_ip");
-    	$remote_ip = CUSTOM_MOBILE_load_ip();
+        $remote_ip = CUSTOM_MOBILE_load_ip();
         CUSTOM_MOBILE_debug("remote_ip from mobile session: $remote_ip");
     }
-    
+
     if ($md5_based == 1) {
         $sql = "SELECT uid FROM {$_TABLES['sessions']} WHERE "
         . "(md5_sess_id = '$sessid') AND (start_time > $mintime) AND (remote_ip = '$remote_ip')";
@@ -372,20 +465,21 @@ function SESS_getUserIdFromSession($sessid, $cookietime, $remote_ip, $md5_based=
     }
 
     if ($_SESS_VERBOSE) {
-        COM_errorLog("SQL in SESS_getUserIdFromSession is:\n<br" . XHTML . "> $sql <br" . XHTML . ">\n");
+        COM_errorLog("SQL in SESS_getUserIdFromSession is:\n $sql\n", 1);
     }
 
     $result = DB_query($sql);
-    $row = DB_fetchArray($result);
-
+    $numrows = DB_numRows($result);
+    
     if ($_SESS_VERBOSE) {
         COM_errorLog("****Leaving SESS_getUserIdFromSession",1);
     }
 
-    if (!$row) {
-        return 0;
-    } else {
+    if ($numrows == 1) {
+        $row = DB_fetchArray($result);
         return $row['uid'];
+    } else {
+        return 0;
     }
 }
 
@@ -407,9 +501,9 @@ function SESS_updateSessionTime($sessid, $md5_based=0)
     $newtime = (string) time();
 
     if ($md5_based == 1) {
-        $sql = "UPDATE {$_TABLES['sessions']} SET start_time=$newtime WHERE (md5_sess_id = '$sessid')";
+        $sql = "UPDATE {$_TABLES['sessions']} SET start_time = $newtime, whos_online = 1 WHERE (md5_sess_id = '$sessid')";
     } else {
-        $sql = "UPDATE {$_TABLES['sessions']} SET start_time=$newtime WHERE (sess_id = $sessid)";
+        $sql = "UPDATE {$_TABLES['sessions']} SET start_time = $newtime, whos_online = 1 WHERE (sess_id = '$sessid')";
     }
 
     $result = DB_query($sql);
@@ -430,8 +524,7 @@ function SESS_endUserSession($userid)
 {
     global $_TABLES;
 
-    $sql = "DELETE FROM {$_TABLES['sessions']} WHERE (uid = $userid)";
-    $result = DB_query($sql);
+    DB_delete($_TABLES['sessions'], 'uid', $userid);
 
     // for cellular phones which has no Cookies.
     if( function_exists( 'CUSTOM_MOBILE_is_cellular' ) && CUSTOM_MOBILE_is_cellular()) {
@@ -459,11 +552,11 @@ function SESS_getUserData($username)
         . "{$_TABLES['userprefs']}.uid = {$_TABLES['users']}.uid AND username = '$username'";
 
     if(!$result = DB_query($sql)) {
-        COM_errorLog("error in get_userdata");
+        COM_errorLog("error in get_userdata", 1);
     }
 
     if(!$myrow = DB_fetchArray($result)) {
-        COM_errorLog("error in get_userdata");
+        COM_errorLog("error in get_userdata", 1);
     }
 
     return($myrow);
@@ -474,28 +567,103 @@ function SESS_getUserData($username)
 *
 * Gets user's data based on their user id
 *
-* @param        int     $userid     User ID of user to get data for
-* @return       array   returns user'd data in an array
+* @param    int     $userid     User ID of user to get data for
+* @return   array               returns user's data in an array
 *
 */
 function SESS_getUserDataFromId($userid)
 {
     global $_TABLES;
 
-    $sql = "SELECT *,format FROM {$_TABLES['dateformats']},{$_TABLES["users"]},{$_TABLES['userprefs']} "
+    $sql = "SELECT *,format FROM {$_TABLES['dateformats']},{$_TABLES['users']},{$_TABLES['userprefs']} "
      . "WHERE {$_TABLES['dateformats']}.dfid = {$_TABLES['userprefs']}.dfid AND "
      . "{$_TABLES['userprefs']}.uid = $userid AND {$_TABLES['users']}.uid = $userid";
 
-    if(!$result = DB_query($sql)) {
-        $userdata = array("error" => "1");
-        return ($userdata);
+    if (!$result = DB_query($sql)) {
+        $userdata = array('error' => '1');
+        return $userdata;
     }
 
-    if(!$myrow = DB_fetchArray($result)) {
-        $userdata = array("error" => "1");
-        return ($userdata);
+    if (!$myrow = DB_fetchArray($result, false)) {
+        $userdata = array('error' => '1');
+        return $userdata;
     }
-    return($myrow);
+
+    return $myrow;
+}
+
+
+/**
+* Gets the Session ID from the User Id
+*
+* Returns the session id associated with the user if available.
+* This is not for anonymous users. If no match found, returns an empty string.
+*
+* @param        int      $uid         User Id to retrieve session Id for
+* @return       string                Session ID
+*/
+function SESS_getSessionIdFromUserId($uid)
+{
+    global $_TABLES;
+
+    $retval = '';
+    if ($uid > 1) {
+        $retval = DB_getItem($_TABLES['sessions'], "sess_id", "uid = $uid");
+    }
+
+    return $retval;   
+}
+
+/**
+* Retrieves a session variable from the db
+*
+* @param        string      $variable   Variable name to retrieve
+* @return       string     data from variable
+*
+*/
+function SESS_getVariable($variable)
+{
+    global $_TABLES, $_CONF, $_USER;
+    
+    $session_id = $_USER['session_id'];
+
+    if ( $_CONF['cookie_ip'] == 1) { // $md5_based  Indicates if sessid is MD5 hash
+        $sql_where = "md5_sess_id = '$session_id'";
+    } else {
+        $sql_where = "sess_id = '$session_id'";
+    }
+
+    $retval = DB_getItem($_TABLES['sessions'], $variable, $sql_where);
+
+    return $retval;
+}
+
+/**
+* Updates a session variable from the db
+*
+* @param        string      $variable   Variable name to update
+* @param        string      $value      Value of variable
+* @param        string      $session_id Session ID of variable to update (0 = current session)
+* @return       boolean     always true for some reason
+*
+*/
+function SESS_setVariable($variable, $value, $session_id = 0)
+{
+    global $_TABLES, $_CONF, $_USER;
+    
+    if ($session_id == 0) {
+        $session_id = $_USER['session_id'];
+    }
+
+    if ( $_CONF['cookie_ip'] == 1) { // $md5_based  Indicates if sessid is MD5 hash
+        $sql = "UPDATE {$_TABLES['sessions']} SET $variable = '$value' WHERE (md5_sess_id = '$session_id')";
+    } else {
+        $sql = "UPDATE {$_TABLES['sessions']} SET $variable = '$value' WHERE (sess_id = '$session_id')";
+    }
+
+    $result = DB_query($sql);
+
+    return 1;
 }
 
 ?>
