@@ -90,13 +90,13 @@ function SYND_feedUpdateCheckAll( $frontpage_only, $update_info, $limit, $update
     if( count( $topiclist ) > 0 )
     {
         $tlist = "'" . implode( "','", $topiclist ) . "'";
-        $where .= " AND (tid IN ($tlist))";
+        $where .= " AND ta.type = 'article' AND ta.id = sid AND (ta.tid IN ($tlist))";
 
         if ($frontpage_only) {
             $where .= ' AND frontpage = 1';
         }
 
-        $result = DB_query( "SELECT sid FROM {$_TABLES['stories']} WHERE draft_flag = 0 AND date <= NOW() $where AND perm_anon > 0 ORDER BY date DESC $limitsql" );
+        $result = DB_query( "SELECT sid FROM {$_TABLES['stories']}, {$_TABLES['topic_assignments']} ta WHERE draft_flag = 0 AND date <= NOW() $where AND perm_anon > 0 GROUP BY sid ORDER BY date DESC $limitsql" );
         $nrows = DB_numRows( $result );
 
         for( $i = 0; $i < $nrows; $i++ )
@@ -155,7 +155,16 @@ function SYND_feedUpdateCheckTopic( $tid, $update_info, $limit, $updated_topic =
         $limitsql = ' LIMIT 10';
     }
 
-    $result = DB_query( "SELECT sid FROM {$_TABLES['stories']} WHERE draft_flag = 0 AND date <= NOW() AND tid = '$tid'" . COM_getTopicSQL('AND', 1) . " AND perm_anon > 0 ORDER BY date DESC $limitsql" );
+    // "SELECT sid FROM {$_TABLES['stories']} WHERE draft_flag = 0 AND date <= NOW() AND tid = '$tid'" . COM_getTopicSQL('AND', 1) . " AND perm_anon > 0 ORDER BY date DESC $limitsql"
+    $sql = "SELECT sid 
+        FROM {$_TABLES['stories']}, {$_TABLES['topic_assignments']} ta 
+        WHERE draft_flag = 0 AND date <= NOW() AND perm_anon > 0
+        AND ta.type = 'article' AND ta.id = sid 
+        AND ta.tid = '$tid'" . COM_getTopicSQL('AND', 1, 'ta') . "
+        GROUP BY sid
+        ORDER BY date DESC $limitsql";
+
+    $result = DB_query($sql);
     $nrows = DB_numRows( $result );
 
     $sids = array ();
@@ -256,7 +265,19 @@ function SYND_getFeedContentPerTopic( $tid, $limit, &$link, &$update, $contentLe
         $topic = stripslashes( DB_getItem( $_TABLES['topics'], 'topic',
                                "tid = '$tid'" ));
 
-        $result = DB_query( "SELECT sid,uid,title,introtext,bodytext,postmode,UNIX_TIMESTAMP(date) AS modified,commentcode,trackbackcode FROM {$_TABLES['stories']} WHERE draft_flag = 0 AND date <= NOW() AND tid = '$tid' AND perm_anon > 0 ORDER BY date DESC $limitsql" );
+        // Retrieve list of inherited topics for anonymous user
+        $tid_list = TOPIC_getChildList($tid, 1);        
+
+        //$sql = "SELECT sid,uid,title,introtext,bodytext,postmode,UNIX_TIMESTAMP(date) AS modified,commentcode,trackbackcode FROM {$_TABLES['stories']} WHERE draft_flag = 0 AND date <= NOW() AND tid = '$tid' AND perm_anon > 0 ORDER BY date DESC $limitsql";
+        $sql = "SELECT sid,uid,title,introtext,bodytext,postmode,UNIX_TIMESTAMP(date) AS modified,commentcode,trackbackcode 
+            FROM {$_TABLES['stories']}, {$_TABLES['topic_assignments']} ta 
+            WHERE draft_flag = 0 AND date <= NOW() AND perm_anon > 0 
+            AND ta.type = 'article' AND ta.id = sid 
+            AND (ta.tid IN({$tid_list}) AND (ta.inherit = 1 OR (ta.inherit = 0 AND ta.tid = '$tid'))) 
+            GROUP BY sid 
+            ORDER BY date DESC $limitsql";
+
+        $result = DB_query($sql);
 
         $nrows = DB_numRows( $result );
 
@@ -269,7 +290,7 @@ function SYND_getFeedContentPerTopic( $tid, $limit, &$link, &$update, $contentLe
             $fulltext = stripslashes( $row['introtext']."\n".$row['bodytext'] );
             $fulltext = PLG_replaceTags( $fulltext );
             $storytext = ($contentLength == 1) ? $fulltext : COM_truncateHTML ($fulltext, $contentLength, ' ...');
- 
+
 
             $fulltext = trim( $fulltext );
             $fulltext = str_replace(array("\015\012", "\015"), "\012", $fulltext);
@@ -278,11 +299,11 @@ function SYND_getFeedContentPerTopic( $tid, $limit, &$link, &$update, $contentLe
             {
                 if( !empty($storytext) )
                 {
-                    $storytext = nl2br($storytext);
+                    $storytext = COM_nl2br($storytext);
                 }
                 if( !empty($fulltext) )
                 {
-                    $fulltext = nl2br($fulltext);
+                    $fulltext = COM_nl2br($fulltext);
                 }
             }
 
@@ -338,6 +359,7 @@ function SYND_getFeedContentAll($frontpage_only, $limit, &$link, &$update, $cont
     $link = $_CONF['site_url'];
 
     $where = '';
+
     if( !empty( $limit ))
     {
         if( substr( $limit, -1 ) == 'h' ) // last xx hours
@@ -382,13 +404,19 @@ function SYND_getFeedContentAll($frontpage_only, $limit, &$link, &$update, $cont
     }
     if( !empty( $tlist ))
     {
-        $where .= " AND (tid IN ($tlist))";
+        $where .= " AND (ta.tid IN ($tlist))";
     }
     if ($frontpage_only) {
         $where .= ' AND frontpage = 1';
     }
 
-    $result = DB_query( "SELECT sid,tid,uid,title,introtext,bodytext,postmode,UNIX_TIMESTAMP(date) AS modified,commentcode,trackbackcode FROM {$_TABLES['stories']} WHERE draft_flag = 0 AND date <= NOW() $where AND perm_anon > 0 ORDER BY date DESC $limitsql" );
+    $sql = "SELECT sid,ta.tid,uid,title,introtext,bodytext,postmode,UNIX_TIMESTAMP(date) AS modified,commentcode,trackbackcode 
+        FROM {$_TABLES['stories']}, {$_TABLES['topic_assignments']} ta 
+        WHERE draft_flag = 0 AND date <= NOW() AND ta.type = 'article' AND ta.id = sid AND ta.tdefault = 1 $where AND perm_anon > 0 
+        GROUP BY sid,ta.tid
+        ORDER BY date DESC $limitsql";
+
+    $result = DB_query($sql);
 
     $content = array();
     $sids = array();
@@ -411,14 +439,14 @@ function SYND_getFeedContentAll($frontpage_only, $limit, &$link, &$update, $cont
         {
             if( !empty($storytext) )
             {
-                $storytext = nl2br($storytext);
+                $storytext = COM_nl2br($storytext);
             }
             if( !empty($fulltext) )
             {
-                $fulltext = nl2br($fulltext);
+                $fulltext = COM_nl2br($fulltext);
             }
         }
-        
+
         $storylink = COM_buildUrl( $_CONF['site_url'] . '/article.php?story='
                                    . $row['sid'] );
         $extensionTags = PLG_getFeedElementExtensions('article', $row['sid'], $feedType, $feedVersion, $fid, ($frontpage_only ? '::frontpage' : '::all'));
@@ -462,6 +490,8 @@ function SYND_updateFeed( $fid )
 {
     global $_CONF, $_TABLES, $_SYND_DEBUG;
 
+    SYND_fixCharset($fid);
+
     $result = DB_query( "SELECT * FROM {$_TABLES['syndication']} WHERE fid = $fid");
     $A = DB_fetchArray( $result );
     if( $A['is_enabled'] == 1 )
@@ -477,7 +507,7 @@ function SYND_updateFeed( $fid )
                                           . '/classes/syndication/' );
         $format = explode( '-', $A['format'] );
         $feed = $factory->writer( $format[0], $format[1] );
-        
+
         if( $feed )
         {
             $feed->encoding = $A['charset'];
@@ -576,7 +606,7 @@ function SYND_updateFeed( $fid )
                 $filename = substr( $_CONF['rdf_file'], $pos + 1 );
             }
             $feed->url = SYND_getFeedUrl( $filename );
-            
+
             $feed->extensions = PLG_getFeedExtensionTags($A['type'], $format[0], $format[1], $A['topic'], $fid, $feed);
 
             /* Inject the self reference for Atom into RSS feeds. Illogical?
@@ -627,7 +657,7 @@ function SYND_updateFeed( $fid )
 function SYND_truncateSummary($text, $length)
 {
     $storytext = ($length == 1) ? $text : COM_truncateHTML ($text, $length, ' ...');
-    
+
     return $storytext;
 }
 
@@ -723,4 +753,37 @@ function SYND_getDefaultFeedUrl()
     return $feed;
 }
 
+/**
+* Fix the character set of a default feed file which is hard-coded as 'iso-8859-1'.
+*
+* @param   int   $fid   feed id
+*/
+function SYND_fixCharset($fid)
+{
+    global $_CONF, $_TABLES, $_SYND_DEBUG;
+
+    $sql = "SELECT COUNT(filename) AS cnt "
+         . "FROM {$_TABLES['syndication']} "
+         . "WHERE (fid = {$fid}) AND (filename = 'geeklog.rss') "
+         . "AND (charset = 'iso-8859-1')";
+    $result = DB_query($sql);
+
+    if ($result !== false) {
+        list ($cnt) = DB_fetchArray($result);
+
+        if ($cnt == 1) {
+            $fileName = SYND_getFeedPath('geeklog.rss');
+            clearstatcache();
+
+            if (@filesize($fileName) === 0) {
+                $charset = DB_escapeString(COM_getCharset());
+                $sql = "UPDATE {$_TABLES['syndication']} "
+                     . "SET charset = '{$charset}' "
+                     . "WHERE (fid = {$fid})";
+                DB_query($sql);
+            }
+        }
+    }
+}
+
 ?>
