@@ -8,7 +8,7 @@
 // |                                                                           |
 // | User-related functions needed in more than one place.                     |
 // +---------------------------------------------------------------------------+
-// | Copyright (C) 2000-2010 by the following authors:                         |
+// | Copyright (C) 2000-2011 by the following authors:                         |
 // |                                                                           |
 // | Authors: Tony Bibbs        - tony AT tonybibbs DOT com                    |
 // |          Mark Limburg      - mlimburg AT users DOT sourceforge DOT net    |
@@ -103,9 +103,10 @@ function USER_deleteAccount ($uid)
     DB_query ("UPDATE {$_TABLES['stories']} SET uid = 1 WHERE uid = $uid");
     DB_query ("UPDATE {$_TABLES['stories']} SET owner_id = 1 WHERE owner_id = $uid");
 
-    // delete story submissions
+    // delete submissions
     DB_delete ($_TABLES['storysubmission'], 'uid', $uid);
-
+    DB_delete ($_TABLES['commentsubmissions'], 'uid', $uid); // Includes article and plugin submissions
+    
     // delete user photo, if enabled & exists
     if ($_CONF['allow_user_photo'] == 1) {
         $photo = DB_getItem ($_TABLES['users'], 'photo', "uid = $uid");
@@ -128,28 +129,6 @@ function USER_deleteAccount ($uid)
     return true;
 }
 
-/**
-* Create a new password and set in DB if User Id supplied
-*
-* @param    int      $uid   id of the user
-* @return   array    ['normal'] = human readable password, ['encrypted'] = encrypted password
-*
-*/
-function USER_createPassword ($uid = 0)
-{
-    global $_TABLES;
-
-    $passwd['normal'] = rand ();
-    $passwd['normal'] = md5 ($passwd['normal']);
-    $passwd['normal'] = substr ($passwd['normal'], 1, 8);
-    $passwd['encrypted'] = SEC_encryptPassword($passwd['normal']);
-    if ($uid > 1) { 
-        DB_change ($_TABLES['users'], 'passwd', $passwd['encrypted'], 'uid', $uid);
-    }
-    
-    return $passwd;
-}
-
 /**
 * Create a new password and send it to the user
 *
@@ -162,8 +141,8 @@ function USER_createAndSendPassword ($username, $useremail, $uid)
 {
     global $_CONF, $LANG04;
 
-    $passwords = USER_createPassword($uid);
-    $passwd = $passwords['normal'];
+    $passwd = null;
+    SEC_updateUserPassword($passwd, $uid);
 
     if (file_exists ($_CONF['path_data'] . 'welcome_email.txt')) {
         $template = COM_newTemplate($_CONF['path_data']);
@@ -261,25 +240,27 @@ function USER_createAccount($username, $email, $passwd = '', $fullname = '', $ho
     global $_CONF, $_TABLES;
 
     $queueUser = false;
-    $username = addslashes($username);
-    $email = addslashes($email);
+    $username = DB_escapeString($username);
+    $email = DB_escapeString($email);
 
     $regdate = strftime('%Y-%m-%d %H:%M:%S', time());
     $fields = 'username,email,regdate,cookietimeout';
     $values = "'$username','$email','$regdate','{$_CONF['default_perm_cookie_timeout']}'";
 
     if (! empty($passwd)) {
-        $passwd = addslashes($passwd);
-        $fields .= ',passwd';
-        $values .= ",'$passwd'";
+        // Since no uid exists yet we can't use SEC_updateUserPassword and must handle things manually
+        $salt = SEC_generateSalt();
+        $passwd = SEC_encryptPassword($passwd, $salt, $_CONF['pass_alg'], $_CONF['pass_stretch']); 
+        $fields .= ',passwd,salt,algorithm,stretch';
+        $values .= ",'$passwd','$salt','" . $_CONF['pass_alg'] . "','" . $_CONF['pass_stretch'] . "'";
     }
     if (! empty($fullname)) {
-        $fullname = addslashes($fullname);
+        $fullname = DB_escapeString($fullname);
         $fields .= ',fullname';
         $values .= ",'$fullname'";
     }
     if (! empty($homepage)) {
-        $homepage = addslashes($homepage);
+        $homepage = DB_escapeString($homepage);
         $fields .= ',homepage';
         $values .= ",'$homepage'";
     }
@@ -336,7 +317,7 @@ function USER_createAccount($username, $email, $passwd = '', $fullname = '', $ho
         DB_query("INSERT INTO {$_TABLES['userindex']} (uid,etids) VALUES ($uid, '-')");
     }
 
-    DB_query("INSERT INTO {$_TABLES['usercomment']} (uid,commentmode,commentlimit) VALUES ($uid,'{$_CONF['comment_mode']}','{$_CONF['comment_limit']}')");
+    DB_query("INSERT INTO {$_TABLES['usercomment']} (uid,commentmode,commentorder,commentlimit) VALUES ($uid,'{$_CONF['comment_mode']}','{$_CONF['comment_order']}','{$_CONF['comment_limit']}')");
     DB_query("INSERT INTO {$_TABLES['userinfo']} (uid) VALUES ($uid)");
 
     // call custom registration function and plugins
@@ -443,20 +424,22 @@ function USER_getPhoto ($uid = 0, $photo = '', $email = '', $width = 0)
         }
 
         $img = '';
-        if (empty ($photo) || ($photo == 'none')) {
+        if (empty($photo) || ($photo == 'none')) {
             // no photo - try gravatar.com, if allowed
             if ($_CONF['use_gravatar']) {
-                $img = 'http://www.gravatar.com/avatar.php?gravatar_id='
-                     . md5 ($email);
+                $img = 'https://www.gravatar.com/avatar/' . md5($email);
+                $parms = array();
                 if ($width > 0) {
-                    $img .= '&amp;size=' . $width;
+                    $parms[] = 's=' . $width;
                 }
-                if (!empty ($_CONF['gravatar_rating'])) {
-                    $img .= '&amp;rating=' . $_CONF['gravatar_rating'];
+                if (! empty($_CONF['gravatar_rating'])) {
+                    $parms[] = 'r=' . $_CONF['gravatar_rating'];
                 }
-                if (!empty ($_CONF['default_photo'])) {
-                    $img .= '&amp;default='
-                         . urlencode ($_CONF['default_photo']);
+                if (! empty($_CONF['default_photo'])) {
+                    $parms[] = 'd=' . urlencode($_CONF['default_photo']);
+                }
+                if (count($parms) > 0) {
+                    $img .= '?' . implode('&amp;', $parms);
                 }
             }
         } else {
@@ -506,9 +489,8 @@ function USER_deletePhoto ($photo, $abortonerror = true)
         if (file_exists ($filetodelete)) {
             if (!@unlink ($filetodelete)) {
                 if ($abortonerror) {
-                    $display = COM_siteHeader ('menu', $LANG04[21])
-                             . COM_errorLog ("Unable to remove file $photo")
-                             . COM_siteFooter ();
+                    $display = COM_errorLog ("Unable to remove file $photo");
+                    $display = COM_createHTMLDocument($display, array('pagetitle' => $LANG04[21]));
                     echo $display;
                     exit;
                 } else {
@@ -612,7 +594,9 @@ function USER_emailMatches ($email, $domain_list)
         $email_domain = substr ($email, strpos ($email, '@') + 1);
 
         foreach ($domains as $domain) {
-            if (preg_match ("#$domain#i", $email_domain)) {
+            $domain = trim($domain);	// To fix bug #0001701
+
+            if (preg_match("#{$domain}#i", $email_domain)) {
                 $match_found = true;
                 break;
             }
@@ -644,7 +628,7 @@ function USER_uniqueUsername($username)
 
     $try = $username;
     do {
-        $try = addslashes($try);
+        $try = DB_escapeString($try);
         $uid = DB_getItem($_TABLES['users'], 'uid', "username = '$try'");
         if (!empty($uid)) {
             $r = rand(2, 9999);
@@ -733,7 +717,7 @@ function USER_subscribeToTopic($tid)
         $etids[] = $tid;
         $user_etids = implode(' ', $etids);
     }
-    $user_etids = addslashes($user_etids);
+    $user_etids = DB_escapeString($user_etids);
 
     DB_query("UPDATE {$_TABLES['userindex']} SET etids = '$user_etids' WHERE uid = {$_USER['uid']}");
 }
@@ -783,7 +767,7 @@ function USER_unsubscribeFromTopic($tid)
     } else {
         $user_etids = implode(' ', $etids);
     }
-    $user_etids = addslashes($user_etids);
+    $user_etids = DB_escapeString($user_etids);
 
     DB_query("UPDATE {$_TABLES['userindex']} SET etids = '$user_etids' WHERE uid = {$_USER['uid']}");
 }
@@ -863,15 +847,14 @@ function USER_getAllowedTopics()
 function USER_showProfile($uid, $preview = false, $msg = 0, $plugin = '')
 {
     global $_CONF, $_TABLES, $_USER, $_IMAGE_TYPE,
-           $LANG01, $LANG04, $LANG09, $LANG_LOGIN, $LANG_ADMIN;
+           $LANG01, $LANG04, $LANG09, $LANG28, $LANG_LOGIN, $LANG_ADMIN;
 
     $retval = '';
 
     if (COM_isAnonUser() &&
         (($_CONF['loginrequired'] == 1) || ($_CONF['profileloginrequired'] == 1))) {
-        $retval .= COM_siteHeader('menu', $LANG_LOGIN[1]);
         $retval .= SEC_loginRequiredForm();
-        $retval .= COM_siteFooter();
+        $retval = COM_createHTMLDocument($retval, array('pagetitle' => $LANG_LOGIN[1]));
 
         return $retval;
     }
@@ -879,7 +862,7 @@ function USER_showProfile($uid, $preview = false, $msg = 0, $plugin = '')
     $result = DB_query("SELECT {$_TABLES['users']}.uid,username,fullname,regdate,homepage,about,location,pgpkey,photo,email,status FROM {$_TABLES['userinfo']},{$_TABLES['users']} WHERE {$_TABLES['userinfo']}.uid = {$_TABLES['users']}.uid AND {$_TABLES['users']}.uid = $uid");
     $nrows = DB_numRows($result);
     if ($nrows == 0) { // no such user
-        return COM_refresh($_CONF['site_url'] . '/index.php');
+        COM_handle404();
     }
     $A = DB_fetchArray($result);
 
@@ -887,11 +870,14 @@ function USER_showProfile($uid, $preview = false, $msg = 0, $plugin = '')
         COM_displayMessageAndAbort(30, '', 403, 'Forbidden');
     }
 
+    if ($A['status'] != USER_ACCOUNT_ACTIVE && !SEC_hasRights('user.edit')) {
+        COM_handle404();
+    }
+    
     $display_name = COM_getDisplayName($uid, $A['username'], $A['fullname']);
     $display_name = htmlspecialchars($display_name);
 
     if (! $preview) {
-        $retval .= COM_siteHeader('menu', $LANG04[1] . ' ' . $display_name);
         if ($msg > 0) {
             $retval .= COM_showMessage($msg, $plugin);
         }
@@ -982,9 +968,9 @@ function USER_showProfile($uid, $preview = false, $msg = 0, $plugin = '')
     $user_templates->set_var('lang_location', $LANG04[106]);
     $user_templates->set_var('user_location', strip_tags($A['location']));
     $user_templates->set_var('lang_bio', $LANG04[7]);
-    $user_templates->set_var('user_bio', nl2br(stripslashes ($A['about'])));
+    $user_templates->set_var('user_bio', COM_nl2br(stripslashes($A['about'])));
     $user_templates->set_var('lang_pgpkey', $LANG04[8]);
-    $user_templates->set_var('user_pgp', nl2br ($A['pgpkey']));
+    $user_templates->set_var('user_pgp', COM_nl2br($A['pgpkey']));
     $user_templates->set_var('start_block_last10stories',
             COM_startBlock($LANG04[82] . ' ' . $display_name));
     $user_templates->set_var('start_block_last10comments',
@@ -999,20 +985,17 @@ function USER_showProfile($uid, $preview = false, $msg = 0, $plugin = '')
     $user_templates->set_var('headline_last10comments', $LANG04[10]);
     $user_templates->set_var('headline_postingstats', $LANG04[83]);
 
-    $result = DB_query("SELECT tid FROM {$_TABLES['topics']}"
-                       . COM_getPermSQL());
-    $nrows = DB_numRows($result);
-    $tids = array();
-    for ($i = 0; $i < $nrows; $i++) {
-        $T = DB_fetchArray($result);
-        $tids[] = $T['tid'];
-    }
+    $tids = TOPIC_getList(0, TRUE, FALSE);
     $topics = "'" . implode("','", $tids) . "'";
 
     // list of last 10 stories by this user
     if (count($tids) > 0) {
-        $sql = "SELECT sid,title,UNIX_TIMESTAMP(date) AS unixdate FROM {$_TABLES['stories']} WHERE (uid = $uid) AND (draft_flag = 0) AND (date <= NOW()) AND (tid IN ($topics))" . COM_getPermSQL('AND');
-        $sql .= " ORDER BY unixdate DESC LIMIT 10";
+        $sql = "SELECT sid,title,UNIX_TIMESTAMP(date) AS unixdate 
+            FROM {$_TABLES['stories']}, {$_TABLES['topic_assignments']} ta 
+            WHERE (uid = $uid) AND (draft_flag = 0) AND (date <= NOW()) AND (tid IN ($topics))" . COM_getPermSQL('AND') . " 
+            AND ta.type = 'article' AND ta.id = sid AND ta.tdefault = 1 
+            ORDER BY unixdate DESC LIMIT 10";
+            
         $result = DB_query($sql);
         $nrows = DB_numRows($result);
     } else {
@@ -1038,8 +1021,11 @@ function USER_showProfile($uid, $preview = false, $msg = 0, $plugin = '')
             $user_templates->parse('story_row', 'strow', true);
         }
     } else {
-        $user_templates->set_var('story_row',
-                                 '<tr><td>' . $LANG01[37] . '</td></tr>');
+        $story_row = $LANG01[37];
+        if ($_CONF['supported_version_theme'] == '1.8.1') {
+            $story_row = '<tr><td>' . $story_row . '</td></tr>';
+        }
+        $user_templates->set_var('story_row', $story_row);
     }
 
     // list of last 10 comments by this user
@@ -1080,8 +1066,11 @@ function USER_showProfile($uid, $preview = false, $msg = 0, $plugin = '')
             }
         }
     } else {
-        $user_templates->set_var('comment_row',
-                                 '<tr><td>' . $LANG01[29] . '</td></tr>');
+        $comment_row = $LANG01[29];
+        if ($_CONF['supported_version_theme'] == '1.8.1') {
+            $comment_row = '<tr><td>' . $comment_row . '</td></tr>';
+        }
+        $user_templates->set_var('comment_row', $comment_row);
     }
 
     // posting stats for this user
@@ -1110,7 +1099,7 @@ function USER_showProfile($uid, $preview = false, $msg = 0, $plugin = '')
     $retval .= PLG_profileBlocksDisplay($uid);
 
     if (! $preview) {
-        $retval .= COM_siteFooter();
+        $retval = COM_createHTMLDocument($retval, array('pagetitle' => $LANG04[1] . ' ' . $display_name));
     }
 
     return $retval;
@@ -1160,7 +1149,7 @@ function plugin_autotags_user($op, $content = '', $autotag = '')
             );          
     } elseif ($op == 'parse') {
         $uname = COM_applyFilter($autotag['parm1']);
-        $uname = addslashes($uname);
+        $uname = DB_escapeString($uname);
         $sql = "SELECT uid, username, fullname, status FROM {$_TABLES['users']} WHERE username = '$uname'";
         $result = DB_query($sql);
         if (DB_numRows($result) == 1) {
